@@ -30,15 +30,13 @@ open CommonOptions
 open CommonTypes
 open CommonFile
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[cCO] "
-    (log_time ()); lprintf_nl2
-      
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[cCO] "
-    (log_time ()); lprintf
+let log_prefix = "[cCO]"
+
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 (*************************************************************************)
 (*                                                                       *)
@@ -70,12 +68,12 @@ module FileOption = struct
             with _ -> "Donkey" in
           let network = 
             try network_find_by_name network with e ->
-                lprintf_nl ()
+                lprintf_nl
 		  "Error %s for network %s while parsing file %s"
 		    (Printexc2.to_string e)
 		    network
 		    (get_value "file_filename" value_to_string);
-		lprintf_nl () "This core is lacking support for network %s, exiting" network;
+    lprintf_nl "This core is lacking support for network %s, exiting" network;
                 exit_properly 70
           in
           let file_state = 
@@ -99,18 +97,20 @@ module FileOption = struct
                 normalize_time (get_value "file_age" value_to_int)
             with _ -> ());
           set_file_state file file_state;       
-          if !verbose then
-          (match file_state with
-              FileDownloading -> lprintf_nl () "New downloading file - check complete";
-            | FileDownloaded -> lprintf_nl () "New downloaded file - check complete";
-            | _ -> lprintf_nl () "New file with other state - check complete"
-          );
-          
+
           (try
               set_file_best_name file
               (get_value "file_filename" value_to_string)
             with _ -> ());
           set_file_priority file priority;
+
+          if !verbose then lprintf_nl "New %s file %s"
+	      (match file_state with
+                 FileDownloading -> "downloading"
+               | FileDownloaded -> "downloaded"
+               | _ -> "other")
+	     (file_best_name file);
+
           file
       | _ -> assert false
           
@@ -266,7 +266,7 @@ module ServerOption = struct
           in
           let network = 
             try network_find_by_name network with e ->
-                lprintf_nl () "Network %s not supported" network;
+                lprintf_nl "Network %s not supported" network;
                 raise e
               in
           let server = network_server_of_option network assocs in
@@ -940,7 +940,10 @@ let load () =
   known_uids =:= [];
   Options.load friends_ini
 
+let allow_saving_ini_files = ref true
+
 let save () =
+  if !allow_saving_ini_files then begin
   networks_iter (fun n -> network_save_complex_options n);
 
   Options.save_with_help files_ini;
@@ -962,94 +965,81 @@ let save () =
         Options.save_with_help results_ini;
         results =:= [];
     end;
-  lprintf_nl () "Options correctly saved"
+  lprintf_nl "Options correctly saved"
+  end
 
 let save_sources () =
+  if !allow_saving_ini_files then begin
   networks_iter (fun n -> network_save_sources n);
-  lprintf_nl () "Sources correctly saved"
+  lprintf_nl "Sources correctly saved"
+  end
 
 open Zip
 
 let backup_zip archive files =
-  begin
-    let oc = Zip.open_out archive in
-    try
-        List.iter (fun file ->
-	  begin
-	    try
-              let s = Unix.stat file in
-		Zip.copy_file_to_entry file oc ~level:9 ~mtime:s.Unix.st_mtime file
-	    with e ->
-	      failwith (Printf.sprintf "Zip: error %s in %s" (Printexc2.to_string e) file)
-	  end
-        ) files;
-      Zip.close_out oc
-    with e ->
-	Zip.close_out oc;
-	failwith (Printf.sprintf "Zip: error %s in %s" (Printexc2.to_string e) archive)
-  end
+  try 
+    Unix2.tryopen_write_zip archive (fun oc ->
+      List.iter (fun file ->
+	try
+          let s = Unix.stat file in
+	  Zip.copy_file_to_entry file oc ~level:9 ~mtime:s.Unix.st_mtime file
+	with e ->
+	  failwith (Printf.sprintf "Zip: error %s in %s" (Printexc2.to_string e) file)
+      ) files)
+  with e ->
+    failwith (Printf.sprintf "Zip: error %s in %s" (Printexc2.to_string e) archive)
 
 open Tar
 
 let backup_tar archive files =
-  let failed_files = ref "" in
-  let otar = Tar.open_out ~compress:`Gzip archive in
+  let failed_files = ref [] in
+  Unix2.tryopen_write_tar ~compress:`Gzip archive (fun otar ->
     List.iter (fun arg ->
-    begin
       try
-	let ic = Pervasives.open_in_bin arg in
-	let stat = Unix.stat arg in
-	let size = stat.Unix.st_size in
-	if size > Sys.max_string_length then
-	  begin
-	    Tar.close_out otar;
-	    failwith (Printf.sprintf "Tar: file %s too big, limit %d byte" arg Sys.max_string_length)
-	  end;
-	let header = 
-	  { Tar.t_name = arg;
-	    t_mode = 0o644;
-            t_uid = stat.Unix.st_uid;
-            t_gid = stat.Unix.st_gid;
-            t_size = 0;
-            t_mtime = Int32.of_float stat.Unix.st_mtime;
-            t_chksum = 0;
-            t_typeflag = REGULAR;
-            t_linkname = "";
-	    t_format = POSIX_FORMAT;
-            t_uname = "";
-            t_gname = "";
-            t_devmajor = 0;
-            t_devminor = 0;
-            t_prefix = "";
-            t_gnu = None;}
-	in
-	let s = String.create size in
-	  Pervasives.really_input ic s 0 size;
-	  Pervasives.close_in ic;
-	  Tar.output otar header s
-	with e ->
-	  let error = (Printexc2.to_string e) in
-	    if error =
-	      "Gzip.Error(\"error during compression\")"
-	      && Autoconf.windows && arg = "fasttrack.ini" then
-              (* for whatever reason this error is raised on Windows,
-                 but fasttrack.ini is stored correctly *)
-	      if !verbose then
-	        lprintf_nl () "Tar: Windows specific pseudo error %s in %s" error arg
-	      else ()
-	    else
-	      begin
-		if !failed_files = "" then
-	          failed_files := arg
-		else
-    		  failed_files := Printf.sprintf "%s  %s" !failed_files arg;
-		  lprintf_nl () "Tar: error %s in %s" error arg
-              end
-    end
-    ) files;
-    Tar.close_out otar;
-    if !failed_files <> "" then
-      failwith (Printf.sprintf "Tar: error backing up %s" !failed_files)
+	let header, s =
+	  Unix2.tryopen_read_bin arg (fun ic ->
+	    let stat = Unix.stat arg in
+	    let size = stat.Unix.st_size in
+	    if size > Sys.max_string_length then
+	      failwith (Printf.sprintf "Tar: file %s too big, limit %d byte" arg Sys.max_string_length);
+	    let header = 
+	      { Tar.t_name = arg;
+	      t_mode = 0o644;
+	      t_uid = stat.Unix.st_uid;
+	      t_gid = stat.Unix.st_gid;
+	      t_size = 0;
+	      t_mtime = Int32.of_float stat.Unix.st_mtime;
+	      t_chksum = 0;
+	      t_typeflag = REGULAR;
+	      t_linkname = "";
+	      t_format = POSIX_FORMAT;
+	      t_uname = "";
+	      t_gname = "";
+	      t_devmajor = 0;
+	      t_devminor = 0;
+	      t_prefix = "";
+	      t_gnu = None;} in
+	    let s = String.create size in
+	    Pervasives.really_input ic s 0 size;
+	    header, s) in
+	Tar.output otar header s
+      with e ->
+	let error = Printexc2.to_string e in
+	if error = "Gzip.Error(\"error during compression\")"
+	  && Autoconf.windows && arg = "fasttrack.ini" then begin
+	    (* for whatever reason this error is raised on Windows,
+               but fasttrack.ini is stored correctly *)
+	    if !verbose then
+        lprintf_nl "Tar: Windows specific pseudo error %s in %s" error arg
+	  end
+	else begin
+	  failed_files := arg :: !failed_files;
+    lprintf_nl "Tar: error %s in %s" error arg
+        end
+    ) files);
+    if !failed_files <> [] then
+      failwith (Printf.sprintf "Tar: error backing up %s"
+	(String.concat " " (List.rev !failed_files)))
 
 let backup_options () =
   let counter = ref 1 in
@@ -1085,21 +1075,32 @@ let backup_options () =
           ".zip" -> backup_zip archive files
         | _ -> backup_tar archive files
       end
-    with e -> lprintf_nl () "Exception %s while options backup" (Printexc2.to_string e); raise e
+    with e -> lprintf_nl "Exception %s while options backup" (Printexc2.to_string e); raise e
   end;
-  lprintf_nl () "Options backup as %s correctly saved" format
+  lprintf_nl "Options backup as %s correctly saved" format
              
 let _ =
+  CommonBlocking.add_update_hook CommonServer.check_blocked_servers;
+  CommonBlocking.add_update_hook CommonServer.server_must_update_all;
   option_hook ip_blocking (fun _ ->
-    (try
-      Ip_set.bl := if !!ip_blocking <> "" then
-                     Ip_set.load !!ip_blocking
-                   else Ip_set.bl_empty
-    with _ -> ());
-    CommonServer.check_blocked_servers ()
+    try
+      CommonBlocking.set_ip_blocking_list !!ip_blocking
+    with _ -> ()
+  );
+  option_hook ip_blocking_countries (fun _ ->
+    CommonBlocking.set_ip_blocking_countries !!ip_blocking_countries
+  );
+  option_hook ip_blocking_countries_block (fun _ ->
+    CommonBlocking.set_ip_blocking_countries_block !!ip_blocking_countries_block;
+    CommonBlocking.set_ip_blocking_countries !!ip_blocking_countries
+  );
+  option_hook geoip_dat (fun _ ->
+    try
+      CommonBlocking.set_geoip_dat !!geoip_dat
+    with _ -> ()
   );
   option_hook max_opened_connections (fun _ ->
-  if !verbose then lprintf_nl ()
+  if !verbose then lprintf_nl
     "checking max_opened_connections = %d for validity" !!max_opened_connections;
 (* original code from ./src/config/unix/MlUnix.ml
 let max_all_sockets = getdtablesize ()
@@ -1114,7 +1115,7 @@ let max_filedescs = (max_all_sockets - max_sockets) / 2 *)
   let min_conns = 75 in
 
   if min_conns > !!max_opened_connections then begin
-    lprintf_nl () "max_opened_connections is set too low (%d), raising to %d"
+    lprintf_nl "max_opened_connections is set too low (%d), raising to %d"
       !!max_opened_connections min_conns;
     max_opened_connections =:= min_conns
   end;
@@ -1128,9 +1129,9 @@ let max_filedescs = (max_all_sockets - max_sockets) / 2 *)
   if max_all_sockets < wanted_socks then
     if max_all_sockets < total_files + min_conns then (* check if ulimit is enough to allow total_files + min_conns *)
       begin
-        lprintf_nl () "only %d file descriptors available, raise ulimit open files to at least %d"
+        lprintf_nl "only %d file descriptors available, raise ulimit open files to at least %d"
           max_all_sockets wanted_socks;
-        lprintf_nl () "FD info: max_opened_connections %d, number of (possible) concurrent downloads %d, = %d fd needed"
+        lprintf_nl "FD info: max_opened_connections %d, number of (possible) concurrent downloads %d, = %d fd needed"
           !!max_opened_connections total_files wanted_socks;
         CommonGlobals.exit_properly 71
       end
@@ -1139,12 +1140,12 @@ let max_filedescs = (max_all_sockets - max_sockets) / 2 *)
       let new_max_opened_connections =
         maxi (max_all_sockets - total_files) (max_all_sockets / 2)
       in
-      lprintf_nl () "max_opened_connections is set too high (%d), reducing to %d"
+      lprintf_nl "max_opened_connections is set too high (%d), reducing to %d"
         !!max_opened_connections new_max_opened_connections;
       max_opened_connections =:= new_max_opened_connections;
     end;
 
-  if !verbose then lprintf_nl ()
+  if !verbose then lprintf_nl
     "max_opened_connections %d, total_files %d, max_concurrent_downloads %d, !!files %d"
       !!max_opened_connections total_files !!max_concurrent_downloads (List.length !!files);
 
