@@ -26,15 +26,13 @@ open CommonTypes
 open CommonOptions
 open CommonGlobals
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[cF] "
-    (log_time ()); lprintf_nl2
-      
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[cF] "
-    (log_time ()); lprintf
+let log_prefix = "[cF]"
+
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 	    
 (*************************************************************************)
 (*                                                                       *)
@@ -58,6 +56,7 @@ type 'a file_impl = {
     mutable impl_file_last_received : (int64 * int) list;
     mutable impl_file_last_rate : float;
     mutable impl_file_best_name : string;
+    mutable impl_file_magic : string option;
     mutable impl_file_priority: int; (* normal = 0, low < 0, high > 0 *)
     mutable impl_file_last_seen : int;
     mutable impl_file_probable_name : string option;
@@ -128,6 +127,7 @@ let dummy_file_impl = {
     impl_file_last_received = [];
     impl_file_last_rate = 0.0;
     impl_file_best_name = "<UNKNOWN>";
+    impl_file_magic = None;
     impl_file_priority = 0;
     impl_file_last_seen = 0;
     impl_file_comment = "";
@@ -161,7 +161,7 @@ let files_by_num = H.create 1027
 let ni n m =
   let s = Printf.sprintf "File.%s not implemented by %s"
       m n.network_name in
-  lprintf_nl () "%s" s;
+  lprintf_nl "%s" s;
   s
 
 let fni n m = failwith (ni n m)
@@ -256,15 +256,15 @@ let set_file_best_name file name =
   let old_name = file.impl_file_best_name in
   let real_name = Filename2.filesystem_compliant name "" in
   if real_name = "" then
-    lprintf_nl () "can not rename file \"%s\" to \"%s\""
+    lprintf_nl "can not rename file \"%s\" to \"%s\""
       (String.escaped file.impl_file_best_name) (String.escaped real_name)
   else begin
     file.impl_file_best_name <- real_name;
     if name <> real_name then
-      lprintf_nl () "wanted new name \"%s\" changed to \"%s\" due to system limitations"
+      lprintf_nl "wanted new name \"%s\" changed to \"%s\" due to system limitations"
         (String.escaped name) (String.escaped file.impl_file_best_name);
     if !verbose && old_name <> file.impl_file_best_name then
-      lprintf_nl () "best_name of \"%s\" changed to \"%s\""
+      lprintf_nl "best_name of \"%s\" changed to \"%s\""
         (String.escaped old_name) (String.escaped file.impl_file_best_name)
   end
 
@@ -442,6 +442,14 @@ let set_file_priority file p =
       file_must_update file
     end
 
+let file_magic file =
+  (as_file_impl file).impl_file_magic
+  
+let set_file_magic file magic =
+  match magic with
+    None -> ()
+  | Some magic -> (as_file_impl file).impl_file_magic <- Some (HashMagic.merge files_magic magic)
+    
 let set_file_last_seen file age =
   let impl = as_file_impl file in
   impl.impl_file_last_seen <- age
@@ -614,6 +622,13 @@ let file_print file o =
             info.G.file_chunks
         ) ];
 
+      (match file_magic file with
+        Some magic ->
+	    Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-2\\\"\\>";
+	    html_mods_td buf [
+            ("File type computed by libmagic", "sr br", "File magic");
+            ("", "sr", magic) ]
+       | _ -> ());
 
       file_print_html file buf;
       
@@ -622,10 +637,13 @@ let file_print file o =
 
     end else
     begin
-      Printf.bprintf buf "[%-s %5d]\n%s\n%s\nTotal   %10s\nPartial %10s\npriority %d\n"
+      Printf.bprintf buf "[%-s %5d]\n%s\n%s%s\nTotal   %10s\nPartial %10s\npriority %d\n"
         n.network_name
         (file_num file)
         (String2.shorten 80 (file_best_name file))
+	(match file_magic file with
+	   Some magic -> Printf.sprintf "%s\n" magic
+	 | None -> "")
         (string_of_uids info.G.file_uids)
         (Int64.to_string info.G.file_size)
         (Int64.to_string info.G.file_downloaded)
@@ -812,40 +830,40 @@ let new_file_ops network =
   f
 
 let check_file_implementations () =
-  lprintf_nl () "\n---- Methods not implemented for CommonFile ----";
+  lprintf_nl "\n---- Methods not implemented for CommonFile ----";
   List.iter (fun (c, cc) ->
       let n = c.op_file_network.network_name in
-      lprintf_nl () "\n  Network %s" n; 
+      lprintf_nl "\n  Network %s" n; 
       if c.op_file_to_option == cc.op_file_to_option then 
-        lprintf_nl () "op_file_to_option";
+        lprintf_nl "op_file_to_option";
       if c.op_file_info == cc.op_file_info then
-        lprintf_nl () "op_file_info";
+        lprintf_nl "op_file_info";
       if c.op_file_commit == cc.op_file_commit then
-        lprintf_nl () "op_file_commit";
+        lprintf_nl "op_file_commit";
       if c.op_file_save_as == cc.op_file_save_as then
-        lprintf_nl () "op_file_save_as";
+        lprintf_nl "op_file_save_as";
       if c.op_file_cancel == cc.op_file_cancel then
-        lprintf_nl () "op_file_cancel";
+        lprintf_nl "op_file_cancel";
       if c.op_file_pause == cc.op_file_pause then
-        lprintf_nl () "op_file_pause";
+        lprintf_nl "op_file_pause";
       if c.op_file_resume == cc.op_file_resume then
-        lprintf_nl () "op_file_resume";
+        lprintf_nl "op_file_resume";
 (*      if c.op_file_disk_name == cc.op_file_disk_name then
         lprintf_nl "op_file_disk_name"; *)
       if c.op_file_check == cc.op_file_check then
-        lprintf_nl () "op_file_check";
+        lprintf_nl "op_file_check";
       if c.op_file_recover == cc.op_file_recover then
-        lprintf_nl () "op_file_recover";
+        lprintf_nl "op_file_recover";
       if c.op_file_set_format == cc.op_file_set_format then
-        lprintf_nl () "op_file_set_format";
+        lprintf_nl "op_file_set_format";
       if c.op_file_all_sources == cc.op_file_all_sources then
-        lprintf_nl () "op_file_all_sources";
+        lprintf_nl "op_file_all_sources";
       if c.op_file_active_sources == cc.op_file_active_sources then
-        lprintf_nl () "op_file_active_sources";
+        lprintf_nl "op_file_active_sources";
       if c.op_file_print_html == cc.op_file_print_html then
-        lprintf_nl () "op_file_print_html";
+        lprintf_nl "op_file_print_html";
       if c.op_file_print_sources_html == cc.op_file_print_sources_html then
-        lprintf_nl () "op_file_print_sources_html";
+        lprintf_nl "op_file_print_sources_html";
   ) !files_ops;
   lprint_newline ()
 
@@ -867,6 +885,9 @@ let _ =
       ) files_by_num;
       Printf.bprintf buf "  files: %d\n" !counter;
       Printf.bprintf buf "  files_ops: %d\n" (List.length !files_ops);
+      let counter = ref 0 in
+      HashMagic.iter (fun _ -> incr counter) files_magic;
+      Printf.bprintf buf "  files_magic: %d\n" !counter;
   )
 
 
@@ -890,7 +911,7 @@ let file_write file offset s pos len =
 let file_verify file key begin_pos end_pos =
   Unix32.flush_fd (file_fd file);
   if !verbose_md4 then begin
-      lprintf_nl () "Checksum to compute: %Ld-%Ld of %s" begin_pos end_pos
+      lprintf_nl "Checksum to compute: %Ld-%Ld of %s" begin_pos end_pos
         (file_disk_name file);
     end;
   try
@@ -912,7 +933,7 @@ let file_verify file key begin_pos end_pos =
     in
     let result = computed = key in
     if !verbose_md4 then begin
-        lprintf_nl () "Checksum computed: %s against %s = %s"
+        lprintf_nl "Checksum computed: %s against %s = %s"
           (string_of_uid key) 
         (string_of_uid computed)
         (if result then "VERIFIED" else "CORRUPTED");
@@ -920,7 +941,7 @@ let file_verify file key begin_pos end_pos =
     result
   with
     | Not_found -> raise Not_found
-    | e -> lprintf_nl () "Checksum computation failed: Exception: %s" (Printexc2.to_string e);
+    | e -> lprintf_nl "Checksum computation failed: Exception: %s" (Printexc2.to_string e);
     false
 
 let file_mtime file = Unix32.mtime64 (file_fd file)
