@@ -110,11 +110,12 @@ let shorten str limit =
   (* TODO: we schould change all strings to utf8 when
      they come into the core instead. *)
   let name = Charset.to_utf8 (* String.escaped *) str in
-  let len = String.length name in
+  let len = Charset.utf8_length str in
+  let diff_len_utf8_ascii = (String.length str) - len in
   let max_len = maxi limit 10 in
   if len > max_len then
-    let prefix = String.sub name 0 (max_len -7) in
-    let suffix = String.sub name (len-4) 4 in
+    let prefix = String.sub name 0 (max_len - 7 + diff_len_utf8_ascii) in
+    let suffix = String.sub name (len - 4 + diff_len_utf8_ascii) 4 in
     Printf.sprintf "%s...%s" prefix suffix
   else name
 
@@ -459,9 +460,9 @@ let chat_message_fifo = (Fifo.create () : (int * string * int * string * string)
 let log_chat_message i num n s =
   Fifo.put chat_message_fifo (last_time(),i,num,n,s);
   try
-    let oc = open_out_gen [Open_creat; Open_wronly; Open_append] 0o600 !messages_log in
-    Printf.fprintf oc "%s: %s (%s): %s\n" (Date.simple (BasicSocket.date_of_int (last_time ()))) n i s;
-    close_out oc;
+    Unix2.tryopen_write_gen !messages_log [Open_creat; Open_wronly; Open_append] 
+      0o600 (fun oc ->
+	Printf.fprintf oc "%s: %s (%s): %s\n" (Date.simple (BasicSocket.date_of_int (last_time ()))) n i s)
   with e ->
     lprintf_nl "[ERROR] Exception %s while trying to log message to %s"
       (Printexc2.to_string e) !messages_log;
@@ -476,7 +477,7 @@ let last_message_log = ref 0
 let debug_clients = ref Intset.empty
 
 let default_user = {
-    ui_user_name = "admin";
+    ui_user_name = CommonUserDb.admin_user;
     ui_user_searches = [];
     ui_last_search = None;
     ui_last_results = [];
@@ -503,14 +504,6 @@ let find_ui_user user =
   in
   iter !ui_users
 
-
-let valid_password user pass =
-  let pass = Md4.Md4.string pass in
-  try
-    let password = List.assoc user !!users in
-    password = pass
-  with _ -> false
-
 (* control_: means that it is the limited bandwidth, not the unlimited one
   used by the interfaces. tcp_: the full bandwidth (limited+unlimited) *)
 
@@ -873,3 +866,10 @@ let _ =
       activity := new_activity ()
   )
 
+module HashMagic = Weak.Make(struct
+        type t = string
+        let hash s = Hashtbl.hash s
+        let equal x y = x = y
+      end)
+
+let files_magic = HashMagic.create 100
