@@ -102,9 +102,10 @@ in this directory. Please shut it down before starting
 a new instance here. If you are sure no other process uses
 this directory delete %s and restart the core.\n" file
 
-let exit_message_dev file = Printf.sprintf
-"\n/dev/%s does not exist, please create it, exiting...
-If you are using a chroot environment, create it inside the chroot.\n" file
+let exit_message_dev file exit = Printf.sprintf
+"\n/dev/%s does not exist, please create it%s
+If you are using a chroot environment, create it inside the chroot.\n"
+  file (if exit then ", exiting..." else "")
 
 let _ =
   lprintf_nl "Starting MLDonkey %s ... " Autoconf.current_version;
@@ -152,17 +153,20 @@ let _ =
     end;
 
   if (String2.starts_with (Filename.basename Sys.argv.(0)) "mlnet")
-    && not Autoconf.windows && not (Autoconf.system = "morphos") &&
-       Autoconf.donkey_sui = "yes" && not (Sys.file_exists "/dev/urandom") then begin
-      lprintf "%s" (exit_message_dev "urandom");
+    && not Autoconf.windows && not (Autoconf.system = "morphos")
+    && Autoconf.donkey_sui = "yes" && not (Sys.file_exists "/dev/urandom") then
+    begin
+      Autoconf.donkey_sui_urandom := false;
+      lprintf "%s" (exit_message_dev "urandom" false);
       if Autoconf.system = "hpux" then
         lprintf_nl "For HP-UX get urandom support from http://www.josvisser.nl/hpux11-random";
-      exit 2
-    end;  
+    end
+  else
+    Autoconf.donkey_sui_urandom := true;
 
   if (String2.starts_with (Filename.basename Sys.argv.(0)) "mlnet")
     && not Autoconf.windows && not (Sys.file_exists "/dev/null") then begin
-      lprintf "%s" (exit_message_dev "null");
+      lprintf "%s" (exit_message_dev "null" true);
       exit 2
     end;  
 
@@ -177,24 +181,22 @@ let _ =
       then begin
         if Sys.file_exists pid_filename then
           lprintf_nl "PID file %s exists."
-	    (Filename.concat file_basedir pid_filename)
-	else
-	  if Sys.file_exists config_space then begin
+      (Filename.concat file_basedir pid_filename)
+  else
+    if Sys.file_exists config_space then begin
             lprintf_nl "%s exists." (Filename.concat file_basedir config_space);
-	    lprintf "%s" (exit_message config_space);
-	    if Autoconf.windows then
-	      begin
-	        lprintf_nl "waiting 10 seconds to exit...";
-		Unix.sleep 10
-	      end;
-	    exit 2
-	    end;
+      lprintf "%s" (exit_message config_space);
+      if Autoconf.windows then
+        begin
+          lprintf_nl "waiting 10 seconds to exit...";
+    Unix.sleep 10
+        end;
+      exit 2
+      end;
         let pid =
           try
-            let pid_ci = open_in pid_filename in
-            let pid = int_of_string (input_line pid_ci) in
-            close_in pid_ci;
-            pid
+      Unix2.tryopen_read pid_filename (fun pid_ci ->
+              int_of_string (input_line pid_ci))
           with _ ->
             lprintf_nl "But it couldn't be read to check if the process still exists.";
             lprintf_nl "To avoid doing any harm, MLDonkey will now stop.";
@@ -202,23 +204,23 @@ let _ =
         in
           try
             Unix.kill pid 0;
-	    lprintf "%s" (exit_message pid_filename);
+      lprintf "%s" (exit_message pid_filename);
             exit 2
           with
             (* stalled pid file, disregard it *)
             | Unix.Unix_error (Unix.ESRCH, _, _) ->
-	       (lprintf_nl "Removing stalled file %s " pid_filename;
-	       try Sys.remove pid_filename with _ -> ())
-	    | e -> 
-	      lprintf "%s" (exit_message pid_filename);
-	      if Autoconf.system = "mingw" then lprintf_nl
-	        "can not check for stalled pid file because Unix.kill is not implemented on MinGW";
-	      lprintf_nl "Exception %s, exiting..." (Printexc2.to_string e);
-	      if Autoconf.system = "mingw" then begin
-	        lprintf_nl "waiting 10 seconds to exit...";
-		Unix.sleep 10;
-	      end;
-	      exit 2
+         (lprintf_nl "Removing stalled file %s " pid_filename;
+         try Sys.remove pid_filename with _ -> ())
+      | e -> 
+        lprintf "%s" (exit_message pid_filename);
+        if Autoconf.system = "mingw" then lprintf_nl
+          "can not check for stalled pid file because Unix.kill is not implemented on MinGW";
+        lprintf_nl "Exception %s, exiting..." (Printexc2.to_string e);
+        if Autoconf.system = "mingw" then begin
+          lprintf_nl "waiting 10 seconds to exit...";
+    Unix.sleep 10;
+        end;
+        exit 2
       end;
 
   let filename =
@@ -257,32 +259,17 @@ let searches_ini = create_options_file "searches.ini"
 let results_ini = create_options_file "results.ini"
 let files_ini = create_options_file "files.ini"
 let friends_ini = create_options_file "friends.ini"
-let users_ini = create_options_file "users.ini"
 
 let messages_log = ref "messages.log"
 
 let servers_section = file_section servers_ini [] ""
 
-let users_section = file_section users_ini ["Users"] "User accounts on the core"
-
-let empty_password = Md4.string ""
-
-let users = define_option users_section ["users"]
-  "The users that are defined on this core. The default user is
-called 'admin', and uses an empty password. To create new users,
-login as admin in mldonkey, and use the 'add_user' command."
-    (list_option (tuple2_option (string_option, Md4.option)))
-    [ "admin", empty_password ]
-
-let empty_password user =
-  try
-    (List.assoc user !!users) = empty_password
-  with _ -> false
-
 let ip_list_option = list_option Ip.option
 
 let int_list_option = list_option int_option
 
+let country_list_option = list_option string_option
+
 let allow_browse_share_option = define_option_class "Integer"
     (fun v ->
       match v with
@@ -318,7 +305,10 @@ let _ =
   (fun s ->
       let list = String2.tokens s in
       List.map (fun i -> int_of_string i) list
-  )
+  );
+  Options.set_string_wrappers country_list_option
+  (String.concat " ")
+  String2.tokens
 
 let is_not_spam = ref (fun _ -> true)
 
@@ -828,6 +818,15 @@ let force_client_ip = define_option current_section ["force_client_ip"]
     ourself. Don't set this option to true if you have dynamic IP."
     bool_option false
 
+let user_agent = define_option current_section ["user_agent"]
+    "User agent string (default = \"default\")"
+    string_option "default"
+
+let get_user_agent () = 
+  if !!user_agent = "default" then
+     Printf.sprintf "MLDonkey/%s" Autoconf.current_version
+  else !!user_agent
+
 let web_infos = define_option current_section ["web_infos"]
     "A list of lines to download on the WEB: each line has
     the format: (kind, period, url), where kind is either
@@ -837,14 +836,15 @@ let web_infos = define_option current_section ["web_infos"]
     'guarding.p2p' for a blocklist file (also in gz/bz2/zip format), or
     'ocl' for file in the ocl format containing overnet peers, or
     'contact.dat' for an contact.dat file containing overnet peers,
+    'nodes.gzip' for a fasttrack nodes.gzip,
     and period is the period between updates (in hours),
     a period of zero means the file is only loaded once on startup,
     and url is the url of the file to download.
     IMPORTANT: Put the URL and the kind between quotes.
     EXAMPLE:
  web_infos = [
-  (\"server.met\", 0, \"http://www.gruk.org/server.met.gz\");
-  (\"guarding.p2p\", 96, \"http://www.bluetack.co.uk/config/antip2p.txt\");
+  (\"server.met\", 0, \"http://www.jd2k.com/server.met\");
+  (\"guarding.p2p\", 96, \"http://www.bluetack.co.uk/config/level1.gz\");
   (\"ocl\", 24, \"http://members.lycos.co.uk/appbyhp2/FlockHelpApp/contact-files/contact.ocl\");
   (\"contact.dat\", 168, \"http://download.overnet.org/contact.dat\");
  ]
@@ -853,27 +853,45 @@ let web_infos = define_option current_section ["web_infos"]
       tuple3_option (string_option, int_option, string_option)))
   [
     ("guarding.p2p", 96,
-      "http://www.bluetack.co.uk/config/antip2p.txt");
+      "http://www.bluetack.co.uk/config/level1.gz");
     ("server.met", 0,
-      "http://www.gruk.org/server.met.gz");
+      "http://www.jd2k.com/server.met");
     ("contact.dat", 168,
       "http://download.overnet.org/contact.dat");
     ("geoip.dat", 0,
       "http://www.maxmind.com/download/geoip/database/GeoIP.dat.gz");
+    ("nodes.gzip", 0,
+      "http://update.kceasy.com/update/fasttrack/nodes.gzip");
+(*
+    ("slsk_boot", 0,
+      "http://www.slsknet.org/slskinfo2");
+*)
   ]
 
 let rss_feeds = define_expert_option current_section ["rss_feeds"]
     "URLs of RSS feeds"
     (list_option Url.option) []
 
-let ip_blocking_descriptions =
-  define_expert_option current_section ["ip_blocking_descriptions"] "Keep IP blocking ranges descriptions in memory" bool_option true
+let ip_blocking_descriptions = define_expert_option current_section ["ip_blocking_descriptions"]
+    "Keep IP blocking ranges descriptions in memory"
+    bool_option false
 
 let ip_blocking = define_expert_option current_section ["ip_blocking"]
     "IP blocking list filename (peerguardian format), can also be in gz/bz2/zip format
   Zip files must contain either a file named guarding.p2p or guarding_full.p2p."
     string_option ""
 
+let ip_blocking_countries = define_expert_option current_section ["ip_blocking_countries"]
+    "List of countries to block connections from/to (requires Geoip).
+  Names are in ISO 3166 format, see http://www.maxmind.com/app/iso3166
+  You can also at your own risk use \"Unknown\" for IPs Geoip won't recognize."
+    country_list_option []
+
+let ip_blocking_countries_block = define_expert_option current_section
+   ["ip_blocking_countries_block"]
+    "false: use ip_blocking_countries as block list, all other countries are allowed
+  true: use ip_blocking_countries as allow list, all other countries are blocked" bool_option false
+
 let geoip_dat = define_expert_option current_section ["geoip_dat"]
     "Location of GeoIP.dat (Get one from http://www.maxmind.com/download/geoip/database/)"
     string_option ""
@@ -881,11 +899,6 @@ let geoip_dat = define_expert_option current_section ["geoip_dat"]
 let _ =
   option_hook ip_blocking_descriptions (fun _ ->
     Ip_set.store_blocking_descriptions := !!ip_blocking_descriptions
-  );
-  option_hook geoip_dat (fun _ ->
-    try
-      Geoip.init (Geoip.unpack !!geoip_dat);
-    with _ -> ()
   )
 
 let tcpip_packet_size = define_expert_option current_section ["tcpip_packet_size"]
@@ -912,6 +925,14 @@ let socket_keepalive = define_expert_option current_section ["socket_keepalive"]
   This implies some bandwidth-cost (with 200 connections ~10-20%)"
     bool_option !BasicSocket.socket_keepalive
 
+let referers = define_option current_section ["referers"]
+    "Cookies send with a http request (used for .torrent files and web_infos)"
+    (list_option (tuple2_option (string_option, string_option))) [(".*suprnova.*", "http://www.suprnova.org/")]
+
+let cookies = define_option current_section ["cookies"]
+    "Cookies send with a http request (used for .torrent files and web_infos)"
+    (list_option (tuple2_option (string_option, list_option (tuple2_option (string_option, string_option))))) []
+
 let http_proxy_server = define_option current_section ["http_proxy_server"]
     "Direct HTTP queries to HTTP proxy" string_option ""
 let http_proxy_port = define_option current_section ["http_proxy_port"]
@@ -970,6 +991,11 @@ let auto_commit = define_option current_section
   "Set to false if you don't want mldonkey to automatically put completed files in incoming directory"
     bool_option true
 
+let pause_new_downloads = define_option current_section
+    ["pause_new_downloads"]
+    "Set to true if you want all new downloads be paused immediatly, will be set to false on core start."
+    bool_option false
+
   (*
 let commit_unverified_files = define_option current_section
     ["commit_unverified_files"]
@@ -1093,6 +1119,26 @@ let create_file_sparse = define_option current_section ["create_file_sparse"]
     "Create new files as sparse, only valid on MinGW for files on NTFS drives"
     bool_option true
 
+let hdd_temp_minfree = define_option current_section ["hdd_temp_minfree"]
+    "Mininum free space in MB on temp_directory, minimum 50" int_option 50
+
+let hdd_temp_stop_core = define_option current_section ["hdd_temp_stop_core"]
+    "If true core shuts down when free space on temp dir is below hdd_temp_minfree,
+    otherwise all downloads are paused and a warning email is sent."
+    bool_option false
+
+let hdd_coredir_minfree = define_option current_section ["hdd_coredir_minfree"]
+    "Mininum free space in MB on core directory, minimum 20" int_option 50
+
+let hdd_coredir_stop_core = define_option current_section ["hdd_coredir_stop_core"]
+    "If true core shuts down when free space on core dir is below hdd_coredir_minfree,
+    otherwise all downloads are paused and a warning email is sent."
+    bool_option true
+
+let hdd_send_warning_interval = define_option current_section ["hdd_send_warning_interval"]
+    "Send a warning mail each <interval> hours for each directory, 0 to deactivate mail warnings."
+    int_option 1
+
 let previewer = define_expert_option current_section ["previewer"]
   "Name of program used for preview (first arg is local filename, second arg
     is name of file as searched on eDonkey" string_option
@@ -1467,7 +1513,7 @@ let max_displayed_results = define_expert_option current_section
 
 let options_version = define_expert_option current_section ["options_version"]
     "(internal option)"
-    int_option 9
+    int_option 13
 
 
 (*************************************************************************)
@@ -1591,18 +1637,18 @@ let _ =
   option_hook log_file (fun _ ->
       if !!log_file <> "" then
         try
-	  if Sys.file_exists !!log_file then
-	    if (Unix32.getsize !!log_file)
-	     > (Int64ops.megabytes !!log_file_size) then begin
-	      Sys.remove !!log_file;
+    if Unix32.file_exists !!log_file then
+      if (Unix32.getsize !!log_file)
+       > (Int64ops.megabytes !!log_file_size) then begin
+        Sys.remove !!log_file;
               lprintf_nl "Logfile %s reset: bigger than %d MB" !!log_file !!log_file_size
-	    end;
+      end;
           let oc = open_out_gen [Open_creat; Open_wronly; Open_append] 0o644 !!log_file in
           lprintf_to_file := true;
           if Autoconf.system = "cygwin" then lprintf "%s" win_message;
           lprintf_nl "Logging in %s" ( Filename.concat file_basedir !!log_file);
           log_to_file oc;
-	  lprintf_nl "Started logging..."
+    lprintf_nl "Started logging..."
         with e ->
             lprintf_nl "Exception %s while opening log file: %s"
               (Printexc2.to_string e) !!log_file
@@ -1620,6 +1666,12 @@ let _ =
   option_hook log_size (fun _ ->
       lprintf_max_size := !!log_size
   );
+  option_hook hdd_temp_minfree (fun _ ->
+      if !!hdd_temp_minfree < 50 then
+        hdd_temp_minfree =:= 50);
+  option_hook hdd_coredir_minfree (fun _ ->
+      if !!hdd_coredir_minfree < 20 then
+        hdd_coredir_minfree =:= 20);
   option_hook compaction_overhead (fun _ ->
       let gc_control = Gc.get () in
       Gc.set { gc_control with Gc.max_overhead = !!compaction_overhead };
@@ -1779,26 +1831,26 @@ let quote_unquote_bars m =
       Buffer.contents result
     else match m.[i] with
       | '|' -> 
-	  Buffer.add_string result "\\|";
-	  aux (i+1)
+    Buffer.add_string result "\\|";
+    aux (i+1)
       | '\\' -> 
-	  aux_escaped (i+1)
+    aux_escaped (i+1)
       | _ -> 
-	  Buffer.add_char result m.[i];
-	  aux (i+1)
+    Buffer.add_char result m.[i];
+    aux (i+1)
   and aux_escaped i =
     if i = len then begin
       Buffer.add_char result '\\';
       Buffer.contents result
     end else match m.[i] with
       | '|' -> 
-	  Buffer.add_char result '|';
-	  aux (i+1)
+    Buffer.add_char result '|';
+    aux (i+1)
       | _ ->
-	  Buffer.add_char result '\\';
-	  aux i
+    Buffer.add_char result '\\';
+    aux i
   in aux 0
-	    
+      
 let _ =
   option_hook messages_filter (fun _ ->
       is_not_spam := if !!messages_filter <> "" then
@@ -1832,19 +1884,23 @@ let _ =
   option_hook allow_local_network (fun _ ->
       Ip.allow_local_network := !!allow_local_network)
 
+let web_infos_exists url =
+  List.exists (fun (_, _, weburl) ->
+    weburl = url) !!web_infos
+
+let web_infos_remove outdated_web_infos =
+  web_infos =:=
+  List.fold_left (fun acc owi ->
+    let (kind2, _, url2) = owi in
+    List.filter (fun (_,_,url) -> url <> url2) acc
+  ) !!web_infos outdated_web_infos
+
+let web_infos_add kind period url =
+  let web_info = (kind,period,url) in
+  if web_infos_exists url then web_infos_remove [web_info];
+  web_infos =:=  web_info :: !!web_infos
+
 let rec update_options () =
-  let web_infos_remove outdated_web_infos =
-    let web_infos_filter n =
-      List.filter
-        (fun (kind, _, url) ->
-          let (kind2, _, url2) = (List.nth outdated_web_infos n) in
-          kind <> kind2 && url <> url2
-        ) !!web_infos
-    in
-    for n = 0 to (List.length outdated_web_infos) - 1 do
-      web_infos =:= web_infos_filter n;
-    done;
-  in
   let update v =
       lprintf_nl "Updating options to version %i" v;
       options_version =:= v;
@@ -1891,10 +1947,7 @@ let rec update_options () =
           ("ocl", 24,
             "http://members.lycos.co.uk/appbyhp2/FlockHelpApp/contact-files/contact.ocl");
         ];
-      web_infos =:= !!web_infos @ [
-          ("contact.dat", 168,
-            "http://www.overnet.org/download/contact.dat");
-        ];
+      web_infos_add "contact.dat" 168 "http://www.overnet.org/download/contact.dat";
       update 4
 
   | 4 ->
@@ -1903,10 +1956,7 @@ let rec update_options () =
           ("server.met", 24,
             "http://ocbmaurice.dyndns.org/pl/slist.pl/server.met?download/server-best.met");
         ];
-      web_infos =:= !!web_infos @ [
-          ("server.met", 0,
-            "http://www.gruk.org/server.met.gz");
-        ];
+      web_infos_add "server.met" 0 "http://www.gruk.org/server.met.gz";
       update 5
 
   | 5 ->
@@ -1925,10 +1975,46 @@ let rec update_options () =
       update 8
 
   | 8 ->
-      web_infos =:= !!web_infos @ [
-          ("geoip.dat", 0,
-            "http://www.maxmind.com/download/geoip/database/GeoIP.dat.gz");
-        ];
+      web_infos_add "geoip.dat" 0 "http://www.maxmind.com/download/geoip/database/GeoIP.dat.gz";
       update 9
 
+  | 9 ->
+      if web_infos_exists "http://www.gruk.org/server.met.gz" then
+      begin
+        web_infos_remove
+          [
+      ("server.met", 0, "http://www.gruk.org/server.met.gz")
+          ];
+  web_infos_add "server.met" 0 "http://www.jd2k.com/server.met";
+      end;
+      update 10
+
+  | 10 ->
+      if web_infos_exists "http://www.overnet.org/download/contact.dat" then
+      begin
+        web_infos_remove
+          [
+      ("contact.dat", 672,
+        "http://www.overnet.org/download/contact.dat");
+          ];
+  web_infos_add "contact.dat" 168 "http://download.overnet.org/contact.dat";
+      end;
+      update 11
+
+  | 11 ->
+      if web_infos_exists "http://www.bluetack.co.uk/config/antip2p.txt" then
+      begin
+        web_infos_remove
+          [
+      ("guarding.p2p", 96,
+        "http://www.bluetack.co.uk/config/antip2p.txt");
+          ];
+  web_infos_add "guarding.p2p" 0 "http://www.bluetack.co.uk/config/level1.gz";
+      end;
+      update 12
+
+  | 12 ->
+      web_infos_add "nodes.gzip" 0 "http://update.kceasy.com/update/fasttrack/nodes.gzip";
+      update 13
+
   | _ -> ()
