@@ -25,15 +25,13 @@ open Options
 open CommonUser
 open CommonTypes
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[cSe] "
-    (log_time ()); lprintf_nl2
+let log_prefix = "[cSe]"
 
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[cSe] "
-    (log_time ()); lprintf
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 module G = GuiTypes
 
@@ -66,7 +64,7 @@ and 'a server_ops = {
 let ni n m =
   let s = Printf.sprintf "Server.%s not implemented by %s"
       m n.network_name in
-  lprintf_nl () "%s" s;
+  lprintf_nl "%s" s;
   s
 
 let fni n m =  failwith (ni n m)
@@ -226,36 +224,36 @@ let new_server_ops network =
   s
 
 let check_server_implementations () =
-  lprintf_nl () "----- Methods not implemented for CommonServer ----";
+  lprintf_nl "----- Methods not implemented for CommonServer ----";
   List.iter (fun (c, cc) ->
       let n = c.op_server_network.network_name in
-      lprintf_nl ()"  Network %s" n;
+      lprintf_nl "  Network %s" n;
       if c.op_server_remove == cc.op_server_remove then
-        lprintf_nl () "op_server_remove";
+        lprintf_nl "op_server_remove";
       if c.op_server_to_option == cc.op_server_to_option then
-        lprintf_nl () "op_server_to_option";
+        lprintf_nl "op_server_to_option";
       if c.op_server_info == cc.op_server_info then
-        lprintf_nl () "op_server_info";
+        lprintf_nl "op_server_info";
       if c.op_server_sort == cc.op_server_sort then
-        lprintf_nl () "op_server_sort";
+        lprintf_nl "op_server_sort";
       if c.op_server_connect == cc.op_server_connect then
-        lprintf_nl () "op_server_connect";
+        lprintf_nl "op_server_connect";
       if c.op_server_disconnect == cc.op_server_disconnect then
-        lprintf_nl () "op_server_disconnect";
+        lprintf_nl "op_server_disconnect";
       if c.op_server_find_user == cc.op_server_find_user then
-        lprintf_nl () "op_server_find_user";
+        lprintf_nl "op_server_find_user";
       if c.op_server_query_users == cc.op_server_query_users then
-        lprintf_nl () "op_server_query_users";
+        lprintf_nl "op_server_query_users";
       if c.op_server_users == cc.op_server_users then
-        lprintf_nl () "op_server_users";
+        lprintf_nl "op_server_users";
       if c.op_server_cid == cc.op_server_cid then
-        lprintf_nl () "op_server_cid";
+        lprintf_nl "op_server_cid";
       if c.op_server_low_id == cc.op_server_low_id then
-        lprintf_nl () "op_server_low_id";
+        lprintf_nl "op_server_low_id";
       if c.op_server_rename == cc.op_server_rename then
-        lprintf_nl () "op_server_rename";
+        lprintf_nl "op_server_rename";
       if c.op_server_set_preferred == cc.op_server_set_preferred then
-        lprintf_nl () "op_server_set_preferred";
+        lprintf_nl "op_server_set_preferred";
   ) !servers_ops;
   lprint_newline ()
 
@@ -265,7 +263,7 @@ let server_find (num : int) =
 
 let server_blocked s =
   let info = server_info s in
-    Ip_set.ip_blocked (Ip.ip_of_addr info.G.server_addr)
+  !Ip.banned (Ip.ip_of_addr info.G.server_addr) <> None
 
 let server_connect s =
   if not (server_blocked s) then
@@ -330,14 +328,21 @@ let check_blocked_servers () =
           (match impl.impl_server_state with
              NotConnected _ -> ()
          | _ -> server_disconnect s;
-              lprintf_nl () "Disconnected server %s (%s:%d), IP is now blocked"
+              lprintf_nl "Disconnected server %s (%s:%d), IP is now blocked"
                 info.G.server_name
                 (Ip.string_of_addr info.G.server_addr)
                 info.G.server_port);
       end;
       server_must_update s)
   with e ->
-    lprintf_nl () "Exception in check_blocked_servers: %s" (Printexc2.to_string e)
+    lprintf_nl "Exception in check_blocked_servers: %s" (Printexc2.to_string e)
+
+let server_must_update_all () =
+  try
+    server_iter (fun s ->
+      server_must_update s)
+  with e ->
+    lprintf_nl "Exception in server_must_update_all: %s" (Printexc2.to_string e)
 
 let server_banner s o =
   let buf = o.conn_buf in
@@ -369,10 +374,11 @@ let server_print_html_header buf ext =
 let server_print s o =
   let impl = as_server_impl s in
   let n = impl.impl_server_ops.op_server_network in
+  if network_is_enabled n then
   try
     let info =
       try server_info s with e ->
-          lprintf_nl () "Exception %s in server_info (%s)\n"
+          lprintf_nl "Exception %s in server_info (%s)\n"
             (Printexc2.to_string e) n.network_name;
           raise e in
 
@@ -521,5 +527,5 @@ let server_print s o =
       end;
 
   with e ->
-      lprintf_nl () "Exception %s in CommonServer.server_print"
+      lprintf_nl "Exception %s in CommonServer.server_print"
         (Printexc2.to_string e)
