@@ -41,8 +41,9 @@ let hours = ref 0
 
 let file_kinds = ref []
 
-let add_web_kind kind f =
-  file_kinds := (kind,f) :: !file_kinds
+let add_web_kind kind descr f =
+  let kind_record = { f = f; description = descr } in
+  file_kinds := (kind, kind_record) :: !file_kinds
 
 let mldonkey_wget url f =
   let module H = Http_client in
@@ -50,9 +51,26 @@ let mldonkey_wget url f =
       H.basic_request with
       H.req_url = Url.of_string url;
       H.req_proxy = !CommonOptions.http_proxy;
-      H.req_user_agent =
-      Printf.sprintf "MLDonkey/%s" Autoconf.current_version;
+      H.req_referer = (
+        let (rule_search,rule_value) =
+          try (List.find(fun (rule_search,rule_value) ->
+            Str.string_match (Str.regexp rule_search) url 0
+          ) !!referers )
+          with Not_found -> ("",url) in
+        Some (Url.of_string rule_value) );
+      H.req_headers = (try
+        let cookies = List.assoc url !!cookies in
+          [ ( "Cookie", List.fold_left (fun res (key, value) ->
+              if res = "" then
+                key ^ "=" ^ value
+              else
+                res ^ "; " ^ key ^ "=" ^ value
+          ) "" cookies
+        ) ]
+      with Not_found -> []);
+      H.req_user_agent = get_user_agent ();
       H.req_max_retry = 20;
+      H.req_save = true;
     } in
     let r1 = {
       r with
@@ -108,7 +126,7 @@ let mldonkey_wget url f =
 let load_url can_fail kind url =
   let f =
     try
-      (List.assoc kind !file_kinds) url
+      (List.assoc kind !file_kinds).f url
     with e -> failwith (Printf.sprintf "Unknown kind [%s]" kind)
   in
   try
@@ -124,7 +142,7 @@ let load_url can_fail kind url =
 
 let load_file kind file =
   try
-    (List.assoc kind !file_kinds) file file
+    (List.assoc kind !file_kinds).f file file
   with e ->
       lprintf_nl "[cWeb] Exception %s while loading kind %s"
         (Printexc2.to_string e) kind
@@ -156,7 +174,8 @@ let rss_feeds = Hashtbl.create 10
 
 
 let _ =
-  add_web_kind "rss" (fun url filename ->
+  add_web_kind "rss" "Syndication feeds to get periodically updated data" 
+    (fun url filename ->
       lprintf_nl "[cWeb=rss] parsing feed %s" url;
       let c = Rss.channel_of_file filename in
       (try Sys.remove filename with _ -> ());
