@@ -453,6 +453,7 @@ let get_result proto s pos =
     result_modified = false;
     result_force = false;
     result_time = time;
+    result_source_network = 0;
   }, pos+1
 
 let get_message s pos =
@@ -509,7 +510,7 @@ let get_sub_files s pos =
   get_list (fun s pos ->
     let name, pos = get_string s pos in
     let size, pos = get_int64 s pos, pos+8 in
-    (name, size), pos
+    (name, size, Some ""), pos
   ) s pos
   
 let get_file proto s pos = 
@@ -995,7 +996,7 @@ let from_gui (proto : int array) opcode s =
     | 5
     | 52 ->
         if proto < 14 then
-           let pass,_ = get_string s 2 in Password ("admin", pass)
+           let pass,_ = get_string s 2 in Password (CommonUserDb.admin_user, pass)
         else
         let pass,pos = get_string s 2 in
         let login,pos = get_string s pos in
