@@ -255,7 +255,7 @@ let buf_bool_option buf b =
       
 let buf_result proto buf r =
   buf_int buf r.result_num;
-  buf_int buf 0;
+  buf_int buf r.result_source_network;
   buf_list buf buf_string r.result_names;
   if proto < 27 then
     buf_md4 buf Md4.null
@@ -541,7 +541,7 @@ let buf_file_field proto buf field =
       buf_string buf x
     
 let buf_sub_files buf l =
-  buf_list buf (fun buf (name, size) ->
+  buf_list buf (fun buf (name, size, _) ->
     buf_string buf name;
     buf_int64 buf size
   ) l
@@ -596,10 +596,7 @@ let buf_addr proto buf addr =
   );
   if proto > 33 then begin
     let is_blocked = 
-      try 
-        Ip_set.ip_blocked (Ip.ip_of_addr addr)
-      with _ ->
-        false
+      !Ip.banned (Ip.ip_of_addr addr) <> None
     in
     buf_bool buf is_blocked 
   end
