@@ -35,16 +35,15 @@ open TcpBufferedSocket
 open DriverGraphics
 open DriverInteractive
 open CommonOptions
+open CommonUserDb
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[dCon] "
-    (log_time ()); lprintf_nl2
+let log_prefix = "[dCon]"
 
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[dCon] "
-    (log_time ()); lprintf
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 let rec dollar_escape o with_frames s =
   String2.convert false (fun b escaped c ->
@@ -310,12 +309,13 @@ Use '$rhelp command$n' or '$r? command$n' for help on a command.
         let user, pass =
           match args with
             [] -> failwith "Usage: auth <user> <password>"
-          | [s1] -> "admin", s1
+          | [s1] -> admin_user, s1
           | user :: pass :: _ -> user, pass
         in
         if valid_password user pass then begin
             auth := true;
             o.conn_user <- find_ui_user user;
+            lprintf_nl "Authenticated user: %s" user;
             let module M = CommonMessages in
             Buffer.add_string buf M.full_access
           end else
@@ -348,9 +348,9 @@ let check_calendar () =
   List.iter (fun (days, hours, command) ->
       if (List.mem tm.Unix.tm_wday days || days = []) &&
         (List.mem tm.Unix.tm_hour hours || hours = []) then begin
-          lprintf_nl () "Calendar execute: %s" command;
+          lprintf_nl "Calendar execute: %s" command;
           eval (ref true) command calendar_options;
-          lprintf_nl () "Calendar result: %s" (Buffer.contents calendar_options.conn_buf);
+          lprintf_nl "Calendar result: %s" (Buffer.contents calendar_options.conn_buf);
           Buffer.reset calendar_options.conn_buf;
         end
   ) !!calendar
@@ -571,12 +571,13 @@ let telnet_handler t event =
   match event with
     TcpServerSocket.CONNECTION (s, Unix.ADDR_INET (from_ip, from_port)) ->
       let from_ip = Ip.of_inet_addr from_ip in
+        lprintf_nl "Telnet connection from %s" (Ip.to_string from_ip);
         let token = create_token unlimited_connection_manager in
         let sock = TcpBufferedSocket.create_simple token
           "telnet connection"
           s in
         let telnet = {
-            telnet_auth = ref (empty_password "admin");
+            telnet_auth = ref (empty_password admin_user);
             telnet_iac = false;
             telnet_wait = 0;
             telnet_buffer = Buffer.create 100;
@@ -617,7 +618,7 @@ let telnet_handler t event =
 	in
 	TcpBufferedSocket.write_string sock (dollar_escape o false reject_message);
 	shutdown sock Closed_connect_failed;
-	lprintf_n () "%s" reject_message;
+  lprintf_n "%s" reject_message;
 	Unix.close s
       end
 
@@ -693,7 +694,7 @@ let chat_handler t event =
            Unix.close s
      with
        Failure mess ->
-         lprintf_nl () "%s" mess;
+         lprintf_nl "%s" mess;
          Unix.close s
     )
   | _ ->
@@ -840,12 +841,12 @@ let theme_page_exists page =
 
 (* if files are small really_input should be okay *)
 let read_theme_page page =
-        let theme_page = get_theme_page page in
-        let file = open_in theme_page in
-        let size = (Unix.stat theme_page).Unix.st_size in
-        let s = String.make size ' ' in
-        let _ = really_input file s 0 size in
-        close_in file; s
+  let theme_page = get_theme_page page in
+  Unix2.tryopen_read theme_page (fun file ->
+    let size = (Unix.stat theme_page).Unix.st_size in
+    let s = String.make size ' ' in
+    really_input file s 0 size;
+    s)
 
 let add_simple_commands buf =
   let this_page = "commands.html" in
@@ -904,7 +905,7 @@ let http_send_bin r buf filename =
   let ext_pos = (String.rindex filename '.') + 1 in
   let exten = (String.sub filename ext_pos ((String.length filename) - ext_pos)) in
   if !verbose_msg_servers then
-    lprintf_nl () "Extension found [%s] for file: [%s]" exten filename;
+    lprintf_nl "Extension found [%s] for file: [%s]" exten filename;
   let ext = extension_to_file_ext exten in
   http_add_bin_header r ext clen;
   Buffer.add_string buf file_to_send
@@ -914,15 +915,15 @@ let http_error_no_gd img_type =
     "jpg" ->
       (match Autoconf.has_gd_jpg with
         true -> false
-      | false -> lprintf_nl () "Warning: GD jpg support disabled"; true)
+      | false -> lprintf_nl "Warning: GD jpg support disabled"; true)
   | "png" ->
       (match Autoconf.has_gd_png with
         true -> false
-      | false -> lprintf_nl () "Warning: GD png support disabled"; true)
+      | false -> lprintf_nl "Warning: GD png support disabled"; true)
   | _ ->
       (match Autoconf.has_gd with
         true -> false
-      | false -> lprintf_nl () "Warning: GD support disabled"; true)
+      | false -> lprintf_nl "Warning: GD support disabled"; true)
 let any_ip = Ip.of_inet_addr Unix.inet_addr_any
 
 let html_open_page buf t r open_body =
@@ -1021,7 +1022,7 @@ let http_handler o t r =
   CommonInteractive.display_bw_stats := false;
   clear_page buf;
 
-  let user = if r.options.login = "" then "admin" else r.options.login in
+  let user = if r.options.login = "" then admin_user else r.options.login in
   if not (valid_password user r.options.passwd) then begin
       clear_page buf;
       need_auth r !!http_realm
@@ -1103,6 +1104,14 @@ let http_handler o t r =
                 read_theme_page this_page else
               if !!html_mods then !!CommonMessages.web_common_header_mods0
               else !!CommonMessages.web_common_header_old)
+        | "multidllink.html" ->
+            html_open_page buf t r true;
+            let this_page = "multidllink.html" in
+            Buffer.add_string buf (
+              if !!html_mods_theme != "" && theme_page_exists this_page then
+                read_theme_page this_page else
+              if !!html_mods then !!CommonMessages.multidllink_mods0
+              else !!CommonMessages.multidllink_old)
         | "" | "index.html" ->
             if !!use_html_frames then begin
                 html_open_page buf t r false;
@@ -1255,7 +1264,7 @@ let http_handler o t r =
 
         | "favicon.ico" ->
             if !verbose_msg_servers then
-              lprintf_nl () "favicon.ico request received by tracker";
+              lprintf_nl "favicon.ico request received by tracker";
             http_send_bin r buf "favicon.ico"
 
         | "filter" ->
@@ -1382,7 +1391,18 @@ let http_handler o t r =
 
         | "submit" ->
             begin
+
               match r.get_url.Url.args with
+                | [ "jvcmd", "multidllink" ; "links", links] ->
+                    html_open_page buf t r true;
+                    List.iter (fun url ->
+		      if url <> "\013" && url <> "" then
+		        begin
+                          Buffer.add_string buf (html_escaped (dllink_parse (o.conn_output = HTML) url));
+                          Buffer.add_string buf (html_escaped "\\<P\\>")
+			end
+                    ) (String2.split links '\n')
+
               | ("q", cmd) :: other_args ->
                   List.iter (fun arg ->
                       match arg with
@@ -1417,9 +1437,9 @@ let http_handler o t r =
                     | "downloaders" | "uploaders" | "scan_temp" | "cs"
                     | "version" | "rename" | "force_download" | "close_fds"
                     | "vd" | "vo" | "voo" | "upstats" | "shares" | "share"
-                    | "unshare" | "stats" | "users" -> drop_pre := true;
+                    | "unshare" | "stats" | "users" | "block_list" -> 
+			drop_pre := true;
                     | _ -> ());
-
                   Printf.bprintf buf "%s\n"
                     (if use_html_mods o && !drop_pre then s else "\n<pre>\n" ^ s ^ "</pre>");
 
@@ -1443,7 +1463,7 @@ let http_handler o t r =
 
               | args ->
                   List.iter (fun (s,v) ->
-                      lprintf_nl () "[%s]=[%s]" (String.escaped s) (String.escaped v))
+                      lprintf_nl "[%s]=[%s]" (String.escaped s) (String.escaped v))
                   args;
                   raise Not_found
             end
@@ -1463,7 +1483,7 @@ let http_handler o t r =
 
               | args ->
                   List.iter (fun (s,v) ->
-                      lprintf_nl () "[%s]=[%s]" (String.escaped s) (String.escaped v))
+                      lprintf_nl "[%s]=[%s]" (String.escaped s) (String.escaped v))
                   args;
                   raise Not_found
             end
@@ -1481,7 +1501,7 @@ let http_handler o t r =
 		  let exten = Filename2.last_extension impl.impl_shared_codedname in
 		  if not (Sys.file_exists filename) then
 		    begin
-		      lprintf_nl () "file %s not found" filename;
+          lprintf_nl "file %s not found" filename;
 		      raise Not_found
 		    end;
 		  let fd = Unix32.create_ro filename in
@@ -1490,7 +1510,7 @@ let http_handler o t r =
 
               | args ->
                   List.iter (fun (s,v) ->
-                      lprintf_nl () "[%s]=[%s]" (String.escaped s) (String.escaped v))
+                      lprintf_nl "[%s]=[%s]" (String.escaped s) (String.escaped v))
                   args;
                   raise Not_found
             end
