@@ -34,40 +34,34 @@ open TcpBufferedSocket
 open CommonTypes
 open CommonGlobals
 open CommonOptions
+open CommonUserDb
 open CommonTypes
 open Int64ops
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s"
-    (log_time ()); lprintf_nl2
+let log_prefix = "[dIve]"
 
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s"
-    (log_time ()); lprintf
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 let verify_user_admin () =
-  let warning =
-    "SECURITY WARNING: user admin has an empty password, use command: add_user admin password\n"
-  in
-  let found = ref false in
-  let empty_password = ref false in
-  List.iter (fun (user,pass) ->
-    if user = "admin" then begin
-      found := true;
-      if pass = Md4.string "" then
-        empty_password := true
-    end
-  ) !!users;
-  if not !found then begin
-    lprintf_nl () "SECURITY INFO: user 'admin' has to be present, creating...";
-    users =:= ("admin", Md4.string "") :: !!users;
-    empty_password := true
+  let empty_pwd = ref false in
+  begin try
+    if user2_password admin_user = blank_password then
+      empty_pwd := true
+    with e ->
+      lprintf_nl "SECURITY INFO: user 'admin' has to be present, creating...";
+      empty_pwd := true;
+      ignore (user2_add admin_user blank_password "")
   end;
-  if !empty_password && not !!enable_user_config then
+  let warning =
+    "SECURITY WARNING: user admin has an empty password, use command: useradd admin password\n"
+  in
+  if !empty_pwd && not !!enable_user_config then
     begin
-      lprintf_n () "%s" warning;
+      lprintf_n "%s" warning;
       warning
     end
   else ""
@@ -76,7 +70,7 @@ let check_supported_os () =
   let uname = Unix32.uname () in
   let message = Printf.sprintf "MLDonkey is not able to run faultless under %s" uname; in
   if uname <> "" && not (Unix32.os_supported ()) then begin
-    lprintf_nl () "%s" message;
+    lprintf_nl "%s" message;
     message;
   end
   else ""
@@ -86,7 +80,66 @@ let dns_works = ref false
 let real_startup_message () =
   !startup_message ^ (verify_user_admin ()) ^ (check_supported_os ()) 
   ^ (if not !dns_works then "DNS resolution does not work" else "")
-      
+
+let hdd_check () =
+  let dir_full dir mb =
+    match Unix32.diskfree dir with
+    | None -> false
+    | Some v -> v < megabytes mb
+  in
+
+  if dir_full !!temp_directory !!hdd_temp_minfree then
+    if !!hdd_temp_stop_core then begin
+      send_dirfull_warning !!temp_directory "MLDonkey temp directory partition full, shutting down...";
+      CommonInteractive.clean_exit 0
+      end
+    else begin
+      send_dirfull_warning !!temp_directory "MLDonkey queues all downloads";
+      all_temp_queued := true
+    end
+  else
+    begin
+      all_temp_queued := false;
+      try Hashtbl.remove last_sent_dir_warning !!temp_directory with _ -> ()
+    end;
+
+  let core_dir = Sys.getcwd () in
+  if dir_full core_dir !!hdd_coredir_minfree then
+    if !!hdd_coredir_stop_core then begin
+      send_dirfull_warning core_dir "MLDonkey base directory partition full, shutting down...";
+      CommonInteractive.clean_exit 0
+      end
+    else
+      begin
+        send_dirfull_warning core_dir "MLDonkey base directory partition full, stop saving ini files...";
+        allow_saving_ini_files := false
+      end
+  else
+    allow_saving_ini_files := true;
+
+  let log_dir = Filename.dirname !!log_file in
+  if dir_full log_dir !!hdd_coredir_minfree then begin
+    send_dirfull_warning log_dir "MLDonkey logdirectory partition full, redirect log to RAM...";
+    close_log ()
+  end
+
+let file_magic_check () =
+  if !Autoconf.magic_works then begin
+    if !verbose then lprintf_nl "computing file magic values";
+    let check_magic file =
+      match Magic.M.magic_fileinfo (file_disk_name file) false with
+        None -> ()
+      | Some magic -> set_file_magic file (Some magic)
+    in
+    List.iter (fun file ->
+      let magic = file_magic file in
+      match magic with
+        None -> check_magic file
+      | Some magic when magic = "data" -> check_magic file
+      | _ -> ()
+    ) !!files
+  end
+
 (* ripped from gui_downloads *)
 
 let calc_file_eta f =
@@ -232,6 +285,7 @@ let save_config () =
         Printf2.lprintf "Exception %s while flushing\n" (Printexc2.to_string e)
   );
   if !initialization_completed then (
+    if !allow_saving_ini_files then begin
       Options.save_with_help downloads_ini;
       Options.save_with_help_private users_ini;
       CommonComplexOptions.save ();
@@ -240,6 +294,7 @@ let save_config () =
           List.iter (fun opfile ->
               Options.save_with_help opfile
           ) r.network_config_file);
+    end
     ) else (
       Printf2.lprintf "Initialization not completed, bypassing state saving\n"
     );
@@ -266,7 +321,7 @@ type table_align =
 
 let col_sep = " "
 let add buf s align max_len =
-  let slen = String.length s in
+  let slen = Charset.utf8_length s in
   let diff = max_len - slen in
   match align with
     Align_Center ->
@@ -290,7 +345,7 @@ let print_table_text buf alignments titles lines =
   List.iter (fun line ->
       let len = Array.length line in
       for i = 0 to len-1 do
-        let slen = String.length line.(i) in
+        let slen = Charset.utf8_length line.(i) in
         if cols.(i) <  slen then cols.(i) <- slen
       done;
   ) (titles :: lines);
@@ -629,8 +684,11 @@ let ctd fn td = Printf.sprintf "\\<td onClick=\\\"location.href='submit?q=vd+%d'
         [|
           (if !!html_mods_use_js_tooltips then
                         Printf.sprintf "
-                                onMouseOver=\\\"mOvr(this);setTimeout('popLayer(\\\\\'%s<br>File#: %d<br>Network: %s\\\\\')',%d);setTimeout('hideLayer()',%d);return true;\\\" onMouseOut=\\\"mOut(this);hideLayer();setTimeout('hideLayer()',%d)\\\"\\>"
+                                onMouseOver=\\\"mOvr(this);setTimeout('popLayer(\\\\\'%s<br>%sFile#: %d<br>Network: %s\\\\\')',%d);setTimeout('hideLayer()',%d);return true;\\\" onMouseOut=\\\"mOut(this);hideLayer();setTimeout('hideLayer()',%d)\\\"\\>"
                         (Http_server.html_real_escaped file.file_name)
+			(match file_magic (file_find file.file_num) with
+			   None -> ""
+			 | Some magic -> "File type: " ^ magic ^ "<br>")
 			file.file_num
                         (net_name file)
 			!!html_mods_js_tooltips_wait
@@ -846,7 +904,7 @@ let simple_print_file_list finished buf files format =
             "    %";
             "    Done";
             "    Size";
-            "Avail";
+            "lSeen";
             "Old";
             " Active";
             "Rate";
@@ -892,7 +950,12 @@ let simple_print_file_list finished buf files format =
                 else (Int64.to_string file.file_downloaded) );
               (if !!improved_telnet then (print_human_readable file file.file_size)
                 else (Int64.to_string file.file_size) );
-		(Printf.sprintf "%.0f%%" (get_file_availability file));
+              (Printf.sprintf "%s"
+                (if file.file_last_seen > 0 then
+                   let last = (BasicSocket.last_time ()) - file.file_last_seen in
+                     Date.time_to_string last "long"
+                 else "-"
+                ));
               (Printf.sprintf "%d:%s" (age_to_day file.file_age)
                 (
                   let len = Array.length file.file_chunks_age in
@@ -1069,18 +1132,16 @@ let old_print_search buf o results =
                 end;
 
               user.ui_last_results <- (!counter, rs) :: user.ui_last_results;
-              if use_html_mods o then Printf.bprintf buf "\\<td class=\\\"sr\\\"\\>%s\\</td\\>"
-                  (
-(* TODO RESULT: use the uids to display from which networks it is downloadable
-                  let n = network_find_by_num r.result_network in
-              n.network_name *) "--")
-              else Printf.bprintf  buf "[%5d] %s "
-                  !counter
-
-(* TODO RESULT:
-              (let n = network_find_by_num r.result_network in
-                  n.network_name) *)
-                  "--";
+              let network_name = 
+                try 
+                 let n = network_find_by_num r.result_source_network in
+                 n.network_name 
+                with _ -> "Unknown"
+              in
+              
+                if use_html_mods o 
+                  then Printf.bprintf buf "\\<td class=\\\"sr\\\"\\>%s\\</td\\>" network_name
+                  else Printf.bprintf  buf "[%5d] %s " !counter network_name;
 
               if o.conn_output = HTML then begin
                   if !!html_mods then
@@ -1106,7 +1167,7 @@ let old_print_search buf o results =
                               Buffer.add_string buf ((if !nl then "<br>" else begin nl := true;"" end) ^
                                 escaped_string_of_field t ^ ": " ^ get_tag_value t);
                       ) r.result_tags;
-                    Printf.bprintf buf "\\\\\'),%d');setTimeout('hideLayer()',%d);return true;\\\"  onMouseOut=\\\"hideLayer();setTimeout('hideLayer()',%d);return true;\\\" class=\\\"sr\\\"\\>\\<a href=results\\?d=%d target=\\\"$S\\\"\\>"
+                    Printf.bprintf buf "\\\\\')',%d);setTimeout('hideLayer()',%d);return true;\\\"  onMouseOut=\\\"hideLayer();setTimeout('hideLayer()',%d);return true;\\\" class=\\\"sr\\\"\\>\\<a href=results\\?d=%d target=\\\"$S\\\"\\>"
 			!!html_mods_js_tooltips_wait
 			!!html_mods_js_tooltips_timeout
 			!!html_mods_js_tooltips_wait
@@ -1400,7 +1461,7 @@ let print_results stime buf o results =
   let files = ref [] in
   (try
       List.iter (fun (rs, r,avail) ->
-          if !!display_downloaded_results || not r.result_done  then begin
+          if !!display_downloaded_results || not r.result_done then begin
               incr counter;
               nsources := !nsources + avail;
               totalsize := !totalsize ++ r.result_size ** (Int64.of_int avail);
@@ -1416,7 +1477,6 @@ let print_results stime buf o results =
                       (if new_result then "N" else " ")
                     !counter);
 
-
                 (if use_html_mods o then
                     "\\<td class=\\\"sr ar\\\"\\>" ^  size_of_int64 r.result_size ^ "\\</td\\>"
                   else Int64.to_string r.result_size
@@ -1427,6 +1487,20 @@ let print_results stime buf o results =
                   else (string_of_int avail)
                 );
 
+                (if r.result_done then
+                   begin
+	                if use_html_mods o then
+        	            "\\<td class=\\\"sr ar\\\"\\>D\\</td\\>"
+                	  else "dled"
+                   end
+                 else
+                   begin
+	                if use_html_mods o then
+        	            "\\<td class=\\\"sr ar\\\"\\> \\</td\\>"
+                	  else " "
+                   end
+                );
+
                 (Printf.sprintf "%s%s%s"
                     (if o.conn_output = HTML then begin
                         if !!html_mods then Printf.sprintf "\\<td class=\\\"sr\\\"\\>\\<a href=results\\?d=%d target=\\\"$S\\\"\\>" r.result_num
@@ -1436,8 +1510,6 @@ let print_results stime buf o results =
 
                   ( shorten (
                       let names = r.result_names in
-                      let names = if r.result_done then
-                          ["ALREADY DOWNLOADED "] @ names else names in
                       let names = match  r.result_comment with
                           "" -> names
                         |  comment ->
@@ -1466,7 +1538,6 @@ let print_results stime buf o results =
                   )
                 );
 
-
                 (let buf = Buffer.create 100 in
 
                   if use_html_mods o then Buffer.add_string buf "\\<td class=\\\"sr\\\"\\>";
@@ -1478,7 +1549,7 @@ let print_results stime buf o results =
                             String s -> s
                           | Uint64 i -> Int64.to_string i
                           | Fint64 i -> Int64.to_string i
-                          | _ -> "???"
+                          | _ -> ""
                         ))
                   ) r.result_tags;
                   Buffer.contents buf);
@@ -1501,6 +1572,7 @@ let print_results stime buf o results =
 		( "1", "srh", "Number", "#" ) ;
 		( "1", "srh ar", "Size", "Size" ) ;
 		( "0", "srh ar", "Availability", "A" )  ;
+		( "0", "srh ar", "Status, D = already downloaded", "S" )  ;
 		( "0", "srh", "Filename", "Name" ) ;
 		( "0", "srh", "Tag", "Tag" ) ;
 		( "0", "srh", "MD4", "MD4" ) ];
@@ -1512,11 +1584,12 @@ let print_results stime buf o results =
 
   else
 
-    print_table buf [| Align_Left; Align_Right; Align_Right; Align_Left; Align_Left; Align_Left|]
+    print_table buf [| Align_Left; Align_Right; Align_Right; Align_Right; Align_Left; Align_Left; Align_Left|]
       [|
       "[ Num ]";
       "Size";
       "Avail";
+      "Status";
       "Names";
       "Tags";
       "MD4";
@@ -1539,7 +1612,6 @@ let print_search buf s o =
     ) !results in
 
   Printf.bprintf buf "Result of search %d\n" s.search_num;
-  Printf.bprintf buf "Reinitialising download selectors\n";
   Printf.bprintf buf "%d results (%s)\n" s.search_nresults
     (if s.search_waiting = 0 then "done" else
       (string_of_int s.search_waiting) ^ " waiting");
@@ -1723,6 +1795,14 @@ let buildinfo html buf =
 	  ^ (if Autoconf.has_gd && not Autoconf.has_gd_png && Autoconf.has_gd_jpg then " gd(jpg)" else "")
 	  ^ (if not Autoconf.has_gd then " no-gd" else "")
           ^ (if Autoconf.has_iconv then " iconv" else " no-iconv")
+          ^ (if Autoconf.magic then
+	       begin
+	         if !Autoconf.magic_works then
+		   " magic(active)"
+		 else
+		   " magic(inactive)"
+	       end
+	     else " no-magic")
           ^ (if Autoconf.check_bounds then " check-bounds" else " no-check-bounds")
   )
   in
@@ -1745,7 +1825,7 @@ let runinfo html buf o =
   let s =
   (
         "User:\t\t " ^ ui_user
-      ^   (if List.assoc ui_user !!users = Md4.string "" then " (Warning: empty Password)"
+      ^   (if empty_password ui_user then " (Warning: empty Password)"
            else " (PW Protected)")
       ^	  " - uptime: " ^ Date.time_to_string (last_time () - start_time) "verbose"
       ^ "\nEnabled nets:\t"
@@ -1760,8 +1840,15 @@ let runinfo html buf o =
       ^ "\nServer usage:\t " ^ (if !!enable_servers then "enabled" else "disabled (you are not able to connect to ED2K Servers)")
       ^ "\nGeoip:\t\t " ^ (if !Geoip.active then "enabled, GeoLite data created by MaxMind, available from http://maxmind.com/"
           else dis_mess)
-      ^ "\nIP blocking:\t " ^ (let r1,r2 = Ip_set.block_stats () in
-          if r1 = 0 then dis_mess else Printf.sprintf "enabled, %d ranges loaded - optimized to %d" r1 r2)
+      ^ (Printf.sprintf "\nIP blocking local: %d ranges, web: %d ranges"
+          (Ip_set.bl_length !CommonBlocking.ip_blocking_list)
+          (Ip_set.bl_length !CommonBlocking.web_ip_blocking_list))
+      ^ (if Autoconf.magic then
+           if !Autoconf.magic_works then
+             Printf.sprintf "\nLibmagic:\t file-type recognition database present"
+           else
+             Printf.sprintf "\nLibmagic:\t file-type recognition database not present"
+         else "")
       ^ (if not !dns_works then
 	    Printf.sprintf "\nDNS:\t\t DNS resolution not available, web_infos %s not work"
 	      (if Autoconf.bittorrent = "yes" then "and BT does" else "do")
@@ -1872,3 +1959,108 @@ let diskinfo html buf =
     	) !list;
   if html then
     Printf.bprintf buf "\\</table\\>\\</td\\>\\<tr\\>\\</table\\>\\</div\\>"
+
+let print_option_help o option =
+  let buf = o.conn_buf in
+  let help_text = get_help option in
+  if use_html_mods o then
+    begin
+      Printf.bprintf buf "\\<div class=\\\"cs\\\"\\>";
+      html_mods_table_header buf "versionTable" "results" [];
+      Printf.bprintf buf "\\<tr\\>";
+      html_mods_td buf [ ("", "srh", "Helptext"); ];
+      Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-1\\\"\\>";
+      html_mods_td buf [ ("", "sr", Str.global_replace (Str.regexp "\n") "\\<br\\>" help_text); ];
+      Printf.bprintf buf "\\</tr\\>\\</table\\>\\</div\\>\\</div\\>";
+    end
+  else
+    Printf.bprintf buf "\n\t--Helptext--\n%s\n" help_text
+
+let dllink_print_result html url header results =
+  let buf = Buffer.create 100 in
+  if html then
+    begin
+      Printf.bprintf buf "\\<div class=\\\"cs\\\"\\>";
+      html_mods_table_header buf "dllinkTable" "results" [];
+      Printf.bprintf buf "\\<tr\\>";
+      html_mods_td buf [ ("", "srh", header); ];
+      Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-1\\\"\\>";
+      html_mods_td buf [ ("", "sr", url); ]
+    end
+  else
+    Printf.bprintf buf "%s : %s\n" header url;
+  List.iter (fun s ->
+    if html then
+      begin
+        Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-1\\\"\\>";
+        html_mods_td buf [ ("", "sr", s); ]
+      end
+    else
+      Printf.bprintf buf "%s\n" s) (List.rev results);
+  if html then Printf.bprintf buf "\\</tr\\>\\</table\\>\\</div\\>\\</div\\>";
+  Buffer.contents buf
+
+let dllink_query_networks html url =
+  let result = ref [] in
+  if not (networks_iter_until_true (fun n ->
+    try
+      let s,r = network_parse_url n url in
+        if s = "" then
+          r
+        else
+          let s1 = Printf.sprintf "%s: %s" n.network_name s in
+            result := s1 :: !result;
+            r
+    with e ->
+      let s1 = Printf.sprintf "%s: Exception %s"
+        (n.network_name) (Printexc2.to_string e)
+      in
+        result := s1 :: !result;
+        false
+  )) then
+    dllink_print_result html url "Unable to match URL" !result
+  else
+    dllink_print_result html url "Added link" !result
+
+let dllink_parse html url =
+  if (String2.starts_with url "http") then (
+    let u = Url.of_string url in
+    let module H = Http_client in
+    let r = {
+      H.basic_request with
+      H.req_url =  u;
+      H.req_proxy = !CommonOptions.http_proxy;
+      H.req_request = H.HEAD;
+      H.req_max_retry = 10;
+      H.req_referer = (
+        let (rule_search,rule_value) =
+        try (List.find(fun (rule_search,rule_value) ->
+          Str.string_match (Str.regexp rule_search) u.Url.server 0
+        ) !!referers )
+        with Not_found -> ("",Url.to_string u) in
+        Some (Url.of_string rule_value) );
+      H.req_headers = (try
+        let cookies = List.assoc u.Url.server !!cookies in
+          [ ( "Cookie", List.fold_left (fun res (key, value) ->
+              if res = "" then
+                key ^ "=" ^ value
+              else
+                res ^ "; " ^ key ^ "=" ^ value
+            ) "" cookies
+            ) ]
+         with Not_found -> []);
+      H.req_user_agent = get_user_agent ();
+    } in
+    H.whead r (fun headers ->
+      (* Combine the list of header fields into one string *)
+      let concat_headers =
+        (List.fold_right (fun (n, c) t -> n ^ ": " ^ c ^ "\n" ^ t) headers "")
+      in
+      ignore (dllink_query_networks html concat_headers)
+    );
+    dllink_print_result html url "Parsing HTTP url" [])
+  else
+    if (String2.starts_with url "ftp") then
+      dllink_query_networks html (Printf.sprintf "Location: %s" url)
+    else
+      dllink_query_networks html url
