@@ -40,12 +40,17 @@ open BasicSocket
 open TcpBufferedSocket
 open CommonOptions
 open CommonGlobals
-  
-module P = GuiProto
-let lprintf_nl () =
-  lprintf "%s[dIface] "
-    (log_time ()); lprintf_nl2
+open CommonUserDb
 
+module P = GuiProto
+
+let log_prefix = "[dIface]"
+
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 let binary_gui_send gui t =
   match gui.gui_sock with
@@ -532,7 +537,7 @@ let gui_reader (gui: gui_record) t _ =
           (to_gui_last_opcode + 1) version;
         gui.gui_proto_from_gui_version <- Array.create 
           (from_gui_last_opcode + 1) version;
-        lprintf_nl () "GUI protocol %d" version    
+        lprintf_nl "GUI protocol %d" version    
     
     | P.GuiExtensions list ->
         List.iter (fun (ext, bool) ->
@@ -564,11 +569,12 @@ let gui_reader (gui: gui_record) t _ =
     
     | P.Password (user, pass) ->
         begin
+          lprintf_nl "GUI connection from user %s" user;
           match gui.gui_sock with
             Some sock when not (valid_password user pass) ->
               gui_send gui BadPassword;                  
               set_lifetime sock 5.;
-              lprintf "BAD PASSWORD\n"; 
+              lprintf_nl "GUI connection BAD PASSWORD for user %s" user; 
               TcpBufferedSocket.close sock (Closed_for_error "Bad Password")
           
           | _ ->
@@ -772,8 +778,7 @@ search.op_search_end_reply_handlers;
                     H.req_url =  u;
                     H.req_proxy = !CommonOptions.http_proxy;
                     H.req_request = H.HEAD;
-                    H.req_user_agent = 
-                       Printf.sprintf "MLDonkey/%s" Autoconf.current_version;
+                    H.req_user_agent = get_user_agent ();
                 } in
                 H.whead r 
                   (fun headers ->
@@ -1069,8 +1074,22 @@ search.op_search_end_reply_handlers;
           | P.GetVersion ->
               gui_send gui (P.Version Autoconf.current_version)
 
-          | P.GiftAttach _ ->
-              gui_send gui (P.GiftServerAttach ("mldonkey", "1.1"))
+          | P.GiftAttach (profile, version, client) ->
+	      let user, pass =
+		try
+		  let index = String.index profile ':' in
+		    String.sub profile 0 (index), 
+		    String.sub profile (index+1) (String.length profile - index - 1)
+		with Not_found -> profile, "" in
+		(match gui.gui_sock with
+		  | Some sock when not (valid_password user pass) ->
+		      set_lifetime sock 5.;
+		      lprintf "BAD PASSWORD\n"; 
+		      TcpBufferedSocket.close sock (Closed_for_error "Bad Password")
+		  | _ ->
+		      gui.gui_auth <- true;
+		      gui.gui_conn.conn_user <- find_ui_user user;
+		      gui_send gui (P.GiftServerAttach ("mldonkey", "1.1")))
           | P.GiftStats ->
               let list = ref [] in
               networks_iter (fun n ->
@@ -1153,7 +1172,7 @@ let gui_handler t event =
   match event with
     TcpServerSocket.CONNECTION (s, Unix.ADDR_INET (from_ip, from_port)) ->
       let from_ip = Ip.of_inet_addr from_ip in
-      lprintf_nl () "GUI connection from %s" (Ip.to_string from_ip);
+      lprintf_nl "GUI connection from %s" (Ip.to_string from_ip);
       if Ip.matches from_ip !!allowed_ips then 
         
         let module P = GuiProto in
@@ -1182,7 +1201,7 @@ let gui_handler t event =
         (* sort GUIs in increasing order of their num *)
         
       else begin
-          lprintf_nl () "GUI connection from %s rejected (see allowed_ips setting)"
+          lprintf_nl "GUI connection from %s rejected (see allowed_ips setting)"
             (Ip.to_string from_ip);
           Unix.close s
         end
