@@ -28,6 +28,7 @@ open CommonInteractive
 open CommonDownloads
 open CommonTypes
 open CommonOptions
+open CommonUserDb
 open CommonGlobals
 open CommonNetwork
 
@@ -50,15 +51,14 @@ open Gettext (* open last  as most modules redefine _s and _b *)
 let _s x = _s "DriverMain" x
 let _b x = _b "DriverMain" x
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s"
-    (log_time ()); lprintf_nl2
+let log_prefix = "[dMain]"
+
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s"
-    (log_time ()); lprintf
 
 let keep_console_output = ref false
 let pid = ref ""
@@ -67,19 +67,16 @@ let do_daily () =
   incr CommonWeb.days
 
 let minute_timer () =
+  DriverInteractive.hdd_check ();
+  DriverInteractive.file_magic_check ();
   CommonShared.shared_check_files ();
   CommonUploads.upload_credit_timer ();
   CommonInteractive.force_download_quotas ();
   CommonResult.dummy_result.result_time <- last_time ();
   (try
-      Int64Swarmer.verify_some_chunks ()
-    with _ -> ()
-  );
-  CommonClient.clear_upload_slots ();
-  if !!auto_commit then
-    List.iter (fun file ->
-        file_commit file
-    ) !!CommonComplexOptions.done_files
+      CommonSwarming.verify_some_chunks ()
+    with _ -> ());
+  CommonClient.clear_upload_slots ()
 
 let hourly_timer timer =
   incr CommonWeb.hours;
@@ -91,16 +88,21 @@ let hourly_timer timer =
   DriverControlers.check_calendar ();
   CommonFile.propose_filenames ()
 
+let ten_second_timer timer =
+  if !!auto_commit then
+    List.iter (fun file ->
+        file_commit file
+    ) !!CommonComplexOptions.done_files
 
 let second_timer timer =
   (try
       update_link_stats ()
     with e ->
-        lprintf_nl () (_b "Exception %s") (Printexc2.to_string e));
+        lprintf_nl (_b "Exception %s") (Printexc2.to_string e));
 	  (try
      CommonUploads.refill_upload_slots ()
    with e ->
-        lprintf_nl () (_b "Exception %s") (Printexc2.to_string e));
+        lprintf_nl (_b "Exception %s") (Printexc2.to_string e));
   CommonUploads.reset_upload_timer ();
   CommonUploads.shared_files_timer ();
   ()
@@ -111,7 +113,7 @@ let start_interfaces () =
   if !!http_port <> 0 then begin try
         ignore (DriverControlers.create_http_handler ());
       with e ->
-          lprintf_nl () (_b "Exception %s while starting HTTP interface")
+          lprintf_nl (_b "Exception %s while starting HTTP interface")
             (Printexc2.to_string e);
     end;
 
@@ -139,43 +141,36 @@ let start_interfaces () =
 
 
 let _ =
-  CommonWeb.add_web_kind "motd.html" (fun _ filename ->
-      lprintf_nl () (_b "motd.html changed");
+  CommonWeb.add_web_kind "motd.html" "Information of the day in HTML format" 
+    (fun _ filename ->
+      lprintf_nl (_b "motd.html changed");
     motd_html =:= File.to_string filename
   );
-  CommonWeb.add_web_kind "motd.conf" (fun _ filename ->
-    let ic = open_in filename in
+  CommonWeb.add_web_kind "motd.conf" "Setup changes of the day" 
+    (fun _ filename ->
     try
-      while true do
-	let line = input_line ic in
-	let cmd, args = String2.cut_at line ' ' in
-	let name, value = String2.cut_at args ' ' in
-	match cmd with
-	  "set" ->
-            CommonInteractive.set_fully_qualified_options name value
-	| "add_item" ->
-            CommonInteractive.add_item_to_fully_qualified_options name value
-	| "del_item" ->
-            CommonInteractive.del_item_from_fully_qualified_options name value
-	| _ ->
-	    lprintf_nl () (_b "UNUSED LINE: %s") line
-
-      done;
+      Unix2.tryopen_read filename (fun ic ->
+	try
+	  while true do
+	    let line = input_line ic in
+	    let cmd, args = String2.cut_at line ' ' in
+	    let name, value = String2.cut_at args ' ' in
+	    match cmd with
+	      | "set" ->
+		  CommonInteractive.set_fully_qualified_options name value
+	      | "add_item" ->
+		  CommonInteractive.add_item_to_fully_qualified_options name value
+	      | "del_item" ->
+		  CommonInteractive.del_item_from_fully_qualified_options name value
+	      | _ ->
+      lprintf_nl (_b "UNUSED LINE: %s") line
+	  done
+	with End_of_file -> ())
     with
-    | End_of_file ->
-	close_in ic
-    | e -> lprintf_nl () (_b "Error while reading motd.conf(%s): %s") filename
-	(Printexc2.to_string e);
-	close_in ic
-  );
-  CommonWeb.add_web_kind "guarding.p2p" (fun _ filename ->
-      Ip_set.bl := Ip_set.load filename;
-(*      Ip_set.bl := Ip_set.load_merge !Ip_set.bl filename *)
-      CommonServer.check_blocked_servers ()
-  );
-  CommonWeb.add_web_kind "geoip.dat" (fun _ filename ->
-      Geoip.init (Geoip.unpack filename))
-
+	e -> 
+    lprintf_nl (_b "Error while reading motd.conf(%s): %s") filename
+	    (Printexc2.to_string e)
+  )
 
 
 let save_mlsubmit_reg () =
@@ -265,7 +260,7 @@ let load_config () =
   in
   if not exists_users_ini && exists_downloads_ini then
     begin
-      lprintf_nl () "No config file (users.ini) found. Importing users from downloads.ini.";
+      lprintf_nl "No config file (users.ini) found. Importing users from downloads.ini.";
       ( try Unix2.copy "downloads.ini" "users.ini" with _ -> () );
     end;
 
@@ -274,9 +269,10 @@ let load_config () =
   (try
       Options.load downloads_ini;
       Options.load users_ini;
-      ignore (DriverInteractive.verify_user_admin ())
+      ignore (DriverInteractive.verify_user_admin ());
+      DriverInteractive.hdd_check ()
     with e ->
-        lprintf_nl () "Exception %s during options load" (Printexc2.to_string e);
+        lprintf_nl "Exception %s during options load" (Printexc2.to_string e);
         exit 70);
 
   (* Here, we try to update options when a new version of mldonkey is
@@ -324,14 +320,14 @@ let load_config () =
 
   Arg.parse ([
       "-v", Arg.Unit (fun _ ->
-          lprintf_nl () "%s" (CommonGlobals.version ());
+          lprintf_nl "%s" (CommonGlobals.version ());
           exit 0), _s " : print version number and exit";
       "-exit", Arg.Unit (fun _ -> exit 0), ": exit immediatly";
       "-format", Arg.String (fun file ->
           ignore (CommonMultimedia.get_info file)),
           _s  " <filename> : check file format";
       "-test_ip", Arg.String (fun ip ->
-          lprintf_nl () "%s = %s" ip (Ip.to_string (Ip.of_string ip));
+          lprintf_nl "%s = %s" ip (Ip.to_string (Ip.of_string ip));
           exit 0), _s "<ip> : undocumented";
       "-check_impl", Arg.Unit (fun _ ->
           CommonNetwork.check_network_implementations ();
@@ -354,7 +350,7 @@ let load_config () =
        _s ": keep output to stderr after startup";
       "-daemon", Arg.Unit (fun _ ->
           (* Removed due to savannah bug #11514 . *)
-          lprintf_nl () "\n\nOption -daemon was removed.\nUse 'mlnet > /dev/null 2>&1 &' instead. Exiting...";
+          lprintf_nl "\n\nOption -daemon was removed.\nUse 'mlnet > /dev/null 2>&1 &' instead. Exiting...";
           exit 64), _s " : this argument was removed, core will exit";
       "-find_port", Arg.Set find_other_port,
       _s " : find another port when one is already used";
@@ -391,8 +387,8 @@ let _ =
   let t = Unix.localtime (Unix.time ()) in
   if (t.Unix.tm_year<=104) then
     begin
-      lprintf_nl () (_b "\n\n\nYour system has a system date earlier than 2004, please correct it.");
-      lprintf_nl () (_b "MLdonkey can not work with such a system date, exiting...");
+      lprintf_nl (_b "\n\n\nYour system has a system date earlier than 2004, please correct it.");
+      lprintf_nl (_b "MLdonkey can not work with such a system date, exiting...");
       CommonGlobals.exit_properly 71
     end;
 
@@ -421,12 +417,26 @@ This can lead to unexpected behaviour. Consider compiling the core yourself
 or getting a binary compiled with glibc %s.\n\n")
           real_glibc_version Autoconf.glibc_version Autoconf.glibc_version
   );
+  (
+    if Autoconf.magic then
+      if Magic.M.magic_works () then
+        begin
+	  Autoconf.magic_works := true;
+          lprintf_nl (_b "Libmagic file-type recognition database present")
+	end
+      else
+        begin
+	  Autoconf.magic_works := false;
+          lprintf_nl (_b "Libmagic file-type recognition database not present")
+	end
+  );
   load_config ();
   
   add_infinite_option_timer download_sample_rate CommonFile.sample_timer;
 
 (*  lprintf "(1) CommonComplexOptions.load\n"; *)
   CommonComplexOptions.load ();
+  DriverInteractive.file_magic_check ();
   CommonUploads.load ();
 
 (*  lprintf "(2) CommonComplexOptions.load done\n"; *)
@@ -439,7 +449,7 @@ or getting a binary compiled with glibc %s.\n\n")
   end;
 
 (*  lprintf "(3) networks_iter load_complex_options\n"; *)
-  lprintf_nl () (_b "Check http://www.mldonkey.net/ for updates");
+  lprintf_nl (_b "Check http://www.mldonkey.net/ for updates");
   networks_iter (fun r -> network_load_complex_options r);
   lprintf (_b "%senabling networks: ") (log_time ());
   networks_iter (fun r ->
@@ -472,6 +482,7 @@ or getting a binary compiled with glibc %s.\n\n")
   start_interfaces ();
 
   add_infinite_timer 60. minute_timer;
+  add_infinite_timer 10. ten_second_timer;
   add_infinite_timer 3600. hourly_timer;
   add_infinite_timer 0.1 CommonUploads.upload_download_timer;
 
@@ -490,17 +501,17 @@ or getting a binary compiled with glibc %s.\n\n")
   Options.prune_file users_ini;
 (*  Options.prune_file downloads_expert_ini; *)
   add_timer 5. (fun _ -> try CommonWeb.load_web_infos true with _ -> ());
-  lprintf_nl ()  (_b "To command: telnet %s %d")
+  lprintf_nl  (_b "To command: telnet %s %d")
 	(if !!telnet_bind_addr = Ip.any then "127.0.0.1"
 		else Ip.to_string !!telnet_bind_addr)  !!telnet_port;
-  lprintf_nl ()  (_b "Or with browser: http://%s:%d")
+  lprintf_nl  (_b "Or with browser: http://%s:%d")
 	(if !!http_bind_addr = Ip.any then "127.0.0.1"
 		else Ip.to_string !!http_bind_addr)  !!http_port;
-  lprintf_nl ()  (_b "For a GUI check out http://sancho-gui.sourceforge.net");
-  lprintf_nl ()  (_b "Connect to IP %s, port %d")
+  lprintf_nl  (_b "For a GUI check out http://sancho-gui.sourceforge.net");
+  lprintf_nl  (_b "Connect to IP %s, port %d")
 	(if !!gui_bind_addr = Ip.any then "127.0.0.1"
 		else Ip.to_string !!gui_bind_addr)  !!gui_port;
-  lprintf_nl ()  (_b "If you connect from a remote machine adjust allowed_ips");
+  lprintf_nl  (_b "If you connect from a remote machine adjust allowed_ips");
   if Autoconf.system = "cygwin" && not !keep_console_output then lprintf (_b "%s") win_message;
 
   add_init_hook (fun _ ->
@@ -515,7 +526,7 @@ or getting a binary compiled with glibc %s.\n\n")
             Sys.file_exists asker then
             ignore (Sys.command (Printf.sprintf "%s %s&" asker !!mldonkey_gui));
         with Not_found ->
-            lprintf_nl () (_b "Not running under X, not trying to start the GUI")
+            lprintf_nl (_b "Not running under X, not trying to start the GUI")
             );
   );
 
@@ -524,9 +535,9 @@ or getting a binary compiled with glibc %s.\n\n")
         let new_pw = Unix.getpwnam !!run_as_user in
         MlUnix.setuid new_pw.Unix.pw_uid;
         let pw = Unix.getpwuid (Unix.getuid()) in
-        lprintf_nl () (_b "mldonkey is now running as user %s") pw.Unix.pw_name;
+        lprintf_nl (_b "mldonkey is now running as user %s") pw.Unix.pw_name;
       with e ->
-          lprintf_nl () (_b "Exception %s trying to set user_uid [%s]")
+          lprintf_nl (_b "Exception %s trying to set user_uid [%s]")
           (Printexc2.to_string e) !!run_as_user;
           exit 67
     end;
@@ -534,9 +545,9 @@ or getting a binary compiled with glibc %s.\n\n")
   if !!run_as_useruid <> 0 then begin
       try
         MlUnix.setuid !!run_as_useruid;
-        lprintf_nl () (_b "mldonkey is now running as uid %d")  !!run_as_useruid;
+        lprintf_nl (_b "mldonkey is now running as uid %d")  !!run_as_useruid;
       with e ->
-          lprintf_nl () (_b "Exception %s trying to set user_uid [%d]")
+          lprintf_nl (_b "Exception %s trying to set user_uid [%d]")
           (Printexc2.to_string e) !!run_as_useruid;
           exit 67
     end;
@@ -547,42 +558,42 @@ or getting a binary compiled with glibc %s.\n\n")
 
   if not Autoconf.windows then
     MlUnix.set_signal  Sys.sigchld
-      (Sys.Signal_handle (fun _ -> if !verbose then lprintf_nl () "Received SIGCHLD, doing nothing"));
+      (Sys.Signal_handle (fun _ -> if !verbose then lprintf_nl "Received SIGCHLD, doing nothing"));
 
   if not Autoconf.windows then
     MlUnix.set_signal  Sys.sighup
       (Sys.Signal_handle (fun _ ->
-	 lprintf_nl () "Received SIGHUP, closing all files/sockets";
+   lprintf_nl "Received SIGHUP, closing all files/sockets";
          BasicSocket.close_all ();
 	 Unix32.close_all ()
          ));
 
   if not Autoconf.windows then
     MlUnix.set_signal  Sys.sigpipe
-      (Sys.Signal_handle (fun _ -> if !verbose then lprintf_nl () "Received SIGPIPE, doing nothing"));
+      (Sys.Signal_handle (fun _ -> if !verbose then lprintf_nl "Received SIGPIPE, doing nothing"));
 
   MlUnix.set_signal  Sys.sigint
-    (Sys.Signal_handle (fun _ -> lprintf_nl () "Received SIGINT, stopping MLDonkey...";
+    (Sys.Signal_handle (fun _ -> lprintf_nl "Received SIGINT, stopping MLDonkey...";
         CommonInteractive.clean_exit 0));
 
   MlUnix.set_signal  Sys.sigterm
-    (Sys.Signal_handle (fun _ -> lprintf_nl () "Received SIGTERM, stopping MLDonkey...";
+    (Sys.Signal_handle (fun _ -> lprintf_nl "Received SIGTERM, stopping MLDonkey...";
         CommonInteractive.clean_exit 0));
 
   if not Autoconf.windows then
   MlUnix.set_signal  Sys.sigusr1
-    (Sys.Signal_handle (fun _ -> lprintf_nl () "Received SIGUSR1, saving options...";
+    (Sys.Signal_handle (fun _ -> lprintf_nl "Received SIGUSR1, saving options...";
         DriverInteractive.save_config ()));
 
   if not Autoconf.windows then
   MlUnix.set_signal  Sys.sigusr2
     (Sys.Signal_handle (fun _ ->
-	lprintf_n () "Received SIGUSR2, starting garbage collection...";
+  lprintf_n "Received SIGUSR2, starting garbage collection...";
 	Gc.compact ();
 	lprintf " finished";
 	lprint_newline ()));
 
-  if !verbose then lprintf_nl () (_b "Activated system signal handling")
+  if !verbose then lprintf_nl (_b "Activated system signal handling")
 
 let _ =
   let security_space_filename = "config_files_space.tmp" in
@@ -605,9 +616,9 @@ for config files at the end. *)
       in
       Unix32.close security_space_fd;
     with _ ->
-        lprintf_nl () (_b "Cannot create Security space file:");
-        lprintf_nl () (_b " not enough space on device or bad permissions");
-        lprintf_nl () (_b "Exiting...");
+        lprintf_nl (_b "Cannot create Security space file:");
+        lprintf_nl (_b " not enough space on device or bad permissions");
+        lprintf_nl (_b "Exiting...");
         exit 73;
   end;
   Unix32.external_start ();
@@ -620,12 +631,10 @@ for config files at the end. *)
         Filename.concat !pid pid_filename,
 	Printf.sprintf "%s\n" (string_of_int(Unix.getpid()))
     in
-    let oc = open_out pid_file in
-    output_string oc s;
-    close_out oc;
+    Unix2.tryopen_write pid_file (fun oc -> output_string oc s);
     CommonGlobals.do_at_exit (fun _ -> try Sys.remove pid_file with _ -> ());
     if !verbose then
-      lprintf_nl () (_b "Starting with pid %s") (string_of_int(Unix.getpid ()))
+      lprintf_nl (_b "Starting with pid %s") (string_of_int(Unix.getpid ()))
   );
 
 (* When a core is spawned from a gui, the only way to know the startup has
@@ -638,7 +647,8 @@ for config files at the end. *)
       with _ -> ()
     end;
 
-  lprintf_nl () (_b "Core started");
+  lprintf_nl (_b "Core started");
+  pause_new_downloads =:= false;
   core_included := true;
 
   CommonGlobals.do_at_exit (fun _ ->
@@ -647,26 +657,27 @@ for config files at the end. *)
       (try
          BasicSocket.close_all ();
        with e ->
-           lprintf_nl () "Exception %s in do_at_exit while closing sockets."
+           lprintf_nl "Exception %s in do_at_exit while closing sockets."
              (Printexc2.to_string e);
       );
       DriverGraphics.G.remove_files ();
       (* In case we have no more space on filesystem for
          config files, remove the security space file *)
       Sys.remove security_space_filename;
+      CommonComplexOptions.allow_saving_ini_files := true;
       DriverInteractive.save_config ();
       CommonComplexOptions.save_sources ();
       CommonComplexOptions.backup_options ();
       Geoip.close ();
       Unix32.external_exit ();
-      lprintf_nl () (_b "Core stopped")
+      lprintf_nl (_b "Core stopped")
     );
 
   if not !keep_console_output then
     if !!log_file = "" then 
       begin
-        lprintf_nl () (_b "Option log_file is empty, disable logging completely...");
-        lprintf_nl () (_b "Disabling output to console, to enable: stdout true");
+        lprintf_nl (_b "Option log_file is empty, disable logging completely...");
+        lprintf_nl (_b "Disabling output to console, to enable: stdout true");
 	log_to_file stdout;
         close_log ()
       end
