@@ -64,16 +64,6 @@ open BTChooser
 open BTStats
 open TcpMessages
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[BT] "
-    (log_time ()); lprintf_nl2
-
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[BT] "
-    (log_time ()); lprintf
-
 let http_ok = "HTTP 200 OK"
 let http11_ok = "HTTP/1.1 200 OK"
 
@@ -109,7 +99,7 @@ let connect_trackers file event f =
         end
 
     | Some swarmer ->
-        let local_downloaded = Int64Swarmer.downloaded swarmer in
+        let local_downloaded = CommonSwarming.downloaded swarmer in
         let left = file_size file -- local_downloaded in
         match event with
           | "completed" -> [("event", "completed")],false,zero,zero
@@ -144,8 +134,8 @@ let connect_trackers file event f =
     else begin
       (* if there is no tracker left, do something ? *)
       if !verbose_msg_servers then
-	lprintf_nl () "No trackers left, reenabling all of them...";
-      List.iter (fun t -> t.tracker_enabled <- true) file.file_trackers;
+  lprintf_nl "No trackers left, reenabling all of them...";
+      List.iter (fun t -> t.tracker_enabled <- can_handle_tracker t) file.file_trackers;
       file.file_trackers
     end in
 
@@ -167,7 +157,7 @@ let connect_trackers file event f =
           if file.file_tracker_connected && t.tracker_last_clients_num = 0 &&
             t.tracker_last_conn < 1 then begin
               if !verbose_msg_servers then
-                lprintf_nl () "Request error from tracker: disabling %s" t.tracker_url;
+                lprintf_nl "Request error from tracker: disabling %s" t.tracker_url;
 	      t.tracker_enabled <- false;
               (* remove_tracker t.tracker_url file *)
             end
@@ -180,7 +170,7 @@ let connect_trackers file event f =
                   ("key", t.tracker_key) :: args else args
               in
               if !verbose_msg_servers then
-                lprintf_nl () "get_sources_from_tracker: tracker_connected:%s id:%s key:%s last_clients:%i last_conn-last_time:%i file: %s"
+                lprintf_nl "get_sources_from_tracker: tracker_connected:%s id:%s key:%s last_clients:%i last_conn-last_time:%i file: %s"
                   (string_of_bool file.file_tracker_connected)
                   t.tracker_id t.tracker_key t.tracker_last_clients_num
                   (t.tracker_last_conn - last_time()) file.file_name;
@@ -197,20 +187,19 @@ let connect_trackers file event f =
                 } in
 
               if !verbose_msg_servers then
-                  lprintf_nl () "Request sent to tracker %s for file: %s"
+                  lprintf_nl "Request sent to tracker %s for file: %s"
                     t.tracker_url file.file_name;
               H.wget r
                 (fun fileres ->
                   t.tracker_last_conn <- last_time ();
                   file.file_tracker_connected <- true;
-                  f t fileres;
-		  (try Sys.remove fileres with _ -> ()))
+                  f t fileres)
           end
         end
 
       else
         if !verbose_msg_servers then
-          lprintf_nl () "Request NOT sent to tracker %s - next request in %ds for file: %s"
+          lprintf_nl "Request NOT sent to tracker %s - next request in %ds for file: %s"
             t.tracker_url (t.tracker_interval - (last_time () - t.tracker_last_conn)) file.file_name
   ) enabled_trackers
 
@@ -220,7 +209,7 @@ let connect_trackers file event f =
   for clients that are in next list (and not in current)
 *)
 let recompute_uploaders () =
-  if !verbose_upload then lprintf_nl () "recompute_uploaders";
+  if !verbose_upload then lprintf_nl "recompute_uploaders";
   next_uploaders := choose_uploaders current_files;
   (*Send choke if a current_uploader is not in next_uploaders*)
   List.iter ( fun c -> if ((List.mem c !next_uploaders)==false) then
@@ -258,7 +247,7 @@ let recompute_uploaders () =
 *)
 let disconnect_client c reason =
   if !verbose_msg_clients then
-    lprintf_nl () "Client %d: disconnected: %s" (client_num c) (string_of_reason reason);
+    lprintf_nl "Client %d: disconnected: %s" (client_num c) (string_of_reason reason);
   begin
     match c.client_sock with
       NoConnection -> ()
@@ -268,7 +257,7 @@ let disconnect_client c reason =
     | Connection sock  ->
         close sock reason;
         try
-(*          List.iter (fun r -> Int64Swarmer.free_range r) c.client_ranges; *)
+(*          List.iter (fun r -> CommonSwarming.free_range r) c.client_ranges; *)
           set_client_disconnected c reason;
           (try if c.client_good then count_seen c with _ -> ());
           (* this is not useful already done in the match
@@ -296,7 +285,7 @@ let disconnect_client c reason =
                      we must unregister him to update the swarmer
                      (Useful for availability)
                   *)
-                  Int64Swarmer.unregister_uploader up
+                  CommonSwarming.unregister_uploader up
 (*        c.client_registered_bitfield <- false;
           for i = 0 to String.length c.client_bitmap - 1 do
             c.client_bitmap.[0] <- '0';
@@ -331,7 +320,7 @@ let disconnect_clients file =
   if not ( !must_keep && (client_has_a_slot (as_client c) || c.client_interested)) then
     begin
       if !verbose_msg_clients then
-        lprintf_nl () "disconnect since download is finished";
+        lprintf_nl "disconnect since download is finished";
       disconnect_client c Closed_by_user
     end
   ) file.file_clients
@@ -347,7 +336,7 @@ let download_finished file =
         (*CommonComplexOptions.file_completed*)
         file_completed (as_file file);
         (* Remove the swarmer for this file as it is not useful anymore... *)
-        Int64Swarmer.remove_swarmer file.file_swarmer;
+        CommonSwarming.remove_swarmer file.file_swarmer;
         file.file_swarmer <- None;
         (* At this point, the file state is FileDownloaded. We should not remove
            the file, because we continue to upload. *)
@@ -359,7 +348,7 @@ let download_finished file =
   @param file The file to check status
 *)
 let check_finished swarmer file =
-  if Int64Swarmer.check_finished swarmer then
+  if CommonSwarming.check_finished swarmer then
       download_finished file
 
 let bits = [| 128; 64; 32;16;8;4;2;1 |]
@@ -401,10 +390,10 @@ let send_bitfield c =
 (* This must be a seeded file... *)
         String.make (Array.length c.client_file.file_chunks) '3'
     | Some swarmer ->
-        Int64Swarmer.verified_bitmap swarmer
+        CommonSwarming.verified_bitmap swarmer
   in
 
-  if !verbose_download then lprintf_nl () "Sending verified bitmap: [%s]" bitmap;
+  if !verbose_download then lprintf_nl "Sending verified bitmap: [%s]" bitmap;
 
 (* In the future, only accept bitmap.[n] > '2' when verification works *)
   send_client c (BitField
@@ -438,16 +427,16 @@ let rec client_parse_header counter cc init_sent gconn sock
   try
     set_lifetime sock 600.;
     if !verbose_msg_clients then
-      lprintf_nl () "client_parse_header %d" counter;
+      lprintf_nl "client_parse_header %d" counter;
 
     let file = Hashtbl.find files_by_uid file_id in
     if !verbose_msg_clients then
-      lprintf_nl () "file found";
+      lprintf_nl "file found";
     let c =
       match !cc with
         None ->
           let c = new_client file Sha1.null (TcpBufferedSocket.peer_addr sock) in
-          if !verbose_connect then lprintf_nl () "Client %d: incoming connection" (client_num c);
+          if !verbose_connect then lprintf_nl "Client %d: incoming connection" (client_num c);
           cc := Some c;
           c
       | Some c ->
@@ -484,7 +473,7 @@ let rec client_parse_header counter cc init_sent gconn sock
 
     if !verbose_msg_clients then begin
         let (ip,port) = c.client_host in
-          lprintf_nl () "Client %d: Connected from %s:%d" (client_num c)
+          lprintf_nl "Client %d: Connected from %s:%d" (client_num c)
             (Ip.to_string ip) port;
       end;
 
@@ -492,17 +481,17 @@ let rec client_parse_header counter cc init_sent gconn sock
         NoConnection ->
           if !verbose_msg_clients then begin
               let (ip,port) = c.client_host in
-              lprintf_nl () "No connection to client (%s:%d)!!!" (Ip.to_string ip) port;
+              lprintf_nl "No connection to client (%s:%d)!!!" (Ip.to_string ip) port;
             end;
           c.client_sock <- Connection sock
       | ConnectionWaiting token ->
           cancel_token token;
           if !verbose_msg_clients then
-            lprintf_nl () "Waiting for connection to client !!!";
+            lprintf_nl "Waiting for connection to client !!!";
           c.client_sock <- Connection sock
       | Connection s when s != sock ->
           if !verbose_msg_clients then
-            lprintf_nl () "CLIENT %d: IMMEDIATE RECONNECTION" (client_num c);
+            lprintf_nl "CLIENT %d: IMMEDIATE RECONNECTION" (client_num c);
           disconnect_client c (Closed_for_error "Reconnected");
           c.client_sock <- Connection sock;
       | Connection _  -> ()
@@ -516,7 +505,7 @@ let rec client_parse_header counter cc init_sent gconn sock
       end;
     connection_ok c.client_connection_control;
     if !verbose_msg_clients then
-      lprintf_nl () "file and client found";
+      lprintf_nl "file and client found";
 (*    if not c.client_incoming then *)
      send_bitfield c; 
     c.client_blocks_sent <- file.file_blocks_downloaded;
@@ -538,10 +527,10 @@ let rec client_parse_header counter cc init_sent gconn sock
       | Not_found ->
           let (ip,port) = (TcpBufferedSocket.peer_addr sock) in
           if !verbose_unexpected_messages then
-            lprintf_nl () "Client %s:%d requested a file that is not shared [%s]"
+            lprintf_nl "Client %s:%d requested a file that is not shared [%s]"
               (Ip.to_string ip) port (Sha1.to_hexa file_id)
       | e ->
-          lprintf_nl () "Exception %s in client_parse_header" (Printexc2.to_string e);
+          lprintf_nl "Exception %s in client_parse_header" (Printexc2.to_string e);
       close sock (Closed_for_exception e);
       raise e
 
@@ -560,7 +549,7 @@ and update_client_bitmap c =
   let up =
     match c.client_uploader with
       None ->
-        let up = Int64Swarmer.register_uploader swarmer (as_client c)
+        let up = CommonSwarming.register_uploader swarmer (as_client c)
           (AvailableRanges []) in
         c.client_uploader <- Some up;
         up
@@ -570,7 +559,7 @@ and update_client_bitmap c =
 
   let bitmap = match c.client_bitmap with
       None ->
-        let len = Int64Swarmer.partition_size swarmer in
+        let len = CommonSwarming.partition_size swarmer in
         let bitmap = Bitv.create len false in
         c.client_bitmap <- Some bitmap;
         bitmap
@@ -581,7 +570,7 @@ and update_client_bitmap c =
     let chunks = c.client_new_chunks in
     c.client_new_chunks <- [];
     List.iter (fun n -> Bitv.set bitmap n true) chunks;
-    Int64Swarmer.update_uploader up (AvailableBitv bitmap);
+    CommonSwarming.update_uploader up (AvailableBitv bitmap);
   end
 
 
@@ -603,18 +592,18 @@ and get_from_client sock (c: client) =
     let up = match c.client_uploader with
         None -> assert false
       | Some up -> up in
-    let swarmer = Int64Swarmer.uploader_swarmer up in
+    let swarmer = CommonSwarming.uploader_swarmer up in
 
   try
   
     let num, x,y, r =
 
       if !verbose_msg_clients then begin
-        lprintf_nl () "CLIENT %d: Finding new range to send" (client_num c);
+        lprintf_nl "CLIENT %d: Finding new range to send" (client_num c);
       end;
 
       if !verbose_swarming then begin
-        lprintf_n () "Current download:\n  Current chunks: ";
+        lprintf_n "Current download:\n  Current chunks: ";
 
         try
           List.iter (fun (x,y) -> lprintf "%Ld-%Ld " x y) c.client_chunks
@@ -622,10 +611,10 @@ and get_from_client sock (c: client) =
           
         lprint_newline ();
           
-        lprintf_n () "Current ranges: ";
+        lprintf_n "Current ranges: ";
           
         List.iter (fun (p1,p2, r) ->
-          let (x,y) = Int64Swarmer.range_range r in
+          let (x,y) = CommonSwarming.range_range r in
           lprintf "%Ld-%Ld[%Ld-%Ld] " p1 p2 x y
         ) c.client_ranges_sent;
 
@@ -635,15 +624,15 @@ and get_from_client sock (c: client) =
 
         lprint_newline ();
           
-        lprintf_n () "Current block: ";
+        lprintf_n "Current block: ";
           
         match c.client_block with
         | None -> lprintf "none"
-        | Some b -> Int64Swarmer.print_block b;
+        | Some b -> CommonSwarming.print_block b;
 
         lprint_newline ();
       
-        lprintf_nl () "Finding Range:";
+        lprintf_nl "Finding Range:";
       end;
 
       try
@@ -658,13 +647,13 @@ and get_from_client sock (c: client) =
 
             None -> 
 
-              if !verbose_swarming then lprintf_nl () "No block";
+              if !verbose_swarming then lprintf_nl "No block";
               update_client_bitmap c;
-              (try Int64Swarmer.verify_one_chunk swarmer with _ -> ());
+              (try CommonSwarming.verify_one_chunk swarmer with _ -> ());
               (*Find a free block in the swarmer*)
-              let b = Int64Swarmer.find_block up in
+              let b = CommonSwarming.find_block up in
               if !verbose_swarming then begin 
-                lprintf_n () "Block Found: "; Int64Swarmer.print_block b;
+                lprintf_n "Block Found: "; CommonSwarming.print_block b;
                 lprint_newline ()
               end;
               c.client_block <- Some b;
@@ -679,7 +668,7 @@ and get_from_client sock (c: client) =
           | Some b ->
 
               if !verbose_swarming then begin
-                lprintf_n () "Current Block: "; Int64Swarmer.print_block b;
+                lprintf_n "Current Block: "; CommonSwarming.print_block b;
                 lprint_newline ()
               end;
 
@@ -691,7 +680,7 @@ and get_from_client sock (c: client) =
                         c.client_range_waiting <- None;
                         (x,y,r)
                   | None -> 
-                        Int64Swarmer.find_range up 
+                        CommonSwarming.find_range up 
                 in
 
                 let (x,y,r) =
@@ -704,12 +693,12 @@ and get_from_client sock (c: client) =
                 in
                 
                   c.client_ranges_sent <- c.client_ranges_sent @ [x,y, r];
-(*                Int64Swarmer.alloc_range r; *)
+(*                CommonSwarming.alloc_range r; *)
                 
-                  let num = Int64Swarmer.block_num swarmer b in
+                  let num = CommonSwarming.block_num swarmer b in
 
                   if !verbose_swarming then 
-                    lprintf_nl () "Asking %d For Range %Ld-%Ld" num x y;
+                    lprintf_nl "Asking %d For Range %Ld-%Ld" num x y;
                       
                   num, x -- file.file_piece_size ** Int64.of_int num, y -- x, r
 
@@ -718,7 +707,7 @@ and get_from_client sock (c: client) =
                   (*If we don't find a range to request inside the block,
                     iter to choose another block*)
                   if !verbose_swarming then
-                    lprintf_nl () "Could not find range in current block";
+                    lprintf_nl "Could not find range in current block";
 (*                  c.client_blocks <- List2.removeq b c.client_blocks; *)
 
                   c.client_block <- None;
@@ -735,8 +724,8 @@ and get_from_client sock (c: client) =
             a block to ask)
           *)
           if !verbose_swarming then
-            lprintf_nl () "Unable to get a block !!";
-          Int64Swarmer.compute_bitmap swarmer;
+            lprintf_nl "Unable to get a block !!";
+          CommonSwarming.compute_bitmap swarmer;
           check_finished swarmer file;
           raise Not_found
     in
@@ -744,12 +733,12 @@ and get_from_client sock (c: client) =
     send_client c (Request (num,x,y));
 
     if !verbose_msg_clients then
-      lprintf_nl () "CLIENT %d: Asking %s For Range %Ld-%Ld"
+      lprintf_nl "CLIENT %d: Asking %s For Range %Ld-%Ld"
         (client_num c) (Sha1.to_string c.client_uid) x y
 
   with Not_found ->
-        if not (Int64Swarmer.check_finished swarmer) && !verbose_download then
-          lprintf_nl () "BTClient.get_from_client ERROR: can't find a block to download and file is not yet finished for file : %s..." file.file_name
+        if not (CommonSwarming.check_finished swarmer) && !verbose_download then
+          lprintf_nl "BTClient.get_from_client ERROR: can't find a block to download and file is not yet finished for file : %s..." file.file_name
 
 
 (** In this function we match a message sent by a client
@@ -761,7 +750,7 @@ and get_from_client sock (c: client) =
 and client_to_client c sock msg =
   if !verbose_msg_clients then begin
       let (timeout, next) = get_rtimeout sock in
-      lprintf_nl () "CLIENT %d: (%d, %d,%d) Received %s"
+      lprintf_nl "CLIENT %d: (%d, %d,%d) Received %s"
         (client_num c)
       (last_time ())
       (int_of_float timeout)
@@ -778,7 +767,7 @@ and client_to_client c sock msg =
           [] -> ()
         | b :: tail when tail == c.client_blocks_sent ->
             c.client_blocks_sent <- list;
-            let (num,_,_) = Int64Swarmer.block_block b  in
+            let (num,_,_) = CommonSwarming.block_block b  in
             send_client c (Have (Int64.of_int num))
         | _ :: tail -> iter tail
       in
@@ -797,26 +786,26 @@ and client_to_client c sock msg =
             let up = match c.client_uploader with
                 None -> assert false
               | Some up -> up in
-            let swarmer = Int64Swarmer.uploader_swarmer up in
+            let swarmer = CommonSwarming.uploader_swarmer up in
 
             if !verbose_msg_clients then
               (match c.client_ranges_sent with
-                  [] -> lprintf_nl () "EMPTY Ranges !!!"
+                  [] -> lprintf_nl "EMPTY Ranges !!!"
                 | (p1,p2,r) :: _ ->
-                    let (x,y) = Int64Swarmer.range_range r in
-                    lprintf_nl () "Current range from %s : %Ld [%d] (asked %Ld-%Ld[%Ld-%Ld])"
+                    let (x,y) = CommonSwarming.range_range r in
+                    lprintf_nl "Current range from %s : %Ld [%d] (asked %Ld-%Ld[%Ld-%Ld])"
                       (brand_to_string c.client_brand) position len
                       p1 p2 x y
               );
 
             let old_downloaded =
-              Int64Swarmer.downloaded swarmer in
-(*            List.iter Int64Swarmer.free_range c.client_ranges;       *)
-            Int64Swarmer.received up
+              CommonSwarming.downloaded swarmer in
+(*            List.iter CommonSwarming.free_range c.client_ranges;       *)
+            CommonSwarming.received up
               position s pos len;
-(*            List.iter Int64Swarmer.alloc_range c.client_ranges; *)
+(*            List.iter CommonSwarming.alloc_range c.client_ranges; *)
             let new_downloaded =
-              Int64Swarmer.downloaded swarmer in
+              CommonSwarming.downloaded swarmer in
 
             (*Update rate and amount of data received from client*)
             count_download c (new_downloaded -- old_downloaded);
@@ -824,10 +813,10 @@ and client_to_client c sock msg =
             Rate.update c.client_downloaded_rate  (float_of_int len);
             if !verbose_msg_clients then
               (match c.client_ranges_sent with
-                  [] -> lprintf_nl () "EMPTY Ranges !!!"
+                  [] -> lprintf_nl "EMPTY Ranges !!!"
                 | (p1,p2,r) :: _ ->
-                    let (x,y) = Int64Swarmer.range_range r in
-                    lprintf_nl () "Received %Ld [%d] %Ld-%Ld[%Ld-%Ld] -> %Ld"
+                    let (x,y) = CommonSwarming.range_range r in
+                    lprintf_nl "Received %Ld [%d] %Ld-%Ld[%Ld-%Ld] -> %Ld"
                       position len
                       p1 p2 x y
                       (new_downloaded -- old_downloaded)
@@ -842,7 +831,7 @@ and client_to_client c sock msg =
           match c.client_ranges_sent with
             [] -> ()
           | r :: tail ->
-(*              Int64Swarmer.free_range r; *)
+(*              CommonSwarming.free_range r; *)
               c.client_ranges_sent <- tail;
         end;
         get_from_client sock c;
@@ -909,15 +898,15 @@ and client_to_client c sock msg =
           | Some swarmer ->
               c.client_new_chunks <- [];
               
-              let npieces = Int64Swarmer.partition_size swarmer in
+              let npieces = CommonSwarming.partition_size swarmer in
               let nbits = String.length p * 8 in
 
               if nbits < npieces then begin
-                lprintf_nl () "Error: expected bitfield of atleast %d but got %d" npieces nbits;
+                lprintf_nl "Error: expected bitfield of atleast %d but got %d" npieces nbits;
                 disconnect_client c (Closed_for_error "Wrong bitfield length")
               end else begin
 
-                let verified = Int64Swarmer.verified_bitmap swarmer in
+                let verified = CommonSwarming.verified_bitmap swarmer in
 
                 for i = 0 to npieces - 1 do
                   if is_bit_set p i then begin
@@ -934,7 +923,7 @@ and client_to_client c sock msg =
                   send_interested c;
 
                 if !verbose_msg_clients then
-                  lprintf_nl () "New BitField Registered";
+                  lprintf_nl "New BitField Registered";
 
                 (*  for i = 1 to max_range_requests - List.length c.client_ranges do
                       (try get_from_client sock c with _ -> ())
@@ -952,7 +941,7 @@ and client_to_client c sock msg =
             None -> ()
           | Some swarmer ->
               let n = Int64.to_int n in
-              let verified = Int64Swarmer.verified_bitmap swarmer in
+              let verified = CommonSwarming.verified_bitmap swarmer in
               (* lprintf_nl "verified: %c;" verified.[n]; *)
               (* if the peer has a chunk we don't, tell him we're interested and update his bitmap *)
               if verified.[n] < '2' then begin
@@ -965,11 +954,11 @@ and client_to_client c sock msg =
 (*        begin
           match c.client_bitmap, c.client_uploader with
             Some bitmap, Some up ->
-              let swarmer = Int64Swarmer.uploader_swarmer up in
+              let swarmer = CommonSwarming.uploader_swarmer up in
               let n = Int64.to_int n in
               if bitmap.[n] <> '1' then
 
-                let verified = Int64Swarmer.verified_bitmap swarmer in
+                let verified = CommonSwarming.verified_bitmap swarmer in
                 if verified.[n] < '2' then begin
                     c.client_interesting <- true;
                     send_interested c;
@@ -982,9 +971,9 @@ and client_to_client c sock msg =
                   done*)
                       end
                   end
-          | None, Some _ -> lprintf_nl () "no bitmap but client_uploader";
-    | Some _ , None ->lprintf_nl () "bitmap but no client_uploader";
-    | None, None -> lprintf_nl () "no bitmap no client_uploader";
+          | None, Some _ -> lprintf_nl "no bitmap but client_uploader";
+    | Some _ , None ->lprintf_nl "bitmap but no client_uploader";
+    | None, None -> lprintf_nl "no bitmap no client_uploader";
         end
 *)
         end
@@ -1002,10 +991,10 @@ and client_to_client c sock msg =
                 (* Afaik this is no protocol violation and happens if the client
                    didn't send a client bitmap after the handshake. *)
                 let (ip,port) = c.client_host in
-                  if !verbose_msg_clients then lprintf_nl () "%s:%d with software %s : Choke send, but no client bitmap"
+                  if !verbose_msg_clients then lprintf_nl "%s:%d with software %s : Choke send, but no client bitmap"
                     (Ip.to_string ip) port (brand_to_string c.client_brand)
             | Some up ->
-                Int64Swarmer.clear_uploader_ranges up
+                CommonSwarming.clear_uploader_ranges up
           end;
           c.client_ranges_sent <- [];
           c.client_range_waiting <- None;
@@ -1067,10 +1056,10 @@ and client_to_client c sock msg =
           c.client_upload_requests <- List2.remove_first (n, pos, len) c.client_upload_requests
         else
           if !verbose_msg_clients then
-            lprintf_nl () "Error: received cancel request but client has no slot"
+            lprintf_nl "Error: received cancel request but client has no slot"
 
   with e ->
-      lprintf_nl () "Error %s while handling MESSAGE: %s" (Printexc2.to_string e) (TcpMessages.to_string msg)
+      lprintf_nl "Error %s while handling MESSAGE: %s" (Printexc2.to_string e) (TcpMessages.to_string msg)
 
 
 (** The function used to connect to a client.
@@ -1082,12 +1071,12 @@ be put in a fifo and dequeued according to
 let connect_client c =
   if can_open_connection connection_manager &&
     (let (ip,port) = c.client_host in
-     match Ip_set.match_ip !Ip_set.bl ip with
+     match !Ip.banned ip with
        None -> true
-     | Some br ->
+     | Some reason ->
          if !verbose_connect then
-           lprintf_nl () "%s:%d blocked: %s"
-             (Ip.to_string ip) port br.blocking_description;
+           lprintf_nl "%s:%d blocked: %s"
+             (Ip.to_string ip) port reason;
          false)
   then
   match c.client_sock with
@@ -1097,10 +1086,10 @@ let connect_client c =
         add_pending_connection connection_manager (fun token ->
             try
               if !verbose_msg_clients then
-                lprintf_nl () "CLIENT %d: connect_client" (client_num c);
+                lprintf_nl "CLIENT %d: connect_client" (client_num c);
               let (ip,port) = c.client_host in
               if !verbose_msg_clients then
-                lprintf_nl () "connecting %s:%d" (Ip.to_string ip) port;
+                lprintf_nl "connecting %s:%d" (Ip.to_string ip) port;
               connection_try c.client_connection_control;
                 begin
                   let sock = connect token "bittorrent download"
@@ -1109,11 +1098,11 @@ let connect_client c =
                         match event with
                           BASIC_EVENT LTIMEOUT ->
                             if !verbose_msg_clients then
-                              lprintf_nl () "CLIENT %d: LIFETIME" (client_num c);
+                              lprintf_nl "CLIENT %d: LIFETIME" (client_num c);
                             close sock Closed_for_timeout
                         | BASIC_EVENT RTIMEOUT ->
                             if !verbose_msg_clients then
-                              lprintf_nl () "CLIENT %d: RTIMEOUT (%d)" (client_num c)
+                              lprintf_nl "CLIENT %d: RTIMEOUT (%d)" (client_num c)
                               (last_time ())
                               ;
                             close sock Closed_for_timeout
@@ -1135,7 +1124,7 @@ let connect_client c =
                   let file = c.client_file in
 
                   if !verbose_msg_clients then
-                    lprintf_nl () "READY TO DOWNLOAD FILE";
+                    lprintf_nl "READY TO DOWNLOAD FILE";
 
                   send_init !!client_uid file.file_id sock;
 (* Fabrice: Initialize the client bitmap and uploader fields to <> None *)
@@ -1150,7 +1139,7 @@ let connect_client c =
                     (BTHeader (client_parse_header !counter (ref (Some c)) true))
                 end
             with e ->
-                lprintf_nl () "Exception %s while connecting to client"
+                lprintf_nl "Exception %s while connecting to client"
                   (Printexc2.to_string e);
                 disconnect_client c (Closed_for_exception e)
         );
@@ -1179,19 +1168,19 @@ let listen () =
                 to connect to us
               *)
               let ip = (Ip.of_inet_addr from_ip) in
-              if !verbose_sources > 1 then lprintf_nl () "CONNECTION RECEIVED FROM %s"
+              if !verbose_sources > 1 then lprintf_nl "CONNECTION RECEIVED FROM %s"
                 (Ip.to_string (Ip.of_inet_addr from_ip))
               ;
               (*Reject this connection if we don't want
                 to bypass the max_connection parameter
               *)
               if can_open_connection connection_manager &&
-                (match Ip_set.match_ip !Ip_set.bl ip with
+                (match !Ip.banned ip with
                    None -> true
-                 | Some br ->
+                 | Some reason ->
                      if !verbose_connect then
-                       lprintf_nl () "%s:%d blocked: %s"
-                         (Ip.to_string ip) from_port br.blocking_description;
+                       lprintf_nl "%s:%d blocked: %s"
+                         (Ip.to_string ip) from_port reason;
                      false)
               then
                 begin
@@ -1239,7 +1228,7 @@ let listen () =
     ()
   with e ->
       if !verbose_connect then
-        lprintf_nl () "Exception %s while init bittorrent server"
+        lprintf_nl "Exception %s while init bittorrent server"
           (Printexc2.to_string e)
 
 
@@ -1283,7 +1272,7 @@ let resume_clients file =
              with _ -> ())
       with e ->
           if !verbose_connect then
-            lprintf_nl () "Exception %s in resume_clients"   (Printexc2.to_string e)
+            lprintf_nl "Exception %s in resume_clients"   (Printexc2.to_string e)
   ) file.file_clients
 
 (** Check if the value replied by the tracker is correct.
@@ -1295,11 +1284,11 @@ let resume_clients file =
 let chk_keyval key n url name =
   let int_n = (Int64.to_int n) in
   if !verbose_msg_clients then
-    lprintf_nl () "Reply from %s in file: %s has %s: %d" url name key int_n;
+    lprintf_nl "Reply from %s in file: %s has %s: %d" url name key int_n;
   if int_n > -1 then
     int_n
   else begin
-     lprintf_nl () "Reply from %s in file: %s has an invalid %s value: %d" url name key int_n;
+     lprintf_nl "Reply from %s in file: %s has an invalid %s value: %d" url name key int_n;
      0
    end
 
@@ -1320,13 +1309,13 @@ let get_sources_from_tracker file =
     let tracker_reply =
       try
         File.to_string filename
-      with e -> lprintf_nl () "Empty reply from tracker"; ""
+      with e -> lprintf_nl "Empty reply from tracker"; ""
     in
     let v =
        match tracker_reply with
        | "" ->
         if !verbose_connect then
-          lprintf_nl () "Empty reply from tracker";
+          lprintf_nl "Empty reply from tracker";
         Bencode.decode ""
        | _ -> Bencode.decode tracker_reply
     in
@@ -1341,10 +1330,10 @@ let get_sources_from_tracker file =
                 (* On failure, remove the faulty tracker from file.file_trackers list *)
 		t.tracker_enabled <- false;
 		(* remove_tracker t.tracker_url file; *)
-                lprintf_nl () "Failure from Tracker %s in file: %s Reason: %s\nBT: Tracker %s disabled for failure"
+                lprintf_nl "Failure from Tracker %s in file: %s Reason: %s\nBT: Tracker %s disabled for failure"
                   t.tracker_url file.file_name failure t.tracker_url
             | String "warning message", String warning ->
-                lprintf_nl () "Warning from Tracker %s in file: %s Reason: %s" t.tracker_url file.file_name warning
+                lprintf_nl "Warning from Tracker %s in file: %s Reason: %s" t.tracker_url file.file_name warning
             | String "interval", Int n ->
                 t.tracker_interval <- chk_keyval (Bencode.print key) n t.tracker_url file.file_name;
                 (* in case we don't receive "min interval" *)
@@ -1375,11 +1364,11 @@ let get_sources_from_tracker file =
             | String "key", String n ->
                 t.tracker_key <- n;
                 if !verbose_msg_clients then
-                  lprintf_nl () "%s in file: %s has key: %s" t.tracker_url file.file_name n
+                  lprintf_nl "%s in file: %s has key: %s" t.tracker_url file.file_name n
             | String "tracker id", String n ->
                 t.tracker_id <- n;
                 if !verbose_msg_clients then
-                  lprintf_nl () "%s in file: %s has tracker id %s" t.tracker_url file.file_name n
+                  lprintf_nl "%s in file: %s has tracker id %s" t.tracker_url file.file_name n
 
             | String "peers", List list ->
                 List.iter (fun v ->
@@ -1407,17 +1396,17 @@ let get_sources_from_tracker file =
                           !peer_id <> !!client_uid &&
                           !peer_ip != Ip.null &&
                           !port <> 0 &&
-                          (match match_ip !Ip_set.bl !peer_ip with
+                          (match !Ip.banned !peer_ip with
                               None -> true
-                            | Some br ->
+                            | Some reason ->
                                 if !verbose_connect then
-                                  lprintf_nl () "%s:%d blocked: %s"
-                                    (Ip.to_string !peer_ip) !port br.blocking_description;
+                                  lprintf_nl "%s:%d blocked: %s"
+                                    (Ip.to_string !peer_ip) !port reason;
                                 false)
                         then
                           let _ = new_client file !peer_id (!peer_ip,!port)
                           in
-                          if !verbose_sources > 1 then lprintf_nl () "Received %s:%d" (Ip.to_string !peer_ip)
+                          if !verbose_sources > 1 then lprintf_nl "Received %s:%d" (Ip.to_string !peer_ip)
                           !port;
                           ()
                     | _ -> assert false
@@ -1438,12 +1427,12 @@ let get_sources_from_tracker file =
             | String "private", Int n -> ()
               (* TODO: if set to 1, disable peer exchange *)
 
-            | _ -> lprintf_nl () "received unknown entry in answer from tracker: %s : %s" (Bencode.print key) (Bencode.print value)
+            | _ -> lprintf_nl "received unknown entry in answer from tracker: %s : %s" (Bencode.print key) (Bencode.print value)
         ) list;
        (*Now, that we have added new clients to a file, it's time
          to connect to them*)
         if !verbose_sources > 0 then
-          lprintf_nl () "get_sources_from_tracker: got %i source(s) for file %s"
+          lprintf_nl "get_sources_from_tracker: got %i source(s) for file %s"
             t.tracker_last_clients_num file.file_name;
         resume_clients file
 
@@ -1472,7 +1461,7 @@ let recover_files () =
               (try
                   connect_trackers file "" (fun _ _ -> ()) with _ -> ())
           | FilePaused -> () (*when we are paused we do nothing, not even logging this vvvv*)
-          | s -> lprintf_nl () "Other state %s!!" (string_of_state s)
+          | s -> lprintf_nl "Other state %s!!" (string_of_state s)
       ) !current_files
 
 let upload_buffer = String.create 100000
@@ -1520,7 +1509,7 @@ let rec iter_upload sock c =
 (*          lprintf "sending piece\n"; *)
           send_client c (Piece (num, pos, upload_buffer, 0, len));
           iter_upload sock c
-	with e -> if !verbose then lprintf_nl ()
+  with e -> if !verbose then lprintf_nl
 		    "Exception %s in iter_upload" (Printexc2.to_string e)
         end else
         begin
@@ -1572,7 +1561,7 @@ let file_stop file =
     if file.file_tracker_connected then
     begin
       connect_trackers file "stopped" (fun _ _ ->
-          lprintf_nl () "Tracker return: stopped %s" file.file_name;
+          lprintf_nl "Tracker return: stopped %s" file.file_name;
           file.file_tracker_connected <- false)
     end
 
@@ -1594,6 +1583,6 @@ let _ =
   );
   client_ops.op_client_enter_upload_queue <- (fun c ->
       if !verbose_msg_clients then
-        lprintf_nl () "Client %d: client_enter_upload_queue" (client_num c);
+        lprintf_nl "Client %d: client_enter_upload_queue" (client_num c);
       ready_for_upload (as_client c));
   network.op_network_connected_servers <- (fun _ -> []);
