@@ -68,11 +68,6 @@ module StatsOption = struct
     let t = define_option_class "Stat" value_to_stat stat_to_value
   end
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[BT] "
-    (log_time ()); lprintf_nl2
-
 module ClientOption = struct
 
     let value_to_client file v =
@@ -210,7 +205,7 @@ let value_to_file file_size file_state assocs =
   (match file.file_swarmer with
       None -> ()
     | Some swarmer ->
-        Int64Swarmer.value_to_swarmer swarmer assocs;
+        CommonSwarming.value_to_swarmer swarmer assocs;
   );
 
 (*
@@ -219,7 +214,7 @@ let value_to_file file_size file_state assocs =
         (get_value  "file_sources" (
           value_to_list (ClientOption.of_value file)))
     with e ->
-        lprintf_nl () "Exception %s while loading sources"
+        lprintf_nl "Exception %s while loading sources"
           (Printexc2.to_string e);
   );
 *)
@@ -254,7 +249,7 @@ send us more clients.
       ("file_hashes", array_to_value
           (to_value Sha1.option) file.file_chunks) ::
       ("file_files", list_to_value
-          (fun (name, p1) ->
+          (fun (name, p1, _) ->
             SmallList [string_to_value name; int64_to_value p1])
         file.file_files) ::
       assocs
@@ -262,10 +257,10 @@ send us more clients.
     match file.file_swarmer with
       None -> assocs
     | Some swarmer ->
-        Int64Swarmer.swarmer_to_value swarmer assocs
+        CommonSwarming.swarmer_to_value swarmer assocs
   with
     e ->
-      lprintf_nl () "exception %s in file_to_value"
+      lprintf_nl "exception %s in file_to_value"
         (Printexc2.to_string e); raise e
 
 
