@@ -121,10 +121,14 @@ let max_request_len = Int64.of_int (1 lsl 16)
 let bt_download_counter = ref Int64.zero
 let bt_upload_counter = ref Int64.zero
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[BT] "
-    (log_time ()); lprintf_nl2
+let log_prefix = "[BT]"
+
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
+
 
 let check_if_interesting file c =
 
@@ -133,25 +137,25 @@ let check_if_interesting file c =
         None -> assert false
       | Some up -> up
     in
-    let swarmer = Int64Swarmer.uploader_swarmer up in
+    let swarmer = CommonSwarming.uploader_swarmer up in
     let must_send =
 (* The client has nothing to propose to us *)
-      (not (Int64Swarmer.is_interesting up )) &&
+      (not (CommonSwarming.is_interesting up )) &&
 (* All the requested ranges are useless *)
       (List.filter (fun (_,_,r) ->
-            let x,y = Int64Swarmer.range_range r in
+            let x,y = CommonSwarming.range_range r in
             x < y) c.client_ranges_sent = []) &&
       (match c.client_range_waiting with
           None -> true
         | Some (x,y,r) ->
-            let x,y = Int64Swarmer.range_range r in
+            let x,y = CommonSwarming.range_range r in
             x < y) &&
 (* The current block is also useless *)
       (match c.client_block with
           None -> true
         | Some b ->
-            let block_num = Int64Swarmer.block_num swarmer b in
-            let bitmap = Int64Swarmer.verified_bitmap swarmer in
+            let block_num = CommonSwarming.block_num swarmer b in
+            let bitmap = CommonSwarming.verified_bitmap swarmer in
             bitmap.[block_num] <> '3')
     in
     if must_send then
@@ -164,14 +168,19 @@ let check_if_interesting file c =
 let add_torrent_infos file trackers =
   file.file_trackers <- trackers @ file.file_trackers
 
-let create_temp_file file_temp file_files =
-  if !verbose then lprintf_nl () "create_temp_file %s" file_temp;
+let create_temp_file file_temp file_files file_state =
+  if !verbose then lprintf_nl "create_temp_file %s - %s" file_temp (string_of_state file_state);
+  let writable =
+    if file_state = FileShared then
+      false
+    else
+      true
+  in
   let file_fd =
     if file_files <> [] then
-      Unix32.create_multifile file_temp
-        true file_files
+      Unix32.create_multifile file_temp writable file_files
     else
-      Unix32.create_rw file_temp
+      Unix32.create_diskfile file_temp writable
   in
   if Unix32.destroyed file_fd then
     failwith
@@ -180,6 +189,9 @@ let create_temp_file file_temp file_files =
         file_temp);
   file_fd
 
+let can_handle_tracker t =
+  String2.check_prefix (String.lowercase t.tracker_url) "http://"
+
 let rec set_trackers file file_trackers =
   match file_trackers with
     | [] -> ()
@@ -187,7 +199,7 @@ let rec set_trackers file file_trackers =
 	if not (List.exists (fun tracker -> 
 			       tracker.tracker_url = url
 			    ) file.file_trackers) then 
-	  file.file_trackers <- {
+	  let t = {
             tracker_url = url;
             tracker_interval = 600;
             tracker_min_interval = 600;
@@ -201,14 +213,16 @@ let rec set_trackers file file_trackers =
             tracker_id = "";
             tracker_key = "";
 	    tracker_enabled = true
-          } :: file.file_trackers;
+          } in
+	  t.tracker_enabled <- can_handle_tracker t;
+	  file.file_trackers <-  t :: file.file_trackers;
 	set_trackers file q
 
 let new_file file_id t torrent_diskname file_temp file_state =
   try
     Hashtbl.find files_by_uid file_id
   with Not_found ->
-      let file_fd = create_temp_file file_temp t.torrent_files in
+      let file_fd = create_temp_file file_temp t.torrent_files file_state in
       let rec file = {
           file_tracker_connected = false;
           file_file = file_impl;
@@ -225,7 +239,7 @@ let new_file file_id t torrent_diskname file_temp file_state =
           file_swarmer = None;
           file_trackers = [];
           file_chunks = t.torrent_pieces;
-          file_files = t.torrent_files;
+          file_files = (List.map (fun (file,size) -> (file,size,None)) t.torrent_files);
           file_blocks_downloaded = [];
           file_uploaded = Int64.zero;
           file_torrent_diskname = torrent_diskname;
@@ -247,12 +261,12 @@ let new_file file_id t torrent_diskname file_temp file_state =
       else
         set_trackers file [t.torrent_announce];
       if file_state <> FileShared then begin
-          let kernel = Int64Swarmer.create_swarmer file_temp (file_size file)
+          let kernel = CommonSwarming.create_swarmer file_temp (file_size file)
             (min max_range_len file.file_piece_size) in
-          let swarmer = Int64Swarmer.create kernel (as_file file)
+          let swarmer = CommonSwarming.create kernel (as_file file)
             file.file_piece_size in
           file.file_swarmer <- Some swarmer;
-          Int64Swarmer.set_verified swarmer (fun _ num ->
+          CommonSwarming.set_verified swarmer (fun _ num ->
               file.file_blocks_downloaded <- (num) ::
               file.file_blocks_downloaded;
               file_must_update file;
@@ -272,7 +286,7 @@ let new_file file_id t torrent_diskname file_temp file_state =
               ) file.file_clients
 
           );
-          Int64Swarmer.set_verifier swarmer (Verification
+          CommonSwarming.set_verifier swarmer (Verification
               (Array.map (fun sha1 -> Sha1 sha1) file.file_chunks));
         end;
       current_files := file :: !current_files;
@@ -362,6 +376,7 @@ let decode_az_style s =
       | "BS" -> Brand_btslave
       | "BX" -> Brand_bittorrentx
       | "CT" -> Brand_ctorrent
+      | "CD" -> Brand_ctorrent
       | "LT" -> Brand_libtorrent
       | "MT" -> Brand_moonlighttorrent
       | "SB" -> Brand_swiftbit
@@ -377,12 +392,27 @@ let decode_az_style s =
       | "MP" -> Brand_moopolice
       | "UT" -> Brand_utorrent
       | "KT" -> Brand_ktorrent
+      | "LP" -> Brand_lphant
+      | "TR" -> Brand_transmission
+      | "HN" -> Brand_hydranode
+      | "RT" -> Brand_retriever
       | _ -> Brand_unknown
     in
     if brand = Brand_unknown then None else
       let version = 
-        if brand = Brand_bitcomet then (String.sub s 4 1) ^ "." ^ (String.sub s 5 2) 
-        else (dot_string (String.sub s 3 4)) 
+        match brand with
+          | Brand_bitcomet -> (String.sub s 4 1) ^ "." ^ (String.sub s 5 2)
+          | Brand_utorrent -> (String.sub s 3 1) ^ "." ^ (String.sub s 4 1) ^ "." ^ (String.sub s 5 1)
+          | Brand_ctorrent 
+          | Brand_transmission -> (String.sub s 3 2) ^ "." ^ (String.sub s 5 2)
+          | Brand_ktorrent -> 
+              let x = match s.[5] with 
+                | 'R' -> " RC" ^ (String.sub s 6 1)
+                | 'D' -> " Dev"
+                | _ -> ""
+              in
+              (String.sub s 3 1) ^ "." ^ (String.sub s 4 1) ^ x
+          | _ -> (dot_string (String.sub s 3 4)) 
       in
       Some (brand, version)
   end else
@@ -396,6 +426,7 @@ let decode_tornado_style s =
      | "S" -> Brand_shadow
      | "A" -> Brand_abc
      | "U" -> Brand_upnp
+     | "O" -> Brand_osprey
      | _ -> Brand_unknown
     in
     let bv = ref None in
@@ -438,15 +469,18 @@ let decode_simple_style s =
       (0, "S587Plus", Brand_btplus, "");
       (5, "Azureus", Brand_azureus, "2.0.3.2");
       (0, "-G3", Brand_g3torrent, "");
+      (0, "-AR", Brand_arctic, "");
       (4, "btfans", Brand_simplebt, "");
       (0, "btuga", Brand_btugaxp, "");
+      (0, "BTuga", Brand_btugaxp, "");
       (0, "DansClient", Brand_xantorrent, "");
       (0, "Deadman Walking-", Brand_deadmanwalking, "");
       (0, "346-", Brand_torrenttopia, "");
       (0, "271-", Brand_greedbt, "2.7.1");
-      (0, "BG", Brand_btgetit, "");
+      (10, "BG", Brand_btgetit, "");
       (0, "a00---0", Brand_swarmy, "");
       (0, "a02---0", Brand_swarmy, "");
+      (0, "10-------", Brand_jvtorrent, "");
       (0, "T00---0", Brand_teeweety, "") ]
   in
   let len = List.length !simple_list in
@@ -631,7 +665,7 @@ let parse_software s =
   let default = (Brand_unknown, "") in
   let rec iter l =
     match l with
-      [] -> lprintf_nl () "Unknown BT client software version, report the next line to http://mldonkey.sourceforge.net/UnknownBtClients%s\nBTUC:\"%s\"" Autoconf.current_version (String.escaped s);
+      [] -> lprintf_nl "Unknown BT client software version, report the next line to http://mldonkey.sourceforge.net/UnknownBtClients%s\nBTUC:\"%s\"" Autoconf.current_version (String.escaped s);
             default
       | d :: t -> match (d s) with 
                   | None -> iter t
@@ -711,7 +745,7 @@ let remove_client c =
 let remove_tracker url file =
   if !verbose_msg_servers then
     List.iter (fun tracker ->
-      lprintf_nl () "Old tracker list :%s" tracker.tracker_url
+      lprintf_nl "Old tracker list :%s" tracker.tracker_url
     ) file.file_trackers;
   List.iter (fun bad_tracker ->
     if bad_tracker.tracker_url = url then
@@ -719,10 +753,11 @@ let remove_tracker url file =
   ) file.file_trackers;
   if !verbose_msg_servers then
     List.iter (fun tracker ->
-      lprintf_nl () "New tracker list :%s" tracker.tracker_url
+      lprintf_nl "New tracker list :%s" tracker.tracker_url
     ) file.file_trackers
 
 let torrents_directory = "torrents"
+let new_torrents_directory = Filename.concat torrents_directory "incoming"
 let downloads_directory = Filename.concat torrents_directory "downloads"
 let tracked_directory = Filename.concat torrents_directory "tracked"
 let seeded_directory = Filename.concat torrents_directory "seeded"
