@@ -50,15 +50,7 @@ open Gettext
 let _s x = _s "BTInteractive" x
 let _b x = _b "BTInteractive" x
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[BT] "
-      (log_time ()); lprintf_nl2
-
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[BT] "
-    (log_time ()); lprintf
+exception Already_exists
 
 let op_file_all_sources file =
   let list = ref [] in
@@ -81,11 +73,11 @@ let op_file_files file impl =
   match file.file_swarmer with
     None -> [CommonFile.as_file impl]
   | Some swarmer ->
-      Int64Swarmer.subfiles swarmer
+      CommonSwarming.subfiles swarmer
 
 let op_file_debug file =
   let buf = Buffer.create 100 in
-(*      Int64Swarmer.debug_print buf file.file_swarmer; *)
+(*      CommonSwarming.debug_print buf file.file_swarmer; *)
   Hashtbl.iter (fun _ c ->
       Printf.bprintf buf "Client %d: %s\n" (client_num c)
       (match c.client_sock with
@@ -97,7 +89,7 @@ let op_file_debug file =
   Buffer.contents buf
 
 let op_file_commit file new_name =
-  Int64Swarmer.remove_swarmer file.file_swarmer;
+  CommonSwarming.remove_swarmer file.file_swarmer;
   file.file_swarmer <- None;
   if file_state file <> FileShared then
     begin
@@ -106,14 +98,16 @@ let op_file_commit file new_name =
       set_file_state file FileShared;
 
       if Unix32.destroyed (file_fd file) then
-        if !verbose then lprintf_nl () "op_file_commit: FD is destroyed... repairing";
+        if !verbose then lprintf_nl "op_file_commit: FD is destroyed... repairing";
 
 (* During the commit operation, for security, the file_fd is destroyed. So
   we create it again to be able to share this file again. *)
-      set_file_fd (as_file file) (create_temp_file new_name file.file_files);
+      set_file_fd
+        (as_file file)
+        (create_temp_file new_name (List.map (fun (file,size,_) -> (file,size)) file.file_files) (file_state file));
 
       if Unix32.destroyed (file_fd file) then
-        lprintf_nl () "op_file_commit: FD is destroyed... could not repair!";
+        lprintf_nl "op_file_commit: FD is destroyed... could not repair!";
 
       let new_torrent_diskname =
         Filename.concat seeded_directory
@@ -122,7 +116,7 @@ let op_file_commit file new_name =
       (try
           Unix2.rename file.file_torrent_diskname new_torrent_diskname;
         with _ ->
-          (lprintf_nl () "op_file_commit: failed to rename %s to %s"
+          (lprintf_nl "op_file_commit: failed to rename %s to %s"
               file.file_torrent_diskname new_torrent_diskname));
       file.file_torrent_diskname <- new_torrent_diskname;
 
@@ -263,12 +257,17 @@ let op_file_print_html file buf =
   print_first_tracker file.file_trackers;
 
   let cntr = ref 0 in
-  List.iter (fun (filename, size) ->
+  List.iter (fun (filename, size, magic) ->
     Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-%d\\\"\\>" (html_mods_cntr ());
     let fs = Printf.sprintf "File %d" !cntr in
+    let magic_string =
+      match magic with
+        None -> ""
+      | Some magic -> Printf.sprintf " / %s" magic
+    in
     html_mods_td buf [
       (fs, "sr br", fs);
-      ("", "sr", (Printf.sprintf "%s (%Ld bytes)" filename size)) 
+      ("", "sr", (Printf.sprintf "%s (%Ld bytes)%s" filename size magic_string)) 
     ];
     incr cntr;
   ) file.file_files
@@ -279,7 +278,7 @@ let op_file_print_sources_html file buf =
 
       let chunks = (match file.file_swarmer with
             None -> "" | Some swarmer ->
-              Int64Swarmer.verified_bitmap swarmer) in
+              CommonSwarming.verified_bitmap swarmer) in
 
       let header_list = [
         ( "1", "srh br ac", "Client number", "Num" ) ;
@@ -367,19 +366,19 @@ let op_file_print_sources_html file buf =
     end
 
 let op_file_check file =
-  lprintf_nl () "Checking chunks of %s" file.file_name;
+  lprintf_nl "Checking chunks of %s" file.file_name;
   match file.file_swarmer with
     None ->
-      lprintf_nl () "verify_chunks: no swarmer to verify chunks"
+      lprintf_nl "verify_chunks: no swarmer to verify chunks"
   | Some swarmer ->
-      Int64Swarmer.verify_all_chunks swarmer true
+      CommonSwarming.verify_all_chunks swarmer true
 
 let remove_all_clients file =
   Hashtbl.clear file.file_clients; 
   file.file_clients_num <- 0
 
 let op_file_cancel file =
-  Int64Swarmer.remove_swarmer file.file_swarmer;
+  CommonSwarming.remove_swarmer file.file_swarmer;
   file.file_swarmer <- None;
   BTClients.file_stop file;
   remove_file file;
@@ -399,7 +398,7 @@ let op_file_info file =
 
   let last_seen = match file.file_swarmer with
       None -> [| last_time () |]
-    | Some swarmer -> Int64Swarmer.compute_last_seen swarmer in
+    | Some swarmer -> CommonSwarming.compute_last_seen swarmer in
 
     { (impl_file_info file.file_file) with
 
@@ -408,11 +407,11 @@ let op_file_info file =
     P.file_names = [file.file_name, P.noips()];
     P.file_chunks = (match file.file_swarmer with
         None -> "" | Some swarmer ->
-          Int64Swarmer.verified_bitmap swarmer);
+          CommonSwarming.verified_bitmap swarmer);
     P.file_availability =
     [network.network_num,(match file.file_swarmer with
           None -> "" | Some swarmer ->
-            Int64Swarmer.availability swarmer)];
+            CommonSwarming.availability swarmer)];
 
     P.file_chunks_age = last_seen;
     P.file_uids = [Uid.create (BTUrl file.file_id)];
@@ -463,10 +462,15 @@ let load_torrent_string s =
     downloads_directory
     torrent.torrent_name ^ ".torrent"
     in
+  if Sys.file_exists torrent_diskname then
+    begin
+      if !verbose then lprintf_nl "load_torrent_string: %s already exists, ignoring" torrent_diskname;
+      raise Already_exists
+    end;
   File.from_string torrent_diskname s;
 
   if !verbose then
-    lprintf_nl () "Starting torrent download with diskname: %s"
+    lprintf_nl "Starting torrent download with diskname: %s"
         torrent_diskname;
   let file = new_download file_id torrent torrent_diskname in
   BTClients.get_sources_from_tracker file;
@@ -476,7 +480,7 @@ let load_torrent_string s =
 
 let load_torrent_file filename =
   if !verbose then
-    lprintf_nl () "load_torrent_file %s" filename;
+    lprintf_nl "load_torrent_file %s" filename;
   let s = File.to_string filename in
   (* Delete the torrent if it is in the downloads dir. because it gets saved
      again under the torrent name and we don't want to clutter up this dir. .*)
@@ -489,21 +493,21 @@ let parse_tracker_reply file t filename =
 (*This is the function which will be called by the http client
 for parsing the response*)
 (* Interested only in interval*)
-  if !verbose_msg_servers then lprintf_nl () "Filename %s" filename;
+  if !verbose_msg_servers then lprintf_nl "Filename %s" filename;
     let tracker_reply =
       try
         File.to_string filename
-      with e -> lprintf_nl () "Empty reply from tracker"; ""
+      with e -> lprintf_nl "Empty reply from tracker"; ""
     in
     let v =
        match tracker_reply with
        | "" ->
         if !verbose_connect then
-          lprintf_nl () "Empty reply from tracker";
+          lprintf_nl "Empty reply from tracker";
         Bencode.decode ""
        | _ -> Bencode.decode tracker_reply
     in
-  if !verbose_msg_servers then lprintf_nl () "Received: %s" (Bencode.print v);
+  if !verbose_msg_servers then lprintf_nl "Received: %s" (Bencode.print v);
   t.tracker_interval <- 600;
   match v with
     Dictionary list ->
@@ -511,9 +515,9 @@ for parsing the response*)
           match (key, value) with
             String "interval", Int n ->
               t.tracker_interval <- Int64.to_int n;
-              if !verbose_msg_servers then lprintf_nl () ".. interval %d .." t.tracker_interval
+              if !verbose_msg_servers then lprintf_nl ".. interval %d .." t.tracker_interval
           | String "failure reason", String failure ->
-                lprintf_nl () "Failure from Tracker in file: %s Reason: %s" file.file_name failure
+                lprintf_nl "Failure from Tracker in file: %s Reason: %s" file.file_name failure
           (*TODO: merge with f from get_sources_from_tracker and parse the rest of the answer, too.
             also connect to the sources we receive or instruct tracker to send none, perhaps based
             on an config option. firewalled people could activate the option and then seed torrents, too.*)
@@ -522,7 +526,7 @@ for parsing the response*)
   | _ -> assert false
 
 let try_share_file torrent_diskname =
-  if !verbose_share then lprintf_nl () "try_share_file: %s" torrent_diskname;
+  if !verbose_share then lprintf_nl "try_share_file: %s" torrent_diskname;
   let s = File.to_string torrent_diskname in
   let file_id, torrent = BTTorrent.decode_torrent s in
 
@@ -539,7 +543,7 @@ let try_share_file torrent_diskname =
               let filename =
                 Filename.concat sh.shdir_dirname torrent.torrent_name
               in
-              if !verbose_share then lprintf_nl () "Checking for %s" filename;
+              if !verbose_share then lprintf_nl "Checking for %s" filename;
               if Sys.file_exists filename then filename else
                 iter tail
             else
@@ -551,13 +555,13 @@ let try_share_file torrent_diskname =
     let file = new_file file_id torrent torrent_diskname
         filename FileShared in
     BTShare.must_share_file file;
-    if !verbose_share then lprintf_nl () "Sharing file %s" filename;
+    if !verbose_share then lprintf_nl "Sharing file %s" filename;
     BTClients.connect_trackers file "started"
       (parse_tracker_reply file)
   with
   | Not_found ->
       (* if the torrent is still there while the file is gone, remove the torrent *)
-      if !verbose_share then lprintf_nl () "Removing torrent for %s" s;
+      if !verbose_share then lprintf_nl "Removing torrent for %s" s;
       let new_torrent_diskname =
         Filename.concat old_directory
           (Filename.basename torrent_diskname)
@@ -565,21 +569,21 @@ let try_share_file torrent_diskname =
       (try
           Unix2.rename torrent_diskname new_torrent_diskname;
         with _ ->
-          (lprintf_nl () "Failed to rename %s to %s"
+          (lprintf_nl "Failed to rename %s to %s"
               torrent_diskname new_torrent_diskname));
 (*
       (try Sys.remove torrent_diskname with e ->
           if !verbose_share then
-            lprintf_nl () "Error: %s while removing torrent %s" (Printexc2.to_string e) s)
+            lprintf_nl "Error: %s while removing torrent %s" (Printexc2.to_string e) s)
 *)
   | e ->
-      lprintf_nl () "Cannot share torrent %s for %s"
+      lprintf_nl "Cannot share torrent %s for %s"
         torrent_diskname (Printexc2.to_string e)
 
 (* Call one minute after start, and then every 20 minutes. Should
   automatically contact the tracker. *)
 let share_files _ =
-  if !verbose_share then lprintf_nl () "share_files";
+  if !verbose_share then lprintf_nl "share_files";
   List.iter (fun dir ->
       let filenames = Unix2.list_directory dir in
       List.iter (fun file ->
@@ -590,11 +594,11 @@ let share_files _ =
   let shared_files_copy = !current_files in
  (* if the torrent is gone while the file is still shared, remove the share *)
   List.iter (fun file ->
-      (* if !verbose_share then lprintf_nl () "Checking torrent share for %s" file.file_torrent_diskname; *)
+      (* if !verbose_share then lprintf_nl "Checking torrent share for %s" file.file_torrent_diskname; *)
       if not (Sys.file_exists file.file_torrent_diskname) &&
         file_state file = FileShared then
         begin
-          if !verbose_share then lprintf_nl () "Removing torrent share for %s" file.file_torrent_diskname;
+          if !verbose_share then lprintf_nl "Removing torrent share for %s" file.file_torrent_diskname;
           BTClients.file_stop file;
           remove_file file;
           BTClients.disconnect_clients file;
@@ -602,31 +606,67 @@ let share_files _ =
         end
   ) shared_files_copy
 
+let scan_new_torrents_directory () =
+  let filenames = Unix2.list_directory new_torrents_directory in
+  List.iter (fun file ->
+    let file = Filename.concat new_torrents_directory file in
+    if not (Unix2.is_directory file) then
+    try
+      load_torrent_file file;
+      (try Sys.remove file with _ -> ())
+    with e -> lprintf_nl "Error %s in scan_new_torrents_directory" (Printexc2.to_string e)
+  ) filenames
+
 let retry_all_ft () =
   Hashtbl.iter (fun _ ft ->
       try ft.ft_retry ft with e ->
-          lprintf_nl () "ft_retry: exception %s" (Printexc2.to_string e)
+          lprintf_nl "ft_retry: exception %s" (Printexc2.to_string e)
   ) ft_by_num
 
+let file_magic_check () =
+  if !Autoconf.magic_works then begin
+    if !verbose then lprintf_nl "computing sub_file magic values";
+    let check_magic file = 
+      match Magic.M.magic_fileinfo file false with
+        None -> None
+      | Some s -> Some (HashMagic.merge CommonGlobals.files_magic s)
+    in
+    Hashtbl.iter (fun _ file ->
+      let updated = ref false in
+      let new_file_files = ref [] in
+      List.iter (fun (filename, size, magic) ->
+        let subfile = Filename.concat (file_disk_name file) filename in
+        let new_magic =
+          match magic with
+            None -> check_magic subfile
+          | Some magic when magic = "data" || magic = "empty" -> check_magic subfile
+          | _ -> magic
+        in
+        if new_magic <> magic then updated := true;
+        new_file_files := (filename, size, new_magic) :: !new_file_files
+        ) file.file_files;
+        if !updated then file.file_files <- !new_file_files
+    ) files_by_uid
+  end
+
 let load_torrent_from_web r ft =
   if !verbose then
-      lprintf_nl () "Loading torrent from web";
+      lprintf_nl "Loading torrent from web";
   let module H = Http_client in
 
   if !verbose then
-      lprintf_nl () "calling...";
+      lprintf_nl "calling...";
   H.wget r (fun filename ->
       if !verbose then
-          lprintf_nl () "done...";
+          lprintf_nl "done...";
       if ft_state ft = FileDownloading then begin
           load_torrent_file filename;
-          file_cancel (as_ft ft);
-	  (try Sys.remove filename with _ -> ())
+          file_cancel (as_ft ft)
         end)
 
 let valid_torrent_extension url =
   let ext = String.lowercase (Filename2.last_extension url) in
-  if !verbose then lprintf_nl () "Last extension: %s" ext;
+  if !verbose then lprintf_nl "Last extension: %s" ext;
   if ext = ".torrent" || ext = ".tor" then true else false
 
 let get_regexp_string text r =
@@ -639,7 +679,7 @@ let op_network_parse_url url =
   let location_regexp = "Location: \\(.*\\)" in
   try
     let real_url = get_regexp_string url (Str.regexp location_regexp) in
-    if !verbose then lprintf_nl () "Loading %s, really %s" url real_url;
+    if !verbose then lprintf_nl "Loading %s, really %s" url real_url;
     if (valid_torrent_extension real_url)
        || (String2.contains url "Content-Type: application/x-bittorrent")
       then (
@@ -651,15 +691,14 @@ let op_network_parse_url url =
             H.req_proxy = !CommonOptions.http_proxy;
             H.req_user_agent = get_user_agent ();
             H.req_referer = (
-              let referers = !!BTOptions.referers in
               let (rule_search,rule_value) =
                 try (List.find(fun (rule_search,rule_value) ->
                         Str.string_match (Str.regexp rule_search) real_url 0
-                    ) referers )
+                    ) !!referers )
                 with Not_found -> ("",real_url) in
               Some (Url.of_string rule_value) );
             H.req_headers = (try
-              let cookies = List.assoc u.Url.server !!BTOptions.cookies in
+              let cookies = List.assoc u.Url.server !!cookies in
               [ ( "Cookie", List.fold_left (fun res (key, value) ->
                       if res = "" then
                         key ^ "=" ^ value
@@ -675,7 +714,7 @@ let op_network_parse_url url =
         let ft = new_ft file_diskname in
         ft.ft_retry <- load_torrent_from_web r ;
         load_torrent_from_web r ft;
-        if !verbose then lprintf_nl () "wget started";
+        if !verbose then lprintf_nl "wget started";
         "started download", true
       )
     else
@@ -684,21 +723,23 @@ let op_network_parse_url url =
     | Not_found ->
       if (valid_torrent_extension url) then
         try
-          if !verbose then lprintf_nl () "Not_found and trying to load %s" url;
-          load_torrent_file url;
-          "", true
+          if !verbose then lprintf_nl "Not_found and trying to load %s" url;
+          try
+            load_torrent_file url;
+            "", true
+          with Already_exists -> "A torrent with this name is already in the download queue", false
         with e ->
-          lprintf_nl () "Exception %s while 2nd loading" (Printexc2.to_string e);
+          lprintf_nl "Exception %s while 2nd loading" (Printexc2.to_string e);
 	  let s = Printf.sprintf "Can not load load torrent file: %s"
 	    (Printexc2.to_string e) in
           s, false
       else
         begin
-          if !verbose then lprintf_nl () "Not_found and url has non valid torrent extension: %s" url;
+          if !verbose then lprintf_nl "Not_found and url has non valid torrent extension: %s" url;
           "Not_found and url has non valid torrent extension", false
         end
     | e ->
-       lprintf_nl () "Exception %s while loading" (Printexc2.to_string e);
+       lprintf_nl "Exception %s while loading" (Printexc2.to_string e);
        let s = Printf.sprintf "Can not load load torrent file: %s"
 	 (Printexc2.to_string e) in
        s, false
@@ -800,7 +841,7 @@ let get_default_tracker () =
 
 let compute_torrent filename announce comment = 
   let announce = if announce = "" then get_default_tracker () else announce in
-  if !verbose then lprintf_nl () "compute_torrent: [%s] [%s] [%s]"
+  if !verbose then lprintf_nl "compute_torrent: [%s] [%s] [%s]"
    filename announce comment;
   let basename = Filename.basename filename in
   let torrent = Filename.concat seeded_directory
@@ -911,6 +952,22 @@ let commands =
       _s ""
     ), _s ":\t\t\tremove all old .torrent files";
 
+    "startbt", "Network/Bittorrent", Arg_one (fun url o ->
+      let buf = o.conn_buf in
+      if Sys.file_exists url then
+        begin
+          load_torrent_file url;
+          Printf.bprintf buf "loaded file %s\n" url
+	end
+      else
+        begin
+          let url = "Location: " ^ url in
+          let result = fst (op_network_parse_url url) in
+          Printf.bprintf buf "%s\n" result
+	end;
+      _s ""
+     ),  "<url>:\t [<URL|file>] start BT download";
+
     "stop_all_bt", "Network/Bittorrent", Arg_none (fun o ->
       List.iter (fun file -> BTClients.file_stop file ) !current_files;
       let buf = o.conn_buf in
@@ -935,7 +992,7 @@ let commands =
           Hashtbl.iter (fun _ file ->
               if file_num file = num then begin
                   if !verbose then
-                    lprintf_nl () "adding trackers for file %i" num;
+                    lprintf_nl "adding trackers for file %i" num;
                   set_trackers file !urls;
                   raise Exit
                 end
@@ -958,7 +1015,7 @@ let commands =
             _s ""
         | _ ->
             if !verbose then
-              lprintf_nl () "Not enough or wrong parameters.";
+              lprintf_nl "Not enough or wrong parameters.";
             let buf = o.conn_buf in
             if o.conn_output = HTML then
               html_mods_table_one_row buf "serversTable" "servers" [
@@ -984,7 +1041,7 @@ let op_gui_message s =
   match get_int16 s 0 with
     0 ->
       let text = String.sub s 2 (String.length s - 2) in
-      if !verbose then lprintf_nl () "received torrent from gui...";
+      if !verbose then lprintf_nl "received torrent from gui...";
       ignore (load_torrent_string text)
   | 1 -> (* 34+ *)
       let n = get_int s 2 in
@@ -1022,8 +1079,13 @@ let _ =
   network.op_network_search <- (fun ss buf -> ());
   network.op_network_download <- (fun r -> dummy_file);
   network.op_network_recover_temp <- (fun s -> ());
+  let clean_exit_started = ref false in
   network.op_network_clean_exit <- (fun s ->
-    List.iter (fun file -> BTClients.file_stop file) !current_files;
+    if not !clean_exit_started then
+      begin
+        List.iter (fun file -> BTClients.file_stop file) !current_files;
+        clean_exit_started := true;
+      end;
     List.for_all (fun file -> not file.file_tracker_connected) !current_files;
   );
 
@@ -1037,7 +1099,7 @@ let _ =
   CommonNetwork.register_commands commands;
 
   shared_ops.op_shared_unshare <- (fun file ->
-      (if !verbose_share then lprintf_nl () "unshare file");
+      (if !verbose_share then lprintf_nl "unshare file");
       BTShare.unshare_file file);
   shared_ops.op_shared_info <- (fun file ->
    let module T = GuiTypes in
