@@ -32,6 +32,11 @@ open BTGlobals
 open BTTypes
 open CommonTypes
 
+let log_prefix = "[bTM]"
+
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
 let is_enabled = ref false
 
 let disable enabler () =
@@ -59,12 +64,21 @@ let enable () =
     Unix2.safe_mkdir tracked_directory;
     Unix2.safe_mkdir downloads_directory;
     Unix2.safe_mkdir old_directory;
+    Unix2.safe_mkdir new_torrents_directory;
     Unix2.can_write_to_directory torrents_directory;
     Unix2.can_write_to_directory seeded_directory;
     Unix2.can_write_to_directory tracked_directory;
     Unix2.can_write_to_directory downloads_directory;
     Unix2.can_write_to_directory old_directory;
+    Unix2.can_write_to_directory new_torrents_directory;
     is_enabled := true;
+    if !!BTTracker.tracker_port = !!client_port then
+      begin
+        lprint_newline();
+  lprintf_nl "BT-client_port and BT-tracker_port can not be the same.";
+  lprintf_nl "Change one of the settings and restart MLDonkey, exiting...\n";
+	Pervasives.exit 69
+      end;
     if !!BTTracker.tracker_port > 0 then (
         try BTTracker.start_tracker ()
         with e ->
@@ -73,6 +87,9 @@ let enable () =
     add_session_timer enabler 300. (fun _ ->
         BTInteractive.share_files ();
     );
+    add_session_timer enabler 10. (fun _ ->
+        BTInteractive.scan_new_torrents_directory ();
+    );
     add_timer 10. BTInteractive.share_files;
     add_session_timer enabler 600. BTInteractive.retry_all_ft;
     network.op_network_disable <- disable enabler;
@@ -98,6 +115,7 @@ let enable () =
     BTClients.recover_files ();
     add_session_timer enabler 60.0 (fun timer ->
         BTClients.recover_files ();
+        BTInteractive.file_magic_check ()
     );
 
     add_session_timer enabler 120.0 (fun timer ->
@@ -113,6 +131,7 @@ let enable () =
 	      ) !current_files;
   );
 
+  BTInteractive.file_magic_check ();
   BTClients.listen ();
   ()
 
