@@ -232,13 +232,6 @@ let _ =
       List2.tail_map (fun s -> as_server s.server_server) !connected_server_list
   )
 
-let lprintf_nl () =
-  lprintf "%s[EDK] "
-  (log_time ()); lprintf_nl2
-
-let lprintf_n () =
-  lprintf "%s[EDK] "
-  (log_time ()); lprintf
 
 let hashtbl_remove table key v =
   try
@@ -303,13 +296,13 @@ let new_file file_diskname file_state md4 file_size filenames writable =
             then
               begin
                 if !verbose_share then
-                  lprintf_nl () "New file with changed filename %s to %s"
+                  lprintf_nl "New file with changed filename %s to %s"
                     file.file_diskname file_diskname;
                 file.file_diskname <- file_diskname;
               end
           else
             if !verbose_share then
-              lprintf_nl () "New file with not changed different filename %s and %s"
+              lprintf_nl "New file with not changed different filename %s and %s"
                 file.file_diskname file_diskname;
         end;
       if Unix32.destroyed (file_fd file)
@@ -319,13 +312,12 @@ let new_file file_diskname file_state md4 file_size filenames writable =
           file.file_file.impl_file_fd <-
             Some (Unix32.create_diskfile file.file_diskname true);
       if Unix32.destroyed (file_fd file) then
-          lprintf_nl () "New Edonkey file with %b && %b remaining destroyed fd %s"
+          lprintf_nl "New Edonkey file with %b && %b remaining destroyed fd %s"
             (not writable) (file.file_diskname = file_diskname) file.file_diskname;
       file
   with _ ->
       if !verbose_share then
-        lprintf_nl () "New file with md4: %s" (Md4.to_string md4);
-      ignore (Unix32.file_exists file_diskname);
+        lprintf_nl "New file with md4: %s" (Md4.to_string md4);
 
       let t =
         if
@@ -334,7 +326,7 @@ let new_file file_diskname file_state md4 file_size filenames writable =
 (* Only if the option is set *)
           !!emulate_sparsefiles &&
 (* Only if the file does not already exists *)
-          not (Sys.file_exists file_diskname)
+          not (Unix32.file_exists file_diskname)
         then
           Unix32.create_sparsefile file_diskname writable
         else
@@ -357,7 +349,7 @@ let new_file file_diskname file_state md4 file_size filenames writable =
 	    (try
 	      Unix32.remove t
 	     with e ->
-		lprintf_nl () "Unix32.remove %s exception %s"
+    lprintf_nl "Unix32.remove %s exception %s"
 		  (file_diskname) (Printexc2.to_string e));
 	    Unix32.destroy t;
 	    failwith (Printf.sprintf "file size %s is too big, exception: %s"
@@ -398,12 +390,12 @@ let new_file file_diskname file_state md4 file_size filenames writable =
       (match file_state with
           FileShared -> ()
         | _ ->
-            let kernel = Int64Swarmer.create_swarmer file_diskname file_size zone_size in
-            let swarmer = Int64Swarmer.create kernel (as_file file) block_size
+            let kernel = CommonSwarming.create_swarmer file_diskname file_size zone_size in
+            let swarmer = CommonSwarming.create kernel (as_file file) block_size
             in
             file.file_swarmer <- Some swarmer;
 (*
-        Int64Swarmer.set_writer swarmer (fun offset s pos len ->
+        CommonSwarming.set_writer swarmer (fun offset s pos len ->
 (*
       lprintf "DOWNLOADED: %d/%d/%d\n" pos len (String.length s);
       AnyEndian.dump_sub s pos len;
@@ -414,11 +406,11 @@ let new_file file_diskname file_state md4 file_size filenames writable =
             else
               Unix32.write  t offset s pos len
         ); *)
-            Int64Swarmer.set_verifier swarmer
+            CommonSwarming.set_verifier swarmer
               (if md4s = [] then VerificationNotAvailable else
                 Verification (Array.of_list (List.map (fun md4 -> Ed2k md4) md4s))
             );
-            Int64Swarmer.set_verified swarmer (fun nblocks num ->
+            CommonSwarming.set_verified swarmer (fun nblocks num ->
                 if nblocks = 1 then begin
                     new_shared_files := file :: !new_shared_files;
                     file_must_update file
@@ -460,11 +452,11 @@ let is_black_address ip port =
 (* lprintf "is black ="; *)
     not (Ip.reachable ip) || (Ip.matches ip !!server_black_list) ||
     (List.mem port !!port_black_list) ||
-    (match Ip_set.match_ip !Ip_set.bl ip with
+    (match !Ip.banned ip with
         None -> false
-      | Some br ->
+      | Some reason ->
           if !verbose_connect then
-            lprintf_nl () "%s:%d blocked: %s" (Ip.to_string ip) port br.Ip_set.blocking_description;
+            lprintf_nl "%s:%d blocked: %s" (Ip.to_string ip) port reason;
           true))
 
 let new_server ip port score =
@@ -927,7 +919,7 @@ let save_join_queue c =
       ) c.client_file_queue in
     begin
       if c.client_debug then
-        lprintf_nl () "Saving %d files associated with %s"
+        lprintf_nl "Saving %d files associated with %s"
         (List.length files) (Md4.to_string c.client_md4);
       Hashtbl.add join_queue_by_md4 c.client_md4 (files, last_time ());
       try
@@ -959,7 +951,7 @@ let client_public_key = ref ""
 
 let _ =
   option_hook client_private_key (fun _ ->
-    if Autoconf.donkey_sui = "yes" then begin
+    if Autoconf.donkey_sui_works () then begin
     client_public_key := DonkeySui.SUI.load_key (!!client_private_key);
     (
     let key_checked = ref false in
@@ -969,12 +961,12 @@ let _ =
       if not (try String.sub !!client_private_key 0 4 = "MIIB" with e -> false) then
         if !key_check_again then
 	  begin
-	    lprintf_nl () "can not create proper client_private_key, exiting...";
+      lprintf_nl "can not create proper client_private_key, exiting...";
 	    exit 70
 	  end
 	else
           begin
-            lprintf_nl () "bad client_private_key detected, creating new key";
+            lprintf_nl "bad client_private_key detected, creating new key";
 	    set_simple_option donkey_ini "client_private_key" (DonkeySui.SUI.create_key ());
 	    key_check_again := true
 	  end
@@ -982,7 +974,7 @@ let _ =
     if not !key_checked then check_client_private_key ();
     if !key_check_again then
       begin
-	lprintf_nl () "re-checking private key";
+  lprintf_nl "re-checking private key";
 	check_client_private_key ()
       end
     );
