@@ -55,15 +55,6 @@ open CommonOptions
 open DonkeyStats
 open DonkeyUdp
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[EDK] "
-    (log_time ()); lprintf_nl2
-
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[EDK] "
-    (log_time ()); lprintf
 
 let result_name r =
   match r.result_names with
@@ -117,7 +108,7 @@ let load_server_met filename =
     ) ss;
     List.length ss
   with e ->
-      lprintf_nl () "Exception %s while loading %s" (Printexc2.to_string e)
+      lprintf_nl "Exception %s while loading %s" (Printexc2.to_string e)
       filename;
       0
   else 0
@@ -125,46 +116,40 @@ let load_server_met filename =
 let unpack_server_met filename url =
   let ext = String.lowercase (Filename2.extension filename) in
     let last_ext = String.lowercase (Filename2.last_extension filename) in
-    let real_ext = if last_ext = ".zip" then
-      last_ext
-    else
-      ext
-    in
+    let real_ext = if last_ext = ".zip" then last_ext else ext in
     match real_ext with
-      ".zip" ->
-  begin try
-    let ic = Zip.open_in filename in
-      try
-        let file = Zip.find_entry ic "server.met" in
-          Zip.close_in ic;
-    lprintf_nl () "server.met found in %s" url;
-    let _ = Misc.archive_extract filename "zip" in
-      file.Zip.filename
-        with e ->
-    Zip.close_in ic;
-    lprintf_nl () "Exception %s while extracting server.met from %s"
-      (Printexc2.to_string e) url;
-    raise Not_found
-      with e ->
-        lprintf_nl () "Exception %s while opening %s"
-    (Printexc2.to_string e) url;
-        raise Not_found
-  end
+      | ".zip" ->
+	  (try
+	    let result =
+	      Unix2.tryopen_read_zip filename (fun ic ->
+		try
+		  let file = Zip.find_entry ic "server.met" in
+      lprintf_nl "server.met found in %s" url;
+		  file.Zip.filename
+		with e ->
+      lprintf_nl "Exception %s while extracting server.met from %s"
+		    (Printexc2.to_string e) url;
+		  raise e) in
+	    (try
+	      ignore(Misc.archive_extract filename "zip")
+	    with e ->
+        lprintf_nl "Exception %s while extracting server.met from %s"
+		(Printexc2.to_string e) url;
+	      raise e);
+	    result
+	  with e ->
+            lprintf_nl "Exception %s while opening %s"
+	      (Printexc2.to_string e) url;
+            raise Not_found)
     | ".met.gz" | ".met.bz2" | ".gz" | ".bz2" ->
-  begin
-    let filetype =
-      if ext = ".bz2" || ext = ".met.bz2" then
-        "bz2"
-      else
-        "gz"
-      in try
-        let s = Misc.archive_extract filename filetype in
-          s
-      with e ->
-        lprintf_nl () "Exception %s while extracting from %s"
-    (Printexc2.to_string e) url;
-        raise Not_found
-  end
+	(let filetype =
+	  if ext = ".bz2" || ext = ".met.bz2" then "bz2" else "gz" in 
+	try
+          Misc.archive_extract filename filetype
+	with e ->
+          lprintf_nl "Exception %s while extracting from %s"
+	    (Printexc2.to_string e) url;
+          raise Not_found)
 (* if file is not a supported archive type try loading servers from that file anyway *)
     | _ -> filename
 
@@ -174,9 +159,9 @@ let download_server_met url =
       H.basic_request with
       H.req_url = Url.of_string url;
       H.req_proxy = !CommonOptions.http_proxy;
-      H.req_user_agent =
-  Printf.sprintf "MLDonkey/%s" Autoconf.current_version;
+      H.req_user_agent = get_user_agent ();
       H.req_max_retry = 10;
+      H.req_save = true;
     } in
     H.wget r (fun filename ->
       try
@@ -184,7 +169,7 @@ let download_server_met url =
         let s = unpack_server_met filename url in
     let n = load_server_met s in
       if s <> filename then Sys.remove s;
-            lprintf_nl () "server.met loaded from %s, %d servers found, %d new ones inserted"
+            lprintf_nl "server.met loaded from %s, %d servers found, %d new ones inserted"
         url n ((List.length (Hashtbl2.to_list servers_by_key)) - nservers)
       with e -> ()
     )
@@ -220,15 +205,15 @@ let really_query_download filenames size md4 location old_file absents =
            && not (Sys.file_exists file_diskname)
           then
             (try
-              lprintf_nl () "Renaming edonkey temp-file from %s to %s"
+              lprintf_nl "Renaming edonkey temp-file from %s to %s"
                   filename file_diskname;
               Unix2.rename filename file_diskname;
               Unix2.chmod file_diskname 0o644;
               with e ->
-                lprintf_nl () "Could not rename %s to %s: exception %s"
+                lprintf_nl "Could not rename %s to %s: exception %s"
                   filename file_diskname (Printexc2.to_string e);
             )
-        else lprintf_nl () "THERE IS SOME PROBLEM WITH RECOVERING TEMP-FILES, THAT COULD CAUSE FILE-CORRUPTION!!!!!!!!!!! filename: %s  exists:%b file_diskname: %s  exists:%b"
+        else lprintf_nl "THERE IS SOME PROBLEM WITH RECOVERING TEMP-FILES, THAT COULD CAUSE FILE-CORRUPTION!!!!!!!!!!! filename: %s  exists:%b file_diskname: %s  exists:%b"
                filename (Sys.file_exists filename)
                file_diskname (Sys.file_exists file_diskname);
     | _ -> ()
@@ -252,10 +237,10 @@ let really_query_download filenames size md4 location old_file absents =
           None -> assert false
         | Some swarmer ->
             let absents = Sort.list (fun (p1,_) (p2,_) -> p1 <= p2) absents in
-            Int64Swarmer.set_absent swarmer absents
+            CommonSwarming.set_absent swarmer absents
   end;
 
-  if !verbose then lprintf_nl () "Started new download, file %s, size %Ld, md4 %s"
+  if !verbose then lprintf_nl "Started new download, file %s, size %Ld, md4 %s"
     (file_best_name file) size (Md4.to_string md4);
 
   DonkeyProtoOvernet.Overnet.recover_file file;
@@ -339,19 +324,13 @@ let query_download filenames size md4 location old_file absents force =
         begin
         if List.mem md4 !!old_files then begin
           (* copy file info into result for later usage in force_download *)
-          let r = {
-              result_num = 0;
+          let r = { dummy_result with
 	      result_uids = [Uid.create (Ed2k md4)];
               result_names = filenames;
               result_size = size;
-              result_tags = [];
-              result_type = "";
-              result_format = "";
-              result_comment = "";
-              result_done = false;
               result_force = true; (* marker for force_download *)
-	      result_time = 0;
 	      result_modified = false;
+                result_source_network = network.network_num;
             } in
             forceable_download := [r];
 	    raise already_done
@@ -383,7 +362,7 @@ let load_prefs filename =
     let t = P.read s in
     t.P.client_tags, t.P.option_tags
   with e ->
-      lprintf_nl () "Exception %s while loading %s" (Printexc2.to_string e)
+      lprintf_nl "Exception %s while loading %s" (Printexc2.to_string e)
       filename;
       [], []
 
@@ -403,7 +382,7 @@ let import_temp temp_dir =
             List.iter (fun tag ->
                 match tag with
                   { tag_name = Field_Filename; tag_value = String s } ->
-                    lprintf_nl () "Import Donkey %s" s;
+                    lprintf_nl "Import Donkey %s" s;
 
                     filenames := s :: !filenames;
                 | { tag_name = Field_Size; tag_value = Uint64 v } ->
@@ -435,7 +414,7 @@ let import_config dirname =
       | { tag_name = Field_UNKNOWN "temp"; tag_value = String s } ->
           if Sys.file_exists s then (* be careful on that *)
             temp_dir := s
-          else (lprintf_nl () "Bad temp directory, using default";
+          else (lprintf_nl "Bad temp directory, using default";
               )
       | _ -> ()
   ) ot;
@@ -504,7 +483,7 @@ let print_file buf file =
   match file.file_swarmer with
     None -> ()
   | Some swarmer ->
-      let bitmap = Int64Swarmer.verified_bitmap swarmer in
+      let bitmap = CommonSwarming.verified_bitmap swarmer in
       Printf.bprintf buf "\nChunks: %s\n" bitmap
 *)
 
@@ -513,7 +492,7 @@ let recover_md4s md4 =
   match file.file_swarmer with
     None -> ()
   | Some swarmer ->
-      Int64Swarmer.verify_all_chunks swarmer false
+      CommonSwarming.verify_all_chunks swarmer false
 
   (*
   if file.file_chunks <> [||] then
@@ -530,7 +509,7 @@ let recover_md4s md4 =
 
 let parse_donkey_url url =
   let url = Str.global_replace (Str.regexp "|sources,") "|sources|" url in
-  match String2.split (String.escaped url) '|' with
+  match String2.split url '|' with
 (* TODO RESULT *)
   | "ed2k://" :: "file" :: name :: size :: md4 :: "/" :: "sources" :: sources :: _
   | "file" :: name :: size :: md4 :: "/" :: "sources" :: sources :: _ ->
@@ -619,7 +598,7 @@ let op_file_check file =
   match file.file_swarmer with
     None -> ()
   | Some swarmer ->
-      Int64Swarmer.verify_all_chunks swarmer true
+      CommonSwarming.verify_all_chunks swarmer true
 
 let register_commands list =
   register_commands
@@ -742,27 +721,6 @@ let commands = [
         ""
     ), ":\t\t\t\t\tprint ID on connected servers";
 
-    "set_brothers", Arg_multiple (fun args o ->
-        let buf = o.conn_buf in
-
-        let files = ref [] in
-        List.iter (fun arg ->
-            let num = int_of_string arg in
-            List.iter (fun file ->
-                if file_num file = num then begin
-                    Printf.bprintf buf "%s\n" (file_best_name file);
-                    files := file :: !files
-                  end
-            ) !current_files
-        ) args;
-
-        DonkeySources.set_brothers
-          (List.map (fun file -> file.file_sources) !files);
-        brotherhood =:=
-          (List.map (fun file -> file.file_md4) !files) :: !!brotherhood;
-        "    are now defined as colocated"
-    ) , "<f1> < f2> ... :\t\tdefine these files as probably colocated";
-
     "recover_bytes", Arg_multiple (fun args o ->
         let buf = o.conn_buf in
 
@@ -774,9 +732,9 @@ let commands = [
                       None -> ()
                     | Some swarmer ->
                         let segments = CommonFile.recover_bytes (as_file file) in
-                        let old_downloaded = Int64Swarmer.downloaded swarmer in
-                        Int64Swarmer.set_present swarmer segments;
-                        let new_downloaded = Int64Swarmer.downloaded swarmer in
+                        let old_downloaded = CommonSwarming.downloaded swarmer in
+                        CommonSwarming.set_present swarmer segments;
+                        let new_downloaded = CommonSwarming.downloaded swarmer in
                         Printf.bprintf buf "Recovered %Ld bytes for %s\n"
                           (new_downloaded -- old_downloaded)
                         (file_best_name file)
@@ -975,7 +933,7 @@ parent.fstatus.location.href='submit?q=rename+'+i+'+\\\"'+encodeURIComponent(for
 
     "reset_md4", Arg_none (fun _ ->
         set_simple_option donkey_ini "client_md4" (Md4.to_string (mldonkey_md4 (Md4.random ())));
-        if Autoconf.donkey_sui = "yes" then set_simple_option donkey_ini "client_private_key" (DonkeySui.SUI.create_key ());
+        if Autoconf.donkey_sui_works () then set_simple_option donkey_ini "client_private_key" (DonkeySui.SUI.create_key ());
         "reset client_md4/client_private_key"
     ), ":\t\t\t\treset client_md4/client_private_key to random values";
 
@@ -1002,7 +960,7 @@ DonkeySources.recompute_ready_sources ()        *)
 
   file_ops.op_file_commit <- (fun file new_name ->
 
-      Int64Swarmer.remove_swarmer file.file_swarmer;
+      CommonSwarming.remove_swarmer file.file_swarmer;
       file.file_swarmer <- None;
 (*      DonkeyStats.save_download_history file; *)
 
@@ -1058,7 +1016,7 @@ let _ =
       try
         let last_seen = match file.file_swarmer with
             None -> [| last_time () |]
-          | Some swarmer -> Int64Swarmer.compute_last_seen swarmer
+          | Some swarmer -> CommonSwarming.compute_last_seen swarmer
         in
         let v =
             { (impl_file_info file.file_file) with
@@ -1071,13 +1029,13 @@ let _ =
             P.file_chunks = 
                   (match file.file_swarmer with
                    | None -> "" 
-                   | Some swarmer -> Int64Swarmer.verified_bitmap swarmer);
+                   | Some swarmer -> CommonSwarming.verified_bitmap swarmer);
             P.file_availability =
               [
                 network.network_num,
                 (match file.file_swarmer with
                   | None -> "" 
-                  | Some swarmer -> Int64Swarmer.availability swarmer)
+                  | Some swarmer -> CommonSwarming.availability swarmer)
               ];
             P.file_format = file.file_format;
             P.file_chunks_age = last_seen;
@@ -1085,7 +1043,7 @@ let _ =
           } in
         v
       with e ->
-          lprintf_nl () "Exception %s in op_file_info" (Printexc2.to_string e);
+          lprintf_nl "Exception %s in op_file_info" (Printexc2.to_string e);
           raise e
 
   )
@@ -1144,7 +1102,7 @@ let get_ips_cc_cn c =
         let cc,cn = Geoip.get_country ip in
         (Ip.to_string ip),cc,cn
     | _ ->  
-        let cc,cn = !Geoip.unknown_country in
+        let cc,cn = Geoip.unknown_country in
         (string_of_client_addr c),cc,cn
   with _ -> ("X","??","Country Error")
 
@@ -1271,9 +1229,12 @@ let _ =
       tr ();
       html_mods_td buf [
         ("File History Links", "sr br", "File History");
-        ("","sr", Printf.sprintf "\\<a target=\\\"_blank\\\" href=\\\"http://stats.razorback2.com/ed2khistory\\?ed2k=%s\\\"\\>RazorBack File History\\</a\\>"
-            (Md4.to_string file.file_md4)
-          )
+        ("","sr", Printf.sprintf
+"\\<a target=\\\"_blank\\\" href=\\\"http://62.241.53.2/cgi-bin/ed2khistory?ed2k=%s\\\"\\>DonkeyServer 1 File History\\</a\\>
+ \\<a target=\\\"_blank\\\" href=\\\"http://tothbenedek.hu/ed2kstats/ed2k?hash=%s\\\"\\>Toth File History\\</a\\>
+ \\<a target=\\\"_blank\\\" href=\\\"http://ed2k.titanesel.ws/ed2k.php?hash=%s\\\"\\>Titanesel File History\\</a\\>"
+            (Md4.to_string file.file_md4) (Md4.to_string file.file_md4) (Md4.to_string file.file_md4)
+	)
        ];
       tr ();
       html_mods_td buf [
@@ -1332,7 +1293,7 @@ parent.fstatus.location.href='submit?q=rename+%d+\\\"'+encodeURIComponent(formID
       let chunks =
       (match file.file_swarmer with
        None -> "" | Some swarmer ->
-       Int64Swarmer.verified_bitmap swarmer)
+       CommonSwarming.verified_bitmap swarmer)
       in
 
       html_mods_table_header buf "sourcesTable" "sources al" ([
@@ -1472,7 +1433,7 @@ parent.fstatus.location.href='submit?q=rename+%d+\\\"'+encodeURIComponent(formID
 
   );
   file_ops.op_file_cancel <- (fun file ->
-      Int64Swarmer.remove_swarmer file.file_swarmer;
+      CommonSwarming.remove_swarmer file.file_swarmer;
       file.file_swarmer <- None;
       Hashtbl.remove files_by_md4 file.file_md4;
       current_files := List2.removeq file !current_files;
@@ -1493,7 +1454,7 @@ parent.fstatus.location.href='submit?q=rename+%d+\\\"'+encodeURIComponent(formID
       match file.file_swarmer with
         None -> [CommonFile.as_file impl]
       | Some swarmer ->
-          Int64Swarmer.subfiles swarmer)
+          CommonSwarming.subfiles swarmer)
 
 let try_recover_temp_file filename md4 =
   try
@@ -1541,7 +1502,7 @@ let _ =
               (try
                  try_recover_temp_file filename md4
                with e ->
-                 lprintf_nl () "exception %s in recover_temp"
+                 lprintf_nl "exception %s in recover_temp"
                  (Printexc2.to_string e);
               )
           | NoUid ->
@@ -1550,7 +1511,7 @@ let _ =
                    let md4 = Md4.of_string filename in
                    try_recover_temp_file filename md4
                  with e ->
-                   lprintf_nl () "exception %s in recover_temp"
+                   lprintf_nl "exception %s in recover_temp"
                      (Printexc2.to_string e);
               )
           | _ -> ()
@@ -1580,7 +1541,7 @@ let _ =
       | Some files ->
           List2.tail_map (fun r -> "", r) files);
   client_ops.op_client_browse <- (fun c immediate ->
-      lprintf_nl () "*************** should browse  ***********";
+      lprintf_nl "*************** should browse  ***********";
       match c.client_source.DonkeySources.source_sock with
       | Connection sock    ->
 (*
@@ -1594,8 +1555,8 @@ lprint_newline ();
             let module C = M.ViewFiles in
             M.ViewFilesReq C.t);
       | NoConnection ->
-          lprintf_nl () "****************************************";
-          lprintf_nl () "       TRYING TO CONTACT FRIEND";
+          lprintf_nl "****************************************";
+          lprintf_nl "       TRYING TO CONTACT FRIEND";
 
           reconnect_client c
       | _ -> ()
@@ -1737,10 +1698,11 @@ let _ =
   )
 
 let _ =
-  CommonWeb.add_web_kind "server.met" (fun url filename ->
+  CommonWeb.add_web_kind "server.met" "List of donkey servers" 
+    (fun url filename ->
     if !!enable_donkey && !!update_server_list_server_met then
       begin
-        lprintf_n () "server.met loaded from %s" url;
+        lprintf_n "server.met loaded from %s" url;
   begin
     try
       let s = unpack_server_met filename url in
@@ -1755,13 +1717,14 @@ let _ =
       end
     else
       if not !!enable_donkey then
-        lprintf_nl () "eDonkey module is disabled, ignoring..."
+        lprintf_nl "eDonkey module is disabled, ignoring..."
       else
-        lprintf_nl () "ED2K_update_server_list_met is disabled, ignoring..."
+        lprintf_nl "ED2K_update_server_list_met is disabled, ignoring..."
   );
-  CommonWeb.add_web_kind "comments.met" (fun _ filename ->
+  CommonWeb.add_web_kind "comments.met" "List of edonkey files comments" 
+    (fun _ filename ->
 (* TODO      DonkeyIndexer.load_comments filename; *)
-      lprintf_nl () "COMMENTS ADDED";
+      lprintf_nl "COMMENTS ADDED";
   );
 
   file_ops.op_file_proposed_filenames <- op_file_proposed_filenames;
