@@ -25,7 +25,8 @@ let donkey_ini = create_options_file "donkey.ini"
 
 let donkey_section = file_section donkey_ini ["Donkey"] "Donkey options"
 
-let initial_score = define_expert_option donkey_section ["initial_score"] "" int_option 5
+let initial_score = define_expert_option donkey_section ["initial_score"]
+  "Initial score for a new server" int_option 5
 
 let max_xs_packets = define_expert_option donkey_section ["max_xs_packets"]
   "Max number of UDP packets per round for eXtended Search" int_option 30
@@ -153,7 +154,8 @@ let client_md4 = define_option donkey_section ["client_md4"]
     "The MD4 of this client" Md4.option (mldonkey_md4 (Md4.random ()))
 
 let client_private_key = define_option donkey_section ["client_private_key"]
-    "The RSA private key of this client" string_option (DonkeySui.SUI.create_key ())
+    "The RSA private key of this client"
+    string_option (if Autoconf.donkey_sui_works () then DonkeySui.SUI.create_key () else "")
 
 let enable_sui = define_option donkey_section ["enable_sui"]
     "Enable secure user identification support" bool_option true
