@@ -37,10 +37,6 @@ open CommonOptions
 open DonkeyComplexOptions
 open DonkeyGlobals
 
-let lprintf_nl () =
-  lprintf "%s[EDK] "
-    (log_time ()); lprintf_nl2
-
 let new_shared_files = ref []
 
 let must_share_file file codedname has_old_impl =
@@ -48,9 +44,16 @@ let must_share_file file codedname has_old_impl =
   | Some _ -> ()
   | None ->
       new_shared := true;
+      let full_name = file_disk_name file in
+      let magic =
+        match Magic.M.magic_fileinfo full_name false with
+          None -> None
+        | Some magic -> Some (HashMagic.merge files_magic magic)
+      in
+
       let impl = {
           impl_shared_update = 1;
-          impl_shared_fullname = file_disk_name file;
+          impl_shared_fullname = full_name;
           impl_shared_codedname = codedname;
           impl_shared_size = file_size file;
           impl_shared_id = file.file_md4;
@@ -59,6 +62,7 @@ let must_share_file file codedname has_old_impl =
           impl_shared_ops = shared_ops;
           impl_shared_val = file;
           impl_shared_requests = 0;
+          impl_shared_magic = magic;
         } in
       file.file_shared <- Some impl;
       new_shared_files := file :: !new_shared_files;
@@ -90,7 +94,7 @@ let new_file_to_share sh codedname old_impl =
     in
 
     if !verbose_share then
-      lprintf_nl () "Sharing file with MD4: %s" (Md4.to_string md4);
+      lprintf_nl "Sharing file with MD4: %s" (Md4.to_string md4);
 
     let file = new_file sh.sh_name FileShared md4 sh.sh_size
         [Filename.basename sh.sh_name, GuiTypes.noips()]
@@ -107,7 +111,7 @@ let new_file_to_share sh codedname old_impl =
 (*    file.file_all_chunks <- String.make file.file_nchunks '1'; *)
     (* Should we trust mtimes, or reverify each file.  If we trust
      * mtimes, I guess we have to call
-     * Int64Swarmer.set_verified_bitmap "333..."
+     * CommonSwarming.set_verified_bitmap "333..."
      * this seems unspeakably ugly, but the alternative is to reverify
      * every shared file every hour.
      *
@@ -122,16 +126,16 @@ let new_file_to_share sh codedname old_impl =
     match file.file_swarmer with
       Some s -> (let len = Array.length md4s in
 		 let ver_str = String.make len '3' in
-		     Int64Swarmer.set_verified_bitmap s ver_str;
+		     CommonSwarming.set_verified_bitmap s ver_str;
 		 (*
-		 Int64Swarmer.set_present s [(Int64.zero, file_size file)];
+		 CommonSwarming.set_present s [(Int64.zero, file_size file)];
 		 (* If we don't verify now, it will never happen! *)
-		 Int64Swarmer.verify_all_blocks s true;
+		 CommonSwarming.verify_all_blocks s true;
 		 *)
                 if !verbose_share then
-                  lprintf_nl () "verified map of %s = %s"
-		         (codedname) (Int64Swarmer.verified_bitmap s))
-      | None -> if !verbose_share then lprintf_nl () "no swarmer for %s" codedname;
+                  lprintf_nl "verified map of %s = %s"
+		         (codedname) (CommonSwarming.verified_bitmap s))
+      | None -> if !verbose_share then lprintf_nl "no swarmer for %s" codedname;
     (try
         file.file_format <- CommonMultimedia.get_info
           (file_disk_name file)
@@ -144,9 +148,9 @@ let new_file_to_share sh codedname old_impl =
 lprint_newline ());
   *)
     if !verbose_share then
-      lprintf_nl () "new_file_to_share: Sharing %s" sh.sh_name;
+      lprintf_nl "new_file_to_share: Sharing %s" sh.sh_name;
   with e ->
-      lprintf_nl () "Exception %s while sharing %s" (Printexc2.to_string e)
+      lprintf_nl "Exception %s while sharing %s" (Printexc2.to_string e)
       sh.sh_name
 
 let all_shared () =
@@ -156,7 +160,7 @@ let all_shared () =
         None -> ()
       | Some _ ->  shared_files := file :: !shared_files
   ) files_by_md4;
-  if !verbose_share then lprintf_nl () "%d files shared" (List.length !shared_files);
+  if !verbose_share then lprintf_nl "%d files shared" (List.length !shared_files);
   !shared_files
 
 (* Check whether new files are shared, and send them to connected servers.
@@ -176,19 +180,19 @@ let send_new_shared () =
             if s.server_master then
               begin
                 if !verbose_share || !verbose then
-                  lprintf_nl () "send_new_shared: found master server %s:%d"
+                  lprintf_nl "send_new_shared: found master server %s:%d"
 		    (Ip.to_string s.server_ip) s.server_port;
 		tag := true;
                 do_if_connected s.server_sock (fun sock ->
                   server_send_share s.server_has_zlib sock !new_shared_files)
               end) (connected_servers ());
           if !tag && (!verbose_share || !verbose) then
-              lprintf_nl () "send_new_shared: Sent %d new shared files to servers"
+              lprintf_nl "send_new_shared: Sent %d new shared files to servers"
                     (List.length !new_shared_files);
           new_shared_files := []
         end
       else
-          lprintf_nl () "donkey send_new_share: No new shared files to send to servers"
+          lprintf_nl "donkey send_new_share: No new shared files to send to servers"
     end
 
 (*
@@ -219,16 +223,19 @@ let check_shared_files () =
             let end_pos = if end_pos > sh.shared_size then sh.shared_size
               else end_pos in
             let len = end_pos -- sh.shared_pos in
-            if !verbose_md4 then lprintf_nl () "compute next md4 of %s" sh.shared_name;
+            if !verbose_md4 then
+        lprintf_nl "Hash chunk %Ld/%Ld of %s"
+	        ((Int64.div sh.shared_pos block_size) ++ one)
+		((Int64.div sh.shared_size block_size) ++ one)
+		sh.shared_name;
 
             M.compute_md4 (Unix32.filename sh.shared_fd) sh.shared_pos len
               (fun job ->
                 computation := false;
                 if job.M.job_error then begin
-                    lprintf_nl () "Error prevent sharing %s" sh.shared_name
+                    lprintf_nl "Error prevent sharing %s" sh.shared_name
                   end else
                 let _ = () in
-		if !verbose_md4 then lprintf_nl () "computed md4 of %s" sh.shared_name;
                 let new_md4 = job.M.job_result in
 
                 sh.shared_list <- new_md4 :: sh.shared_list;
@@ -240,7 +247,7 @@ let check_shared_files () =
                         sh_md4s = Array.of_list (List.rev sh.shared_list);
                         sh_mtime = Unix32.mtime sh.shared_name;
                       } in
-                    lprintf_nl () "New shared file %s" sh.shared_name;
+                    lprintf_nl "New shared file %s" sh.shared_name;
                     Hashtbl.add shared_files_info
                       (s.sh_name, s.sh_size, s.sh_mtime) s;
                     known_shared_files =:= s :: !!known_shared_files;
@@ -251,7 +258,7 @@ let check_shared_files () =
                   job_creater ())
           with e ->
 	      shared_files := files;
-              lprintf_nl () "Exception %s prevents sharing of %s"
+              lprintf_nl "Exception %s prevents sharing of %s"
                 (Printexc2.to_string e) sh.shared_name
         in
         job_creater ()
@@ -259,17 +266,18 @@ let check_shared_files () =
 let _ =
   network.op_network_share <- (fun fullname codedname size ->
       if !verbose_share then
-        lprintf_nl () "op_network_share: Sharing %s" fullname;
+        lprintf_nl "op_network_share: Sharing %s" fullname;
       try
 (*
 lprintf "Searching %s" fullname; lprint_newline ();
 *)
         let mtime = Unix32.mtime fullname in
+
         let s = Hashtbl.find shared_files_info
             (fullname, size, mtime) in
         (* if s.sh_mtime = mtime && s.sh_size = size then begin *)
             if !verbose_share then
-                lprintf_nl () "donkeyShare: Using old MD4s for %s" fullname;
+                lprintf_nl "donkeyShare: Using old MD4s for %s" fullname;
             new_file_to_share s codedname None
 (*          end else begin
             if !verbose_share then begin
@@ -281,11 +289,17 @@ lprintf "Searching %s" fullname; lprint_newline ();
           end *)
       with Not_found ->
           if !verbose_share then
-              lprintf_nl () "donkeyShare: No info on %s" fullname;
+              lprintf_nl "donkeyShare: No info on %s" fullname;
 
 	  let found = ref false in
 	  List.iter (fun sh -> if sh.shared_name = fullname then found := true) !shared_files;
 	  if not !found then begin
+        let magic =
+          match Magic.M.magic_fileinfo fullname false with
+            None -> None
+          | Some magic -> Some (HashMagic.merge files_magic magic)
+        in
+
           let rec impl = {
               impl_shared_update = 1;
               impl_shared_fullname = fullname;
@@ -297,6 +311,7 @@ lprintf "Searching %s" fullname; lprint_newline ();
           	  impl_shared_id = Md4.null;
               impl_shared_val = pre_shared;
               impl_shared_requests = 0;
+              impl_shared_magic = magic;
             } and
             pre_shared = {
               shared_shared = impl;
@@ -324,13 +339,13 @@ let remember_shared_info file new_name =
           Unix32.mtime disk_name
         with _ ->
             if !verbose then
-              lprintf_nl () "Share: Trying mtime on new name %s, disk_name %s, TODO: too many files in shared_files_new.ini?"
+              lprintf_nl "Share: Trying mtime on new name %s, disk_name %s, TODO: too many files in shared_files_new.ini?"
 	        new_name (file_disk_name file);
             Unix32.mtime new_name
       in
 
       if !verbose_share then
-          lprintf_nl () "Remember %s" new_name;
+          lprintf_nl "Remember %s" new_name;
 
       let size = file_size file in
       if not (Hashtbl.mem shared_files_info
@@ -345,7 +360,7 @@ let remember_shared_info file new_name =
         known_shared_files =:= s :: !!known_shared_files;
         Hashtbl.add shared_files_info (new_name, size, mtime) s
     with e ->
-        lprintf_nl () "Exception %s in remember_shared_info"
+        lprintf_nl "Exception %s in remember_shared_info"
           (Printexc2.to_string e)
 
 let must_share_file file = must_share_file file (file_best_name file) None
