@@ -44,15 +44,13 @@ open FasttrackNetwork
 open FasttrackTypes
 open FasttrackOptions
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[Fasttrack] "
-    (log_time ()); lprintf_nl2
+let log_prefix = "[Fasttrack]"
 
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[Fasttrack] "
-    (log_time ()); lprintf
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 let search_num = ref 0
 
@@ -98,6 +96,8 @@ let file_must_update file =
   file_must_update (as_file file)
 let server_num s =
   server_num (as_server s.server_server)
+let server_must_update s =
+  server_must_update (as_server s.server_server)
 let server_state s =
   server_state (as_server s.server_server)
 let set_server_state s state =
@@ -107,6 +107,7 @@ let set_client_state client state =
   CommonClient.set_client_state (as_client client) state
 let set_client_disconnected client =
   CommonClient.set_client_disconnected (as_client client)
+let client_must_update client = client_must_update (as_client client)
 
 (*************************************************************************)
 (*                                                                       *)
@@ -199,8 +200,10 @@ let new_server ip port =
           server_sock = NoConnection;
           server_ciphers = None;
           server_agent = "<unknown>";
+          server_description = "";
           server_nfiles = Int64.zero;
           server_nusers = Int64.zero;
+          server_maxnusers = 0L;
           server_nkb = 0;
 
           server_need_qrt = true;
@@ -208,6 +211,7 @@ let new_server ip port =
           server_nfiles_last = zero;
           server_nkb_last = 0;
           server_vendor = "";
+          server_last_lni = 0;
 
           server_connected = zero;
           server_query_key = ();
@@ -237,18 +241,21 @@ let add_source r (user : user) =
     end
 
 let new_result file_name file_size tags hashes _ =
-
+ 
   match hashes with
   | [ hash ] ->
       let r =
         try
-          Hashtbl.find results_by_uid hash
+          let r = Hashtbl.find results_by_uid hash in
+          increment_avail r
         with _ ->
+            let tags = update_or_create_avail tags in
             let r = { dummy_result with
                 result_names = [file_name];
                 result_size = file_size;
                 result_tags = tags;
                 result_uids = [Uid.create (Md5Ext hash)];
+                result_source_network = network.network_num;
               }
             in
             let r = update_result_num r in
@@ -266,7 +273,7 @@ let new_file file_temporary file_name file_size file_hash =
   let t = Unix32.create_rw file_temp in
   let file_chunk_size =
     max megabyte (
-      file_size // (max 5L (file_size // (megabytes 5)))
+      1L ++ file_size // (max 5L (1L ++ file_size // (megabytes 5)))
     )
   in
   let uid = Uid.create (Md5Ext file_hash) in
@@ -298,18 +305,18 @@ let new_file file_temporary file_name file_size file_hash =
     }
   in
   incr search_num;
-  let kernel = Int64Swarmer.create_swarmer file_temp file_size min_range_size in
-  let swarmer = Int64Swarmer.create kernel (as_file file)
+  let kernel = CommonSwarming.create_swarmer file_temp file_size min_range_size in
+  let swarmer = CommonSwarming.create kernel (as_file file)
       file_chunk_size in
   file.file_swarmer <- Some swarmer;
   Hashtbl.add searches_by_uid search.search_uid search;
 (*  lprintf "SET SIZE : %Ld\n" file_size;*)
-  Int64Swarmer.set_verifier swarmer ForceVerification;
-  Int64Swarmer.set_verified swarmer (fun _ _ ->
+  CommonSwarming.set_verifier swarmer ForceVerification;
+  CommonSwarming.set_verified swarmer (fun _ _ ->
       file_must_update file;
   );
   (*
-  Int64Swarmer.set_writer swarmer (fun offset s pos len ->
+  CommonSwarming.set_writer swarmer (fun offset s pos len ->
 
       (*
       lprintf "DOWNLOADED: %d/%d/%d\n" pos len (String.length s);
@@ -360,6 +367,7 @@ let new_user kind =
 (*          user_files = []; *)
           user_speed = 0;
           user_vendor = "";
+          user_software = "";
           user_nick = "";
         }  and user_impl = {
           dummy_user_impl with
@@ -399,7 +407,7 @@ client_error = false;
           dummy_client_impl with
           impl_client_val = c;
           impl_client_ops = client_ops;
-	  impl_client_upload = None;
+    impl_client_upload = None;
         } in
       new_client impl;
       Hashtbl.add clients_by_uid kind c;
