@@ -990,7 +990,7 @@ dec: [(63)]
             let my_port = get_int16 m 4 in
 
             let bandwidth = get_int8 m 6 in
-(*	    let next_byte = get_int8 m 7 in *)
+(*      let next_byte = get_int8 m 7 in *)
             let client_name = String.sub m 8 (String.length m - 8) in
 
             NodeInfoReq (my_ip, my_port, bandwidth, client_name)
@@ -1892,17 +1892,17 @@ let check_primitives () =
       let cipher = create_cipher () in
       set_cipher cipher 123456789l 0x29;
       init_cipher cipher;
-      let s = String.create 12 in
+      let s = String.make 12 '0' in
       cipher_packet_set cipher s 0;
-      assert (s = "\000+\007[\021n\135");
-      lprintf "cipher_packet_set s = \"%s\"\n" (String.escaped s);
+      assert (s = "\007\091\205\021\110\233\135\1870000"); 
+      (* lprintf "cipher_packet_set s = \"%s\"\n" (String.escaped s); *)
       let s = "123456789abcdefghijklm\233\234\235" in
       apply_cipher cipher s 0 (String.length s);
-      assert (s = "\016\144Ug\028Z8\008\139\019\018Z7i");
-      lprintf "apply_cipher s = \"%s\"\n" (String.escaped s);
+      assert (s = "\016\210\245\241\144Ug\028Z\229\1928\176\167\192\008\139\019\018Z\1937\226\250i"); 
+      (* lprintf "apply_cipher s = \"%s\"\n" (String.escaped s); *)
       cipher_free cipher;
     with _ ->
-	lprint_newline ();
+  lprint_newline ();
         lprintf "The Fasttrack plugin will not work on your computer, since\n";
         lprintf "the encryption algorithm does not work correctly.\n";
         lprintf "You can try to solve this problem by hacking the C files in\n";
@@ -1947,10 +1947,10 @@ let translate_query q =
           | Field_Completesources
           | Field_Length
           | Field_Availability
-	  | Field_Filerating
-	  | Field_Lastseencomplete
-	  | Field_Mediacodec
-	  | Field_Medialength
+    | Field_Filerating
+    | Field_Lastseencomplete
+    | Field_Mediacodec
+    | Field_Medialength
           | Field_Size -> ()
         end
     | QHasMinVal (field, value) ->
