@@ -41,15 +41,13 @@ open CommonNetwork
 open FileTPTypes
 open FileTPOptions
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[FileTP] "
-    (log_time ()); lprintf_nl2
+let log_prefix = "[FileTP]"
 
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[FileTP] "
-    (log_time ()); lprintf
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 let network = new_network "FTP" "FileTP"
     [ ]
@@ -115,32 +113,19 @@ let set_file_size file size =
   if file_size file = zero && size <> zero then begin
       let file_chunk_size =
         max megabyte (
-          size // (max 5L (size // (megabytes 5)))
+          1L ++ size // (max 5L (1L ++ size // (megabytes 5)))
         )
       in
       file.file_file.impl_file_size <- size;
       let file_temp = Unix32.filename (file_fd file) in
-      let kernel = Int64Swarmer.create_swarmer file_temp size min_range_size in
-      let swarmer = Int64Swarmer.create kernel (as_file file)
+      let kernel = CommonSwarming.create_swarmer file_temp size min_range_size in
+      let swarmer = CommonSwarming.create kernel (as_file file)
           file_chunk_size in
       file.file_swarmer <- Some swarmer;
-      Int64Swarmer.set_verified swarmer (fun _ _ ->
+      CommonSwarming.set_verified swarmer (fun _ _ ->
           file_must_update (as_file file);
       );
       file_must_update (as_file file)
-      (*
-      Int64Swarmer.set_writer swarmer (fun offset s pos len ->
-
-(*
-      lprintf "DOWNLOADED: %d/%d/%d\n" pos len (String.length s);
-      AnyEndian.dump_sub s pos len;
-*)
-
-          if !!CommonOptions.buffer_writes then
-            Unix32.buffered_write_copy (file_fd file) offset s pos len
-          else
-            Unix32.write  (file_fd file) offset s pos len
-      ) *)
     end
 
 let new_file file_id file_name file_size =
@@ -173,8 +158,6 @@ let new_file file_id file_name file_size =
 (*      lprintf "ADD FILE TO DOWNLOAD LIST\n"; *)
   file
 
-exception FileFound of file
-
 let new_file file_id file_name file_size =
   try
     Hashtbl.find files_by_uid file_id
@@ -218,8 +201,8 @@ let add_download file c url =
   if not (List.memq c file.file_clients) then begin
       let chunks = [ Int64.zero, file_size file ] in
       (*
-      let bs = Int64Swarmer.register_uploader file.file_swarmer
-        (Int64Swarmer.AvailableRanges chunks) in *)
+      let bs = CommonSwarming.register_uploader file.file_swarmer
+        (CommonSwarming.AvailableRanges chunks) in *)
       c.client_downloads <- c.client_downloads @ [{
           download_file = file;
           download_url = url;
