@@ -57,6 +57,7 @@ module ClientOption = struct
           let client_port = get_value "client_port" value_to_int in
           let client_uid = get_value "client_uid" (from_value Md4.option) in
           let c = new_client (Known_location(client_ip, client_port)) in
+          c.client_user.user_nick <- (Md4.to_string client_uid);
           
           (try
               c.client_user.user_speed <- get_value "client_speed" value_to_int 
@@ -140,8 +141,8 @@ let value_to_file file_size file_state assocs =
   (match file.file_swarmer with
       None -> ()
     | Some swarmer ->
-        Int64Swarmer.value_to_swarmer swarmer assocs;
-        Int64Swarmer.set_verifier swarmer (
+        CommonSwarming.value_to_swarmer swarmer assocs;
+        CommonSwarming.set_verifier swarmer (
           match file.file_ttr with
             None -> ForceVerification
           | Some ttr ->
@@ -183,7 +184,7 @@ let file_to_value file =
 (*      "file_present_chunks", List
         (List.map (fun (i1,i2) -> 
             SmallList [int64_to_value i1; int64_to_value i2])
-        (Int64Swarmer.present_chunks file.file_swarmer));
+        (CommonSwarming.present_chunks file.file_swarmer));
 *)  
     ]
   in
@@ -196,7 +197,7 @@ let file_to_value file =
     match file.file_swarmer with
     None -> assocs 
   | Some swarmer ->
-      Int64Swarmer.swarmer_to_value swarmer assocs
+      CommonSwarming.swarmer_to_value swarmer assocs
       
 
   (*
