@@ -44,15 +44,13 @@ open GnutellaTypes
 open GnutellaOptions
 open GnutellaNetwork
 
-(* prints a new logline with date, module and starts newline *)
-let lprintf_nl () =
-  lprintf "%s[Gnutella] "
-    (log_time ()); lprintf_nl2
+let log_prefix = "[Gnutella]"
 
-(* prints a new logline with date, module and does not start newline *)
-let lprintf_n () =
-  lprintf "%s[Gnutella] "
-    (log_time ()); lprintf
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
+
+let lprintf_n fmt =
+  lprintf2 log_prefix fmt
 
 let should_update_shared_files = ref false
 
@@ -93,6 +91,7 @@ let file_disk_name file = file_disk_name (as_file file)
 let file_state file =  file_state (as_file file)
 let file_num file =  file_num (as_file file)
 let file_must_update file =  file_must_update (as_file file)
+let client_must_update client = client_must_update (as_client client)
 
 let current_files = ref ([] : GnutellaTypes.file list)
 
@@ -179,6 +178,12 @@ module H = CommonHosts.Make(struct
       let max_peers = max_known_peers
     end)
 
+let find_server ip port =
+  try 
+    let h = Hashtbl.find H.hosts_by_key (ip,port) in
+    h.host_server
+  with _ -> None
+
 let new_server ip port =
   let h = H.new_host ip port Ultrapeer in
   match h.host_server with
@@ -190,11 +195,14 @@ let new_server ip port =
           server_host = h;
           server_sock = NoConnection;
           server_agent = "<unknown>";
+          server_description = "";
           server_nfiles = Int64.zero;
           server_nkb = 0;
           server_nusers = Int64.zero;
+          server_maxnusers = 0L;
           server_need_qrt = true;
           server_ping_last = Md4.random ();
+          server_last_lni = 0;
           server_nfiles_last = Int64.zero;
           server_nkb_last = 0;
           server_vendor = "";
@@ -232,7 +240,7 @@ let add_source r (s : user) (index : file_uri) =
       ss := (key, last_time ()) :: !ss
     end
 
-let new_result file_name file_size tags (uids : Uid.t list) sources =
+let new_result file_name file_size (tags : CommonTypes.tag list) (uids : Uid.t list) sources =
   match uids with
     [] -> (*
         lprintf "New result by key\n"; 
@@ -257,13 +265,18 @@ let new_result file_name file_size tags (uids : Uid.t list) sources =
         lprintf "New result by UID\n"; 
       let rs = 
         try
-          Hashtbl.find results_by_uid (Uid.to_uid uid)
+          let r = Hashtbl.find results_by_uid (Uid.to_uid uid) in
+          increment_avail r
         with _ -> 
+
+            let tags = update_or_create_avail tags in 
+
             let r = { dummy_result with
                 result_names = [file_name];
                 result_size = file_size;
                 result_tags = tags;
                 result_uids = uids;
+                result_source_network = network.network_num;
                 }
             in
             let rs = update_result_num r in
@@ -324,11 +337,11 @@ let new_file file_temporary file_name file_size file_uids =
     } 
   in
   if !verbose then
-    lprintf "SET SIZE : %Ld\n" file_size;
-  let kernel = Int64Swarmer.create_swarmer file_temp file_size 
+    lprintf_nl "SET SIZE : %Ld\n" file_size;
+  let kernel = CommonSwarming.create_swarmer file_temp file_size 
       (Int64.of_int (256 * 1024))  in
-  let swarmer = Int64Swarmer.create kernel (as_file file) megabyte in
-  Int64Swarmer.set_verifier swarmer ForceVerification;
+  let swarmer = CommonSwarming.create kernel (as_file file) megabyte in
+  CommonSwarming.set_verifier swarmer ForceVerification;
   
 (* TODO: we could generalize this approach to any UID that is computed
   on the complete file (md5, sha1,...) *)
@@ -336,7 +349,7 @@ let new_file file_temporary file_name file_size file_uids =
     List.iter (fun uid ->
         match Uid.to_uid uid with
           (Sha1 _) as uid ->
-            Int64Swarmer.set_verifier swarmer (Verification [| uid |])
+            CommonSwarming.set_verifier swarmer (Verification [| uid |])
         | _ ->()) file_uids;
   file.file_swarmer <- Some swarmer;
   current_files := file :: !current_files;
@@ -389,6 +402,7 @@ let new_user kind =
           user_speed = 0;
           user_vendor = "";
 (*          user_gnutella2 = false; *)
+          user_software = "";
           user_nick = "";
         }  and user_impl = {
           dummy_user_impl with
@@ -429,7 +443,7 @@ client_error = false;
           dummy_client_impl with
           impl_client_val = c;
           impl_client_ops = client_ops;
-	  impl_client_upload = None;
+    impl_client_upload = None;
         } in
       new_client impl;
       Hashtbl.add clients_by_uid kind c;
@@ -442,8 +456,8 @@ let add_download file c index =
     lprintf "Adding file to client\n";
   if not (List.memq c file.file_clients) then begin
       let chunks = [ Int64.zero, file_size file ] in
-(*      let up = Int64Swarmer.register_uploader file.file_swarmer 
-          (Int64Swarmer.AvailableRanges chunks) in *)
+(*      let up = CommonSwarming.register_uploader file.file_swarmer 
+          (CommonSwarming.AvailableRanges chunks) in *)
       c.client_downloads <- c.client_downloads @ [{
           download_file = file;
           download_uri = index;
@@ -526,6 +540,8 @@ let client_ip sock =
   (match sock with Connection sock -> Some sock | _ -> None)
 
 let disconnect_from_server s r =
+  if !verbose then
+    lprintf_nl "disconnect_from_server %s" (string_of_reason r);
   match s.server_sock with
   | Connection sock ->
       let h = s.server_host in
@@ -534,9 +550,9 @@ let disconnect_from_server s r =
             let connection_time = Int64.to_int (
                 Int64.sub (int64_time ()) s.server_connected) in
             if !verbose then
-              lprintf "DISCONNECT FROM SERVER %s:%d after %d seconds\n"
+              lprintf_nl "disconnect_from_connected_server %s:%d after %d seconds (%s)\n"
                 (Ip.string_of_addr h.host_addr) h.host_port
-                connection_time
+                connection_time (string_of_reason r)
             ;
         | _ -> ()
       );
