@@ -127,7 +127,7 @@ let scan_format fmt pos cont_s cont_a cont_t =
     | 'f' | 'e' | 'E' | 'g' | 'G' ->
         Obj.magic(fun (f: float) ->
           cont_s (format_float (extract_format fmt pos i widths) f) (succ i))
-    | 'b' ->
+    | 'b' | 'B' ->
         Obj.magic(fun (b: bool) ->
           cont_s (string_of_bool b) (succ i))
     | 'a' ->
@@ -198,12 +198,16 @@ let lprintf fmt =
   cprintf (fun s -> try !lprintf_handler s with _ -> ())
   (fmt : ('a,unit, unit) format )
 
+let lprintf2 m fmt =
+  cprintf (fun s -> try !lprintf_handler ((log_time ())^m^" "^s) with _ -> ())
+  (fmt : ('a,unit, unit) format )
+
 let lprintf_nl fmt =
   cprintf (fun s -> try !lprintf_handler ((log_time ())^s^"\n") with _ -> ())
   (fmt : ('a,unit, unit) format )
 
-let lprintf_nl2 fmt =
-  cprintf (fun s -> try !lprintf_handler (s^"\n") with _ -> ())
+let lprintf_nl2 m fmt =
+  cprintf (fun s -> try !lprintf_handler ((log_time ())^m^" "^s^"\n") with _ -> ())
   (fmt : ('a,unit, unit) format )
 
 let lprint_newline () = lprintf "\n"
