@@ -17,22 +17,24 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "../../../config/config.h"
 #include "../../utils/lib/os_stubs.h"
 
 #include <string.h> 
 #include <ctype.h>
-#include <caml/config.h>
-#include <caml/signals.h>
+
+
 #ifdef __MORPHOS__
 #include <inttypes.h>
-#endif
+#endif  /* __MORPHOS__ */
+
+#ifdef HAVE_SYS_RESOURCE_H
+#include <sys/resource.h>
+#endif /* HAVE_SYS_RESOURCE_H */
 
 #define lseek XXXXXXXXX
 #define read XXXXXXXXX
 #define ftruncate XXXXXXXXX
 
-#define UNIX_BUFFER_SIZE 16384
 
 
 /*******************************************************************
@@ -54,7 +56,8 @@
 
 /* Stubs that could be used by epoll */
 
-value ml_change_fd_event_setting(value task_v){
+value ml_change_fd_event_setting(value task_v)
+{
   int fd = Socket_val(Field(task_v,FD_TASK_FD));
   int must_read = ((Field(task_v, FD_TASK_RLEN) != Val_int(0)) &&
     (Field(Field(task_v, FD_TASK_READ_ALLOWED),0) == Val_true));
@@ -64,7 +67,8 @@ value ml_change_fd_event_setting(value task_v){
   return Val_unit;
 }
 
-value ml_add_fd_to_event_set(value task_v){
+value ml_add_fd_to_event_set(value task_v)
+{
   int fd = Socket_val(Field(task_v,FD_TASK_FD));
   int must_read = ((Field(task_v, FD_TASK_RLEN) != Val_int(0)) &&
     (Field(Field(task_v, FD_TASK_READ_ALLOWED),0) == Val_true));
@@ -74,15 +78,14 @@ value ml_add_fd_to_event_set(value task_v){
   return Val_unit;
 }
 
-value ml_remove_fd_from_event_set(value task_v){
+value ml_remove_fd_from_event_set(value task_v)
+{
   int fd = Socket_val(Field(task_v,FD_TASK_FD));
 
   return Val_unit;
 }
 
 
-
-
 #if defined(HAVE_POLL) && defined(HAVE_SYS_POLL_H) && !defined(__MINGW32__)
 
 #include <sys/poll.h>
@@ -143,14 +146,14 @@ value try_poll(value fdlist, value timeout) /* ML */
       if (ufds[pos].revents){
         value v = pfds[pos];
 /*        int fd = Socket_val(Field(v,FD_TASK_FD)); */
-      /*  printf("TESTING %d AT %d\n", fd, pos); */
-      /*  fprintf(stderr, "FOR FD in POLL %d[%d]\n", fd, ufds[pos].revents); */
+/*        printf("TESTING %d AT %d\n", fd, pos); */
+/*        fprintf(stderr, "FOR FD in POLL %d[%d]\n", fd, ufds[pos].revents); */
         value flags = Val_int(0);
         retcode--;
         if (ufds[pos].revents & (POLLIN|POLLERR|POLLHUP))  flags |= 2;
         if (ufds[pos].revents & POLLOUT) flags |= 4;
-        /*        if (ufds[pos].revents & POLLNVAL) */
-        /*        Field(v, FD_TASK_CLOSED) = Val_true; */
+/*                if (ufds[pos].revents & POLLNVAL) */
+/*                Field(v, FD_TASK_CLOSED) = Val_true; */
         Field(v,FD_TASK_FLAGS) = flags;
       }
     }
@@ -158,7 +161,8 @@ value try_poll(value fdlist, value timeout) /* ML */
   return Val_unit;
 }
 
-#endif
+#endif /* defined(HAVE_POLL) && defined(HAVE_SYS_POLL_H) && !defined(__MINGW32__) */
+
 
 value try_select(value fdlist, value timeout) /* ML */
 {
@@ -238,7 +242,6 @@ value ml_use_poll(value use)
 
 value ml_select(value fd_list, value timeout)
 {
-
 #if defined(HAVE_POLL) && defined(HAVE_SYS_POLL_H) && !defined(__MINGW32__)
     if (use_poll) 
       return try_poll(fd_list, timeout);
@@ -247,7 +250,6 @@ value ml_select(value fd_list, value timeout)
 #else
     return try_select(fd_list, timeout);
 #endif
-
 }
 
 /*******************************************************************
@@ -256,13 +258,12 @@ value ml_select(value fd_list, value timeout)
                          ml_getdtablesize
 
 
- *******************************************************************/
+********************************************************************/
 
 value ml_getdtablesize(value unit)
 {
   int dtablesize = os_getdtablesize();
   int maxselectfds = FD_SETSIZE;
-
   int maxfd = dtablesize;
 
   if (maxselectfds < maxfd) {
@@ -275,7 +276,7 @@ value ml_getdtablesize(value unit)
 #else
 
       maxfd = maxselectfds;
-		  // printf("[Info] File descriptor limit: MIN(process: %d, select(): %d) = %d\n", dtablesize, maxselectfds, maxfd);
+/*		   printf("[Info] File descriptor limit: MIN(process: %d, select(): %d) = %d\n", dtablesize, maxselectfds, maxfd); */
 
 #endif
   }
@@ -338,7 +339,7 @@ value ml_setsock_iptos_throughput(value sock_v)
   return Val_unit;
 }
 
-#endif
+#endif /* defined(HAVE_NETINET_IP_H) && !defined(__MINGW32__) */
 
 
 /*******************************************************************
@@ -474,7 +475,7 @@ value ml_ints_of_string(value s_v)
   goto ok;
 
   error:
-  /* printf("Error while parsing[%s]\n",s); */
+/*   printf("Error while parsing[%s]\n",s); */
   raise_not_found();
 /*  a1 = a2 = a3 = a4 = 0; */
 
@@ -587,11 +588,11 @@ ML_HASH(md4,MD4_CTX,MD4Init,MD4Update,md4_finish)
 *******************************************************************/
 #include "tiger.h"
 
-static void tiger_tree_fd(OS_FD fd, size_t len, size_t pos, size_t block_size, char *digest)
+static void tiger_tree_fd(OS_FD fd, OFF_T len, OFF_T pos, OFF_T block_size, char *digest)
 {
   static char tiger_buffer[BLOCK_SIZE+1];
   if(block_size == BLOCK_SIZE){
-    size_t length = (len - pos > BLOCK_SIZE) ? BLOCK_SIZE : len - pos;
+    OFF_T length = (len - pos > BLOCK_SIZE) ? BLOCK_SIZE : len - pos;
     char *s = tiger_buffer+1;
     size_t toread = length;
     char *curs = s;
@@ -653,40 +654,31 @@ value ml_setlcnumeric(value no)
   return Val_unit;
 }
 
-/******************************************************************/
+/*******************************************************************
 
 
-/*        Asynchronous resolution of DNS names in threads         */
+          Asynchronous resolution of DNS names in threads         
 
 
-/******************************************************************/
+*******************************************************************/
 
+/*
+#include <signals.h>
+#include "unixsupport.h"
 
-
-
-
-
-
-
-#include <caml/mlvalues.h>
-#include <caml/alloc.h>
-#include <caml/memory.h>
-#include <caml/fail.h>
-///#include <signals.h>
-//#include "unixsupport.h"
-
-// #include "socketaddr.h"
+#include "socketaddr.h"
+*/
 #ifndef _WIN32
-// #include <sys/types.h>
+/* #include <sys/types.h> */
 #include <netdb.h>
-#endif
+#endif /* ndef _WIN32 */
 
 #define NETDB_BUFFER_SIZE 10000
 
 #ifdef _WIN32
 #define GETHOSTBYADDR_IS_REENTRANT 1
 #define GETHOSTBYNAME_IS_REENTRANT 1
-#endif
+#endif /* _WIN32 */
 
 static char volatile ip_job_result[256];
 static int volatile job_naddresses = 0;
@@ -740,12 +732,12 @@ static int ml_gethostbyname(char *hostname)
 #else
 #ifdef GETHOSTBYNAME_IS_REENTRANT
   enter_blocking_section();
-#endif
+#endif  /* GETHOSTBYNAME_IS_REENTRANT */
   hp = gethostbyname(hostname);
 #ifdef GETHOSTBYNAME_IS_REENTRANT
   leave_blocking_section();
-#endif
-#endif
+#endif /* GETHOSTBYNAME_IS_REENTRANT */
+#endif /* HAS_GETHOSTBYNAME_R == 5 */
 
   if (hp == (struct hostent *) NULL) return 0;
 
@@ -782,7 +774,7 @@ static void store_in_job(value job_v)
   adr = alloc_one_addr(ip_job_result);
   addr_list = alloc_small(1, 0);
   Field(addr_list, 0) = adr;
-#endif
+#endif  /* h_addr */
   modify(&Field(job_v,1), addr_list);
   End_roots();
 }
@@ -808,9 +800,11 @@ value ml_ip_job_done(value job_v)
 
 
 value ml_has_pthread(value unit)
-{ return Val_false; }
+{ 
+  return Val_false; 
+}
 
-#else
+#else  /* !defined(HAVE_PTHREAD) || (!(HAS_GETHOSTBYNAME_R || GETHOSTBYNAME_IS_REENTRANT) && !defined(HAS_SIGWAIT)) */
 
 #include <string.h>
 #include <pthread.h>
@@ -850,12 +844,12 @@ static void * hasher_thread(void * arg)
 #if !defined(PTW32_STATIC_LIB)	
   sigset_t mask;
 
-  /* Block all signals so that we don't try to execute a Caml signal handler */
+/*   Block all signals so that we don't try to execute a Caml signal handler */
   sigfillset(&mask);
   pthread_sigmask(SIG_BLOCK, &mask, NULL);
   
   nice(19);
-#endif
+#endif  /* !defined(PTW32_STATIC_LIB) */
   
   pthread_mutex_lock(&mutex);
 
@@ -913,14 +907,22 @@ value ml_ip_job_start(value job_v)
 }
 
 value ml_has_pthread(value unit)
-{ return Val_true; }
+{
+  return Val_true; 
+}
 
-#endif
+#endif  /* !defined(HAVE_PTHREAD) || (!(HAS_GETHOSTBYNAME_R || GETHOSTBYNAME_IS_REENTRANT) && !defined(HAS_SIGWAIT)) */
 
-#include <caml/custom.h>
-#include <caml/callback.h>
+/*******************************************************************
+
+
+                         statfs
+
+
+*******************************************************************/
 
 #if defined(__MINGW32__)
+
 /* taken from www.greatchief.plus.com/gpc/os-hacks.h */
 #define _fullpath(res,path,size) \
   (GetFullPathNameW ((path), (size), (res), NULL) ? (res) : NULL)
@@ -1024,6 +1026,7 @@ static int statfs (const unsigned char *path, struct statfs *buf)
     return retval;
 }
 
+
 static value
 copy_statfs (struct statfs *buf)
 {
@@ -1056,17 +1059,18 @@ statfs_statfs (value pathv)
   CAMLreturn (bufv);
 }
 
-#else /* defined(__MINGW32__) */
+#else  /* defined(__MINGW32__) */
 
 #if (defined HAVE_SYS_PARAM_H && HAVE_SYS_MOUNT_H)
 #  include <sys/param.h>
 #  include <sys/mount.h>
 #  define HAVE_STATS 1
-#endif
+#endif  /* (defined HAVE_SYS_PARAM_H && HAVE_SYS_MOUNT_H) */
+
 #ifdef HAVE_SYS_VFS_H
 #  include <sys/vfs.h>
 #  define HAVE_STATS 1
-#endif
+#endif  /* HAVE_SYS_VFS_H */
 
 #ifdef HAVE_STATS
 static value
@@ -1074,7 +1078,7 @@ static value
 copy_statfs (struct statvfs *buf)
 #else
 copy_statfs (struct statfs *buf)
-#endif
+#endif  /* ((defined (sun) || defined (__sun__))) || (defined(__NetBSD__) && (__NetBSD_Version__ > 299000000)) || defined (__hpux__) */
 {
   CAMLparam0 ();
   CAMLlocal2 (bufv, v);
@@ -1083,7 +1087,7 @@ copy_statfs (struct statfs *buf)
   v = copy_int64 (-1); caml_modify (&Field (bufv, 0), v);
 #else
   v = copy_int64 (buf->f_type); caml_modify (&Field (bufv, 0), v);
-#endif /* ((defined (sun) || defined (__sun__))) || (defined(__FreeBSD__) && __FreeBSD_version >= 503001) || defined(__OpenBSD__) || defined(__NetBSD__) */
+#endif  /* ((defined (sun) || defined (__sun__))) || (defined(__FreeBSD__) && __FreeBSD_version >= 503001) || defined(__OpenBSD__) || defined(__NetBSD__) */
   v = copy_int64 (buf->f_bsize); caml_modify (&Field (bufv, 1), v);
   v = copy_int64 (buf->f_blocks); caml_modify (&Field (bufv, 2), v);
   v = copy_int64 (buf->f_bfree); caml_modify (&Field (bufv, 3), v);
@@ -1096,8 +1100,8 @@ copy_statfs (struct statfs *buf)
   v = copy_string (buf->f_basetype); caml_modify (&Field (bufv, 9), v);
   v = copy_int64 (buf->f_frsize); caml_modify (&Field (bufv, 10), v);
 #else
-#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__)
-#  if defined(__OpenBSD__) || defined(__NetBSD__) || (defined(__FreeBSD__) && __FreeBSD_version < 502000)
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__DragonFly__)
+#  if defined(__OpenBSD__) || defined(__NetBSD__) || (defined(__FreeBSD__) && __FreeBSD_version < 502000) || defined(__DragonFly__)
 #    include <sys/syslimits.h>
      v = copy_int64 (NAME_MAX); caml_modify (&Field (bufv, 8), v);
 #  else
@@ -1118,7 +1122,7 @@ copy_statfs (struct statfs *buf)
 #endif /*  ((defined (sun) || defined (__sun__))) || defined (__hpux__) */
   CAMLreturn (bufv);
 }
-#endif
+#endif /* HAVE_STATS */
 
 CAMLprim value
 statfs_statfs (value pathv)
@@ -1133,32 +1137,38 @@ statfs_statfs (value pathv)
 #else
   struct statfs buf;
   if (statfs (path, &buf) == -1)
-#endif
+#endif  /* ((defined (sun) || defined (__sun__))) || (defined(__NetBSD__) && (__NetBSD_Version__ > 299000000)) || defined (__hpux__) */
     raise_constant(*(value *)caml_named_value("error"));
   bufv = copy_statfs (&buf);
   CAMLreturn (bufv);
 #else
   raise_constant(*(value *)caml_named_value("not supported"));
-#endif
+#endif  /* HAVE_STATS */
 }
-#endif /* defined(__MINGW32__) */
+#endif  /* defined(__MINGW32__) */
 
+/*******************************************************************
+
+
+                         external_start
+                         external_exit
+
+
+*******************************************************************/
 
 #if defined(__MINGW32__)
 static HWND myHWND = NULL;
 #endif
 
 value
-external_start (value version)
+external_start (void)
 {
 
-// Disable close button on console
+/* Disable close button on console */
 #if defined(__MINGW32__)
-  char *buf = "[MLDonkey TitleSearch]\0"; // if multiple instances
-  char *title = String_val (version);
+  char *buf = "[MLDonkey TitleSearch]\0"; /* if multiple instances */
   SetConsoleTitle((LPCTSTR)buf);
   myHWND = FindWindowEx(NULL, NULL, NULL, (LPCTSTR)buf);
-  SetConsoleTitle((LPCTSTR)title);
 
   if (myHWND != NULL) {
     HMENU hmenu = GetSystemMenu(myHWND, FALSE);
@@ -1170,7 +1180,7 @@ external_start (value version)
     SetMenuItemInfo(hmenu, SC_CLOSE, FALSE, &CloseItem);
     DrawMenuBar(myHWND);
   }
-#endif
+#endif  /* defined(__MINGW32__) */
 
 #if defined(HAVE_PTHREAD) && defined(PTW32_STATIC_LIB)
 	pthread_win32_process_attach_np();
@@ -1179,17 +1189,10 @@ external_start (value version)
 
 }
 
-// Crypto 
-void crypto_exit();
-void createKey(char buf[]);
-unsigned long loadKey(char privateKeyBase64[], char buf[]);
-int createSignature(byte *buf, int maxLen, byte *key, int keyLen, uint32_t cInt, uint8_t ipType, uint32_t ip);
-int verifySignature(byte *key, int keyLen, byte *sig, int sigLen, uint32_t cInt, uint8_t ipType, uint32_t ip);
-
 value
 external_exit (void) 
 {
-// Revert console system menu
+/* Revert console system menu */
 #if defined(__MINGW32__)
   if (myHWND != NULL) {
     HMENU hmenu = GetSystemMenu(myHWND, FALSE);
@@ -1201,89 +1204,45 @@ external_exit (void)
     EnableMenuItem(hmenu, SC_CLOSE, MF_BYCOMMAND | MF_ENABLED);
     DrawMenuBar(myHWND);
   }
-#endif
+#endif  /* defined(__MINGW32__) */
 
 #if defined(HAVE_PTHREAD) && defined(PTW32_STATIC_LIB)
 	pthread_win32_process_detach_np();
 #endif
 
-	crypto_exit();
+#if defined(HAVE_CRYPTOPP)
+/*	crypto_exit(); */
+#endif
 	return Val_unit;
 }
 
+/*******************************************************************
+
+
+                         ml_uname
+
+
+*******************************************************************/
+
 value
-ml_uname(void) {
+ml_uname(void) 
+{
 	char buf[4096];
 	buf[0] = '\0';
 	os_uname(buf);
 	return caml_copy_string(buf);
 }
 
+/*******************************************************************
 
-// return private key Base64Encoded
-value 
-ml_createKey() {
-	char buf[4096];
-	createKey(buf);
-	return caml_copy_string(buf);
-}
 
-// return public key
-value 
-ml_loadKey(value privatekey) {
-  char *s = String_val(privatekey);
-	char buf[4096];
-	unsigned long len =	loadKey(s, buf);
+                         ml_check_endianness
 
-  value res;
-  res = caml_alloc_string(len);
-  memmove(String_val(res), buf, len);
 
-	return res;
-}
-
-value
-ml_createSignature(value m_key, value m_keyLen, value m_cInt, value m_ipType, value m_ip) {
-
-	byte *key = (byte*) String_val(m_key);
-	int keyLen = Int_val(m_keyLen);
-	uint32_t cInt = Int64_val(m_cInt);
-	int ipType = Int_val(m_ipType);
-	uint32_t ip = Int64_val(m_ip);
-
-	byte buf[4096];
-
-	int len = createSignature(buf, 200, key, keyLen, cInt, ipType, ip);
-
-  value res;
-  res = caml_alloc_string(len);
-  memmove(String_val(res), buf, len);
-
-	return res;
-}
+*******************************************************************/
 
 value 
-ml_verifySignature(value m_key, value m_keyLen, value m_sig, value m_sigLen, value m_cInt, value m_ipType, value m_ip) {
-
-	byte* key = (byte*) String_val(m_key);
-	int keyLen = Int_val(m_keyLen);
-	byte* sig = (byte*) String_val(m_sig);
-	int sigLen = Int_val(m_sigLen);
-	uint32_t cInt = Int64_val(m_cInt);
-	int ipType = Int_val(m_ipType);
-	uint32_t ip = Int64_val(m_ip);
-	
-	return Val_bool( 
-			verifySignature(key, keyLen, sig, sigLen, cInt, ipType, ip)
-	);
-}
-
-value
-ml_verifySignature_bytecode(value *argv, int argn) {
-	return ml_verifySignature(argv[0], argv[1], argv[2], argv[3], argv[4], argv[5], argv[6]);
-}
-
-value ml_check_endianness(void)
+ml_check_endianness(void)
 {
   CAMLparam0 ();
   CAMLlocal1 (v);
@@ -1294,3 +1253,230 @@ value ml_check_endianness(void)
 #endif
   CAMLreturn (v);
 }
+
+/*******************************************************************
+
+
+                         rlimit
+
+
+*******************************************************************/
+
+value 
+ml_getrlimit(value resource) 
+{
+#ifdef HAVE_GETRLIMIT
+  CAMLparam1(resource);
+  CAMLlocal1(retval);
+  int r;
+  struct rlimit lim;
+
+  switch (Int_val(resource)) {
+  case 0:
+#ifdef RLIMIT_CPU
+    r = RLIMIT_CPU;
+#else
+    r = -1;
+#endif
+    break;
+  case 1:
+#ifdef RLIMIT_FSIZE
+    r = RLIMIT_FSIZE;
+#else
+    r = -1;
+#endif
+    break;
+  case 2:
+#ifdef RLIMIT_DATA
+    r = RLIMIT_DATA;
+#else
+    r = -1;
+#endif
+    break;
+  case 3:
+#ifdef RLIMIT_STACK
+    r = RLIMIT_STACK;
+#else
+    r = -1;
+#endif
+    break;
+  case 4:
+#ifdef RLIMIT_CORE
+    r = RLIMIT_CORE;
+#else
+    r = -1;
+#endif
+    break;
+  case 5:
+#ifdef RLIMIT_RSS
+    r = RLIMIT_RSS;
+#else
+    r = -1;
+#endif
+    break;
+  case 6:
+#ifdef RLIMIT_NPROC
+    r = RLIMIT_NPROC;
+#else
+    r = -1;
+#endif
+    break;
+  case 7:
+#ifdef RLIMIT_NOFILE
+    r = RLIMIT_NOFILE;
+#elif RLIMIT_OFILE
+    r = RLIMIT_OFILE:
+#else
+    r = -1;
+#endif
+    break;
+  case 8:
+#ifdef RLIMIT_MEMLOCK
+    r = RLIMIT_MEMLOCK;
+#else
+    r = -1;
+#endif
+    break;
+  case 9:
+#ifdef RLIMIT_AS
+    r = RLIMIT_AS;
+#else
+    r = -1;
+#endif
+    break;
+  default:
+    errno = EINVAL;
+    uerror("getrlimit", Nothing);    
+  }
+
+  if (getrlimit(r, &lim) < 0) 
+    uerror("getrlimit", Nothing);
+
+  
+  retval = alloc_tuple(2);
+  Field(retval, 0) = Val_int(lim.rlim_cur);
+  Field(retval, 1) = Val_int(lim.rlim_max);
+
+  CAMLreturn(retval);
+
+#else
+  failwith("getrlimit unimplemented");
+#endif
+}
+
+value 
+ml_setrlimit(value resource, value rlimit) 
+{
+#ifdef HAVE_SETRLIMIT
+  int r;
+  struct rlimit lim;
+
+  switch (Int_val(resource)) {
+  case 0:
+#ifdef RLIMIT_CPU
+    r = RLIMIT_CPU;
+#else
+    r = -1;
+#endif
+    break;
+  case 1:
+#ifdef RLIMIT_FSIZE
+    r = RLIMIT_FSIZE;
+#else
+    r = -1;
+#endif
+    break;
+  case 2:
+#ifdef RLIMIT_DATA
+    r = RLIMIT_DATA;
+#else
+    r = -1;
+#endif
+    break;
+  case 3:
+#ifdef RLIMIT_STACK
+    r = RLIMIT_STACK;
+#else
+    r = -1;
+#endif
+    break;
+  case 4:
+#ifdef RLIMIT_CORE
+    r = RLIMIT_CORE;
+#else
+    r = -1;
+#endif
+    break;
+  case 5:
+#ifdef RLIMIT_RSS
+    r = RLIMIT_RSS;
+#else
+    r = -1;
+#endif
+    break;
+  case 6:
+#ifdef RLIMIT_NPROC
+    r = RLIMIT_NPROC;
+#else
+    r = -1;
+#endif
+    break;
+  case 7:
+#ifdef RLIMIT_NOFILE
+    r = RLIMIT_NOFILE;
+#elif RLIMIT_OFILE
+    r = RLIMIT_OFILE:
+#else
+    r = -1;
+#endif
+    break;
+  case 8:
+#ifdef RLIMIT_MEMLOCK
+    r = RLIMIT_MEMLOCK;
+#else
+    r = -1;
+#endif
+    break;
+  case 9:
+#ifdef RLIMIT_AS
+    r = RLIMIT_AS;
+#else
+    r = -1;
+#endif
+    break;
+  default:
+    errno = EINVAL;
+    uerror("getrlimit", Nothing);    
+  }
+
+  lim.rlim_cur = Int_val(Field(rlimit, 0));
+  lim.rlim_max = Int_val(Field(rlimit, 1));
+
+  if (setrlimit(r, &lim) < 0) 
+    uerror("setrlimit", Nothing);
+
+  return Val_unit;
+
+#else
+  failwith("getrlimit unimplemented");
+#endif
+}
+
+/*******************************************************************
+
+
+                         ml_os_supported
+
+
+*******************************************************************/
+
+value ml_os_supported(value unit)
+{
+	int buf = os_os_supported();
+		
+	if ( buf == 1 )
+	  return Val_true;
+	else
+	  return Val_false;
+}
+
