@@ -22,10 +22,10 @@
 open Int64ops
 open Printf2
 
-let lprintf_nl =
-  (fun format ->
-     lprintf "%s[Ux32] " (log_time ()); 
-     lprintf_nl2 format)
+let log_prefix = "[Ux32]"
+
+let lprintf_nl fmt =
+  lprintf_nl2 log_prefix fmt
   
 let chunk_min_size = ref 65000L
   
@@ -150,8 +150,13 @@ module FDCache = struct
          destroyed = false;
         }
       in
+      try
       let _fd = _local_force_fd true t in
       t
+      with
+	Unix.Unix_error (Unix.EISDIR, _, _) -> t
+      | Unix.Unix_error (Unix.EACCES, _, _) when Autoconf.windows -> t
+      | e -> raise e
       
     let local_force_fd t = _local_force_fd false t
 
@@ -173,23 +178,6 @@ module FDCache = struct
         (Printexc2.to_string e);
       raise e
 
-    let multi_rename t f file =
-      try
-      check_destroyed t;
-      close t;
-      (let d = (Filename.dirname (Filename.concat f file)) in
-        Unix2.safe_mkdir d;
-        Unix2.chmod d (Misc.int_of_octal_string !create_dir_mask);
-	Unix2.can_write_to_directory d);
-      Unix2.rename t.filename (Filename.concat f file);
-      destroy t
-      with e ->
-      if !verbose then lprintf_nl "Exception in FDCache.multi_rename %s %s: %s"
-        t.filename
-        (Filename.concat f file)
-        (Printexc2.to_string e);
-      raise e
-
     let ftruncate64 t len sparse =
       try
       check_destroyed t;
@@ -205,17 +193,29 @@ module FDCache = struct
     let getsize64 t =
       try
       check_destroyed t;
-      let was_closed = is_closed t in
-      let s = Unix2.c_getfdsize64 (local_force_fd t) in
-      if was_closed then
-        close t;
-      s
-      with e ->
+      Unix2.c_getfdsize64 (local_force_fd t)
+      with
+	Unix.Unix_error (Unix.EISDIR, _, _) -> 0L
+      | Unix.Unix_error (Unix.EACCES, _, _) when Autoconf.windows -> 0L
+      | e ->
       if !verbose then lprintf_nl "Exception in FDCache.getsize64 %s: %s"
         t.filename
         (Printexc2.to_string e);
       raise e
 
+    let owner t =
+      try
+      check_destroyed t;
+      let s = Unix.fstat (local_force_fd t) in
+      let user = Unix.getpwuid s.Unix.st_uid in
+      let group = Unix.getgrgid s.Unix.st_gid in
+      user.Unix.pw_name, group.Unix.gr_name
+      with e ->
+      if !verbose then lprintf_nl "Exception in FDCache.owner %s: %s"
+        t.filename
+        (Printexc2.to_string e);
+      raise e
+
     let mtime64 t =
       try
       check_destroyed t;
@@ -249,6 +249,28 @@ module FDCache = struct
         (Printexc2.to_string e);
       raise e
 
+    let multi_rename t f file =
+      try
+      check_destroyed t;
+      close t;
+      (let d = (Filename.dirname (Filename.concat f file)) in
+        Unix2.safe_mkdir d;
+        Unix2.chmod d (Misc.int_of_octal_string !create_dir_mask);
+	Unix2.can_write_to_directory d);
+      (try
+        Unix2.rename t.filename (Filename.concat f file);
+      with
+        Unix.Unix_error (Unix.EACCES, _, _) when
+          Autoconf.windows && (Unix2.list_directory t.filename = [])
+        -> remove t);
+      destroy t
+      with e ->
+      lprintf_nl "Exception in FDCache.multi_rename %s %s: %s"
+        t.filename
+        (Filename.concat f file)
+        (Printexc2.to_string e);
+      raise e
+
     let read file file_pos string string_pos len =
       try
       let fd = local_force_fd file in
@@ -331,8 +353,8 @@ module type File =   sig
     val remove : t -> unit
     val read : t -> int64 -> string -> int -> int -> unit
     val write : t -> int64 -> string -> int -> int -> unit
-      
     val destroy : t -> unit
+    val is_closed : t -> bool
   end
 
 
@@ -353,12 +375,14 @@ module DiskFile = struct
     let ftruncate64 = FDCache.ftruncate64
 
     let getsize64 = FDCache.getsize64
+    let owner = FDCache.owner
     let mtime64 = FDCache.mtime64
     let exists = FDCache.exists
     let remove = FDCache.remove
     let read = FDCache.read
     let write = FDCache.write
     let destroy = FDCache.destroy
+    let is_closed = FDCache.is_closed
   end
 
 let zero_chunk_len = 65536L
@@ -450,18 +474,12 @@ module MultiFile = struct
             let temp_filename = Filename.concat dirname filename in
             Unix2.safe_mkdir (Filename.dirname temp_filename);
             let fd = FDCache.create temp_filename writable in
-            let cur_len = 
-	      if Unix2.is_directory temp_filename then 0L
-	      else begin
-		ignore(FDCache.local_force_fd fd);
-		FDCache.getsize64 fd
-	      end in
             iter tail (pos ++ size)
             ({
                 filename = filename;
                 pos = pos;
                 len = size;
-                current_len = cur_len;
+                current_len = FDCache.getsize64 fd;
                 fd = fd;
                 tail = [];
               } :: files2)
@@ -653,6 +671,7 @@ module MultiFile = struct
       (try Unix.utimes t.dirname time time with _ -> ());
       ()
 
+    let is_closed _ = false
   end
 
 module SparseFile = struct
@@ -679,6 +698,8 @@ module SparseFile = struct
         len = zero_chunk_len;
         fd = zero_chunk_fd ();
       }
+
+    let is_closed _ = false
     
     let create filename writable =
 (*      lprintf_nl "SparseFile.create %s" filename; *)
@@ -1090,6 +1111,18 @@ let dummy =  {
 
 let table = H.create 100
 
+let destroyed t = t.file_kind = Destroyed
+  
+let fd_exists f =
+  try
+    let fd = H.find table { dummy with filename = f } in
+    match fd.file_kind with
+    | DiskFile fd -> not (DiskFile.is_closed fd)
+    | MultiFile fd -> not (MultiFile.is_closed fd)
+    | SparseFile fd -> not (SparseFile.is_closed fd)
+    | Destroyed -> false
+  with Not_found -> false
+
 let create f writable creator =
   try
     let fd = H.find table { dummy with filename = f; writable = writable } in
@@ -1367,15 +1400,48 @@ let remove t =
   | SparseFile t -> SparseFile.remove t
   | Destroyed -> failwith "Unix32.remove on destroyed FD"
       
-let getsize s =  getsize64 (create_ro s)
-let mtime s =  mtime64 (create_ro s)
+let getsize s =
+  let old_fd_exists = fd_exists s in
+  let fd = create_ro s in
+  let size = getsize64 fd in
+  if not old_fd_exists then close fd;
+  size
 
-let file_exists s = 
-  (* We use this instead of Sys.file_exists, in case exists has side
-     effects ? *)
-  try 
-    exists (create_ro s)
-  with Unix.Unix_error (Unix.ENOENT, _, _) -> false
+let mtime s =
+  let old_fd_exists = fd_exists s in
+  let fd = create_ro s in
+  let time = mtime64 fd in
+  if not old_fd_exists then close fd;
+  time
+
+let file_exists s =
+  let old_fd_exists = fd_exists s in
+    try
+      let fd = create_ro s in
+      let exists =
+        try
+          exists fd
+        with Unix.Unix_error (Unix.ENOENT, _, _) -> false
+      in
+      if not old_fd_exists then close fd;
+      exists
+    with Unix.Unix_error (Unix.ENOENT, _, _) -> false
+
+let owner_fd t =
+  match t.file_kind with
+  | DiskFile t -> DiskFile.owner t
+  | MultiFile t -> "", ""
+  | SparseFile t -> "", ""
+  | Destroyed -> "", ""
+
+let owner s =
+  try
+    let old_fd_exists = fd_exists s in
+    let fd = create_ro s in
+    let user,group = owner_fd fd in
+    if not old_fd_exists then close fd;
+    user,group
+  with _ -> "", ""
 
 let rename t f =
   flush_fd t;
@@ -1565,6 +1631,8 @@ The following functions have to be rewritten:
     let create_rw filename = 
       create (create_rw filename)
 
+    let is_closed = FDCache.is_closed
+
 (*
 (* the new part (shared_begin, shared_len) is shared between t1 and t2.
 It will be kept inside t1, and used by t2. The problem is what happens
@@ -1575,8 +1643,6 @@ when these two files have already been partially downloaded ? This
       ()
 *)      
   end
-let destroyed t = t.file_kind = Destroyed
-  
 type t = file
 
 (*
