@@ -115,7 +115,13 @@ let country_name_array = [|
   "Satellite Provider";"Other";
 |]
 
-let unknown_country = ref ("--", "N/A")
+let country_index = Hashtbl.create 10
+let _ =
+  Array.iteri (fun i cc -> 
+    Hashtbl.add country_index cc i
+  ) country_code_array
+
+let unknown_country = ("--", "N/A")
 let file = ref (Obj.magic 0)
 let active = ref false
 let database_type = ref databaseInfo_COUNTRY_EDITION 
@@ -131,28 +137,31 @@ let unpack filename =
       ext
     in
     match real_ext with
-      ".zip" ->
-	begin
-	  try
-	    let ic = Zip.open_in filename in
+    | ".zip" ->
+	(try
+	  let file =
+	    Unix2.tryopen_read_zip filename (fun ic ->
 	      try
-		let file = Zip.find_entry ic "GeoIP.dat" in
-		  Zip.close_in ic;
-		ignore(Misc.archive_extract filename "zip");
-		let geo_file = Filename.concat "web_infos" "GeoIP.dat" in
-		(try Sys.remove geo_file with _ -> ());
-		Unix2.rename file.Zip.filename geo_file;
-		geo_file
+		Zip.find_entry ic "GeoIP.dat"
 	      with e ->
-		Zip.close_in ic;
 		lprintf_nl "Exception %s while extracting geoip.dat"
 		  (Printexc2.to_string e);
-		raise Not_found
+		raise e) in
+	  try
+	    ignore(Misc.archive_extract filename "zip");
+	    let geo_file = Filename.concat "web_infos" "GeoIP.dat" in
+	    (try Sys.remove geo_file with _ -> ());
+	    Unix2.rename file.Zip.filename geo_file;
+	    geo_file
 	  with e ->
-	    lprintf_nl "Exception %s while opening %s"
-	      (Printexc2.to_string e) filename;
-	    raise Not_found
-	end
+	    lprintf_nl "Exception %s while extracting geoip.dat"
+	      (Printexc2.to_string e);
+	    raise e
+	with e ->
+	  lprintf_nl "Exception %s while opening %s"
+	    (Printexc2.to_string e) filename;
+	  raise Not_found)
+
     | ".dat.gz" | ".dat.bz2" | ".gz" | ".bz2" ->
 	begin
 	  let filetype =
@@ -298,13 +307,12 @@ let get_country_code ip =
   end
 
 let get_country ip = 
-  if not !active then !unknown_country
+  if not !active then unknown_country
   else begin
     try 
       let ret = (seek_country ip) - country_begin in
-      if ret = 0 then !unknown_country 
+      if ret = 0 then unknown_country 
         else country_code_array.(ret), country_name_array.(ret);
     with _ -> 
-      !unknown_country
+      unknown_country
   end
-
