@@ -31,10 +31,14 @@ val to_fixed_string : t -> string
 val valid : t -> bool
 val local_ip : t -> bool
 val reachable : t -> bool
+val usable : t -> bool
+val banned : (t -> string option) ref
   
 val resolve_one : t -> string
 val matches : t -> t list -> bool
 val compare : t -> t -> int
+val succ : t -> t
+val pred : t -> t
   
 val localhost : t
 val to_sockaddr : t -> int -> Unix.sockaddr
@@ -71,4 +75,4 @@ val addr_to_value : addr -> Options.option_value
 val addr_option : addr Options.option_class
   
 val allow_local_network : bool ref
-  
\ No newline at end of file
+  
